(function(factory) {
  typeof define === "function" && define.amd ? define(factory) : factory();
})(function() {
  "use strict";
  function makeMap(str, expectsLowerCase) {
    const map = /* @__PURE__ */ Object.create(null);
    const list = str.split(",");
    for (let i = 0; i < list.length; i++) {
      map[list[i]] = true;
    }
    return expectsLowerCase ? (val) => !!map[val.toLowerCase()] : (val) => !!map[val];
  }
  const EMPTY_OBJ = {};
  const EMPTY_ARR = [];
  const NOOP = () => {
  };
  const NO = () => false;
  const onRE = /^on[^a-z]/;
  const isOn = (key) => onRE.test(key);
  const isModelListener = (key) => key.startsWith("onUpdate:");
  const extend = Object.assign;
  const remove = (arr, el) => {
    const i = arr.indexOf(el);
    if (i > -1) {
      arr.splice(i, 1);
    }
  };
  const hasOwnProperty$1 = Object.prototype.hasOwnProperty;
  const hasOwn = (val, key) => hasOwnProperty$1.call(val, key);
  const isArray = Array.isArray;
  const isMap = (val) => toTypeString(val) === "[object Map]";
  const isSet = (val) => toTypeString(val) === "[object Set]";
  const isDate = (val) => toTypeString(val) === "[object Date]";
  const isFunction = (val) => typeof val === "function";
  const isString = (val) => typeof val === "string";
  const isSymbol = (val) => typeof val === "symbol";
  const isObject = (val) => val !== null && typeof val === "object";
  const isPromise = (val) => {
    return (isObject(val) || isFunction(val)) && isFunction(val.then) && isFunction(val.catch);
  };
  const objectToString = Object.prototype.toString;
  const toTypeString = (value) => objectToString.call(value);
  const toRawType = (value) => {
    return toTypeString(value).slice(8, -1);
  };
  const isPlainObject = (val) => toTypeString(val) === "[object Object]";
  const isIntegerKey = (key) => isString(key) && key !== "NaN" && key[0] !== "-" && "" + parseInt(key, 10) === key;
  const isReservedProp = /* @__PURE__ */ makeMap(
    // the leading comma is intentional so empty string "" is also included
    ",key,ref,ref_for,ref_key,onVnodeBeforeMount,onVnodeMounted,onVnodeBeforeUpdate,onVnodeUpdated,onVnodeBeforeUnmount,onVnodeUnmounted"
  );
  const cacheStringFunction = (fn) => {
    const cache = /* @__PURE__ */ Object.create(null);
    return (str) => {
      const hit = cache[str];
      return hit || (cache[str] = fn(str));
    };
  };
  const camelizeRE = /-(\w)/g;
  const camelize = cacheStringFunction((str) => {
    return str.replace(camelizeRE, (_, c) => c ? c.toUpperCase() : "");
  });
  const hyphenateRE = /\B([A-Z])/g;
  const hyphenate = cacheStringFunction(
    (str) => str.replace(hyphenateRE, "-$1").toLowerCase()
  );
  const capitalize = cacheStringFunction((str) => {
    return str.charAt(0).toUpperCase() + str.slice(1);
  });
  const toHandlerKey = cacheStringFunction((str) => {
    const s = str ? `on${capitalize(str)}` : ``;
    return s;
  });
  const hasChanged = (value, oldValue) => !Object.is(value, oldValue);
  const invokeArrayFns = (fns, arg) => {
    for (let i = 0; i < fns.length; i++) {
      fns[i](arg);
    }
  };
  const def = (obj, key, value) => {
    Object.defineProperty(obj, key, {
      configurable: true,
      enumerable: false,
      value
    });
  };
  const looseToNumber = (val) => {
    const n = parseFloat(val);
    return isNaN(n) ? val : n;
  };
  const toNumber = (val) => {
    const n = isString(val) ? Number(val) : NaN;
    return isNaN(n) ? val : n;
  };
  let _globalThis;
  const getGlobalThis = () => {
    return _globalThis || (_globalThis = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {});
  };
  function normalizeStyle(value) {
    if (isArray(value)) {
      const res = {};
      for (let i = 0; i < value.length; i++) {
        const item = value[i];
        const normalized = isString(item) ? parseStringStyle(item) : normalizeStyle(item);
        if (normalized) {
          for (const key in normalized) {
            res[key] = normalized[key];
          }
        }
      }
      return res;
    } else if (isString(value) || isObject(value)) {
      return value;
    }
  }
  const listDelimiterRE = /;(?![^(]*\))/g;
  const propertyDelimiterRE = /:([^]+)/;
  const styleCommentRE = /\/\*[^]*?\*\//g;
  function parseStringStyle(cssText) {
    const ret = {};
    cssText.replace(styleCommentRE, "").split(listDelimiterRE).forEach((item) => {
      if (item) {
        const tmp = item.split(propertyDelimiterRE);
        tmp.length > 1 && (ret[tmp[0].trim()] = tmp[1].trim());
      }
    });
    return ret;
  }
  function normalizeClass(value) {
    let res = "";
    if (isString(value)) {
      res = value;
    } else if (isArray(value)) {
      for (let i = 0; i < value.length; i++) {
        const normalized = normalizeClass(value[i]);
        if (normalized) {
          res += normalized + " ";
        }
      }
    } else if (isObject(value)) {
      for (const name in value) {
        if (value[name]) {
          res += name + " ";
        }
      }
    }
    return res.trim();
  }
  const specialBooleanAttrs = `itemscope,allowfullscreen,formnovalidate,ismap,nomodule,novalidate,readonly`;
  const isSpecialBooleanAttr = /* @__PURE__ */ makeMap(specialBooleanAttrs);
  function includeBooleanAttr(value) {
    return !!value || value === "";
  }
  function looseCompareArrays(a, b) {
    if (a.length !== b.length)
      return false;
    let equal = true;
    for (let i = 0; equal && i < a.length; i++) {
      equal = looseEqual(a[i], b[i]);
    }
    return equal;
  }
  function looseEqual(a, b) {
    if (a === b)
      return true;
    let aValidType = isDate(a);
    let bValidType = isDate(b);
    if (aValidType || bValidType) {
      return aValidType && bValidType ? a.getTime() === b.getTime() : false;
    }
    aValidType = isSymbol(a);
    bValidType = isSymbol(b);
    if (aValidType || bValidType) {
      return a === b;
    }
    aValidType = isArray(a);
    bValidType = isArray(b);
    if (aValidType || bValidType) {
      return aValidType && bValidType ? looseCompareArrays(a, b) : false;
    }
    aValidType = isObject(a);
    bValidType = isObject(b);
    if (aValidType || bValidType) {
      if (!aValidType || !bValidType) {
        return false;
      }
      const aKeysCount = Object.keys(a).length;
      const bKeysCount = Object.keys(b).length;
      if (aKeysCount !== bKeysCount) {
        return false;
      }
      for (const key in a) {
        const aHasKey = a.hasOwnProperty(key);
        const bHasKey = b.hasOwnProperty(key);
        if (aHasKey && !bHasKey || !aHasKey && bHasKey || !looseEqual(a[key], b[key])) {
          return false;
        }
      }
    }
    return String(a) === String(b);
  }
  function looseIndexOf(arr, val) {
    return arr.findIndex((item) => looseEqual(item, val));
  }
  const toDisplayString = (val) => {
    return isString(val) ? val : val == null ? "" : isArray(val) || isObject(val) && (val.toString === objectToString || !isFunction(val.toString)) ? JSON.stringify(val, replacer, 2) : String(val);
  };
  const replacer = (_key, val) => {
    if (val && val.__v_isRef) {
      return replacer(_key, val.value);
    } else if (isMap(val)) {
      return {
        [`Map(${val.size})`]: [...val.entries()].reduce((entries, [key, val2]) => {
          entries[`${key} =>`] = val2;
          return entries;
        }, {})
      };
    } else if (isSet(val)) {
      return {
        [`Set(${val.size})`]: [...val.values()]
      };
    } else if (isObject(val) && !isArray(val) && !isPlainObject(val)) {
      return String(val);
    }
    return val;
  };
  let activeEffectScope;
  class EffectScope {
    constructor(detached = false) {
      this.detached = detached;
      this._active = true;
      this.effects = [];
      this.cleanups = [];
      this.parent = activeEffectScope;
      if (!detached && activeEffectScope) {
        this.index = (activeEffectScope.scopes || (activeEffectScope.scopes = [])).push(
          this
        ) - 1;
      }
    }
    get active() {
      return this._active;
    }
    run(fn) {
      if (this._active) {
        const currentEffectScope = activeEffectScope;
        try {
          activeEffectScope = this;
          return fn();
        } finally {
          activeEffectScope = currentEffectScope;
        }
      }
    }
    /**
     * This should only be called on non-detached scopes
     * @internal
     */
    on() {
      activeEffectScope = this;
    }
    /**
     * This should only be called on non-detached scopes
     * @internal
     */
    off() {
      activeEffectScope = this.parent;
    }
    stop(fromParent) {
      if (this._active) {
        let i, l;
        for (i = 0, l = this.effects.length; i < l; i++) {
          this.effects[i].stop();
        }
        for (i = 0, l = this.cleanups.length; i < l; i++) {
          this.cleanups[i]();
        }
        if (this.scopes) {
          for (i = 0, l = this.scopes.length; i < l; i++) {
            this.scopes[i].stop(true);
          }
        }
        if (!this.detached && this.parent && !fromParent) {
          const last = this.parent.scopes.pop();
          if (last && last !== this) {
            this.parent.scopes[this.index] = last;
            last.index = this.index;
          }
        }
        this.parent = void 0;
        this._active = false;
      }
    }
  }
  function recordEffectScope(effect, scope = activeEffectScope) {
    if (scope && scope.active) {
      scope.effects.push(effect);
    }
  }
  function getCurrentScope() {
    return activeEffectScope;
  }
  const createDep = (effects) => {
    const dep = new Set(effects);
    dep.w = 0;
    dep.n = 0;
    return dep;
  };
  const wasTracked = (dep) => (dep.w & trackOpBit) > 0;
  const newTracked = (dep) => (dep.n & trackOpBit) > 0;
  const initDepMarkers = ({ deps }) => {
    if (deps.length) {
      for (let i = 0; i < deps.length; i++) {
        deps[i].w |= trackOpBit;
      }
    }
  };
  const finalizeDepMarkers = (effect) => {
    const { deps } = effect;
    if (deps.length) {
      let ptr = 0;
      for (let i = 0; i < deps.length; i++) {
        const dep = deps[i];
        if (wasTracked(dep) && !newTracked(dep)) {
          dep.delete(effect);
        } else {
          deps[ptr++] = dep;
        }
        dep.w &= ~trackOpBit;
        dep.n &= ~trackOpBit;
      }
      deps.length = ptr;
    }
  };
  const targetMap = /* @__PURE__ */ new WeakMap();
  let effectTrackDepth = 0;
  let trackOpBit = 1;
  const maxMarkerBits = 30;
  let activeEffect;
  const ITERATE_KEY = Symbol("");
  const MAP_KEY_ITERATE_KEY = Symbol("");
  class ReactiveEffect {
    constructor(fn, scheduler = null, scope) {
      this.fn = fn;
      this.scheduler = scheduler;
      this.active = true;
      this.deps = [];
      this.parent = void 0;
      recordEffectScope(this, scope);
    }
    run() {
      if (!this.active) {
        return this.fn();
      }
      let parent = activeEffect;
      let lastShouldTrack = shouldTrack;
      while (parent) {
        if (parent === this) {
          return;
        }
        parent = parent.parent;
      }
      try {
        this.parent = activeEffect;
        activeEffect = this;
        shouldTrack = true;
        trackOpBit = 1 << ++effectTrackDepth;
        if (effectTrackDepth <= maxMarkerBits) {
          initDepMarkers(this);
        } else {
          cleanupEffect(this);
        }
        return this.fn();
      } finally {
        if (effectTrackDepth <= maxMarkerBits) {
          finalizeDepMarkers(this);
        }
        trackOpBit = 1 << --effectTrackDepth;
        activeEffect = this.parent;
        shouldTrack = lastShouldTrack;
        this.parent = void 0;
        if (this.deferStop) {
          this.stop();
        }
      }
    }
    stop() {
      if (activeEffect === this) {
        this.deferStop = true;
      } else if (this.active) {
        cleanupEffect(this);
        if (this.onStop) {
          this.onStop();
        }
        this.active = false;
      }
    }
  }
  function cleanupEffect(effect2) {
    const { deps } = effect2;
    if (deps.length) {
      for (let i = 0; i < deps.length; i++) {
        deps[i].delete(effect2);
      }
      deps.length = 0;
    }
  }
  let shouldTrack = true;
  const trackStack = [];
  function pauseTracking() {
    trackStack.push(shouldTrack);
    shouldTrack = false;
  }
  function resetTracking() {
    const last = trackStack.pop();
    shouldTrack = last === void 0 ? true : last;
  }
  function track(target, type, key) {
    if (shouldTrack && activeEffect) {
      let depsMap = targetMap.get(target);
      if (!depsMap) {
        targetMap.set(target, depsMap = /* @__PURE__ */ new Map());
      }
      let dep = depsMap.get(key);
      if (!dep) {
        depsMap.set(key, dep = createDep());
      }
      trackEffects(dep);
    }
  }
  function trackEffects(dep, debuggerEventExtraInfo) {
    let shouldTrack2 = false;
    if (effectTrackDepth <= maxMarkerBits) {
      if (!newTracked(dep)) {
        dep.n |= trackOpBit;
        shouldTrack2 = !wasTracked(dep);
      }
    } else {
      shouldTrack2 = !dep.has(activeEffect);
    }
    if (shouldTrack2) {
      dep.add(activeEffect);
      activeEffect.deps.push(dep);
    }
  }
  function trigger(target, type, key, newValue, oldValue, oldTarget) {
    const depsMap = targetMap.get(target);
    if (!depsMap) {
      return;
    }
    let deps = [];
    if (type === "clear") {
      deps = [...depsMap.values()];
    } else if (key === "length" && isArray(target)) {
      const newLength = Number(newValue);
      depsMap.forEach((dep, key2) => {
        if (key2 === "length" || !isSymbol(key2) && key2 >= newLength) {
          deps.push(dep);
        }
      });
    } else {
      if (key !== void 0) {
        deps.push(depsMap.get(key));
      }
      switch (type) {
        case "add":
          if (!isArray(target)) {
            deps.push(depsMap.get(ITERATE_KEY));
            if (isMap(target)) {
              deps.push(depsMap.get(MAP_KEY_ITERATE_KEY));
            }
          } else if (isIntegerKey(key)) {
            deps.push(depsMap.get("length"));
          }
          break;
        case "delete":
          if (!isArray(target)) {
            deps.push(depsMap.get(ITERATE_KEY));
            if (isMap(target)) {
              deps.push(depsMap.get(MAP_KEY_ITERATE_KEY));
            }
          }
          break;
        case "set":
          if (isMap(target)) {
            deps.push(depsMap.get(ITERATE_KEY));
          }
          break;
      }
    }
    if (deps.length === 1) {
      if (deps[0]) {
        {
          triggerEffects(deps[0]);
        }
      }
    } else {
      const effects = [];
      for (const dep of deps) {
        if (dep) {
          effects.push(...dep);
        }
      }
      {
        triggerEffects(createDep(effects));
      }
    }
  }
  function triggerEffects(dep, debuggerEventExtraInfo) {
    const effects = isArray(dep) ? dep : [...dep];
    for (const effect2 of effects) {
      if (effect2.computed) {
        triggerEffect(effect2);
      }
    }
    for (const effect2 of effects) {
      if (!effect2.computed) {
        triggerEffect(effect2);
      }
    }
  }
  function triggerEffect(effect2, debuggerEventExtraInfo) {
    if (effect2 !== activeEffect || effect2.allowRecurse) {
      if (effect2.scheduler) {
        effect2.scheduler();
      } else {
        effect2.run();
      }
    }
  }
  const isNonTrackableKeys = /* @__PURE__ */ makeMap(`__proto__,__v_isRef,__isVue`);
  const builtInSymbols = new Set(
    /* @__PURE__ */ Object.getOwnPropertyNames(Symbol).filter((key) => key !== "arguments" && key !== "caller").map((key) => Symbol[key]).filter(isSymbol)
  );
  const arrayInstrumentations = /* @__PURE__ */ createArrayInstrumentations();
  function createArrayInstrumentations() {
    const instrumentations = {};
    ["includes", "indexOf", "lastIndexOf"].forEach((key) => {
      instrumentations[key] = function(...args) {
        const arr = toRaw(this);
        for (let i = 0, l = this.length; i < l; i++) {
          track(arr, "get", i + "");
        }
        const res = arr[key](...args);
        if (res === -1 || res === false) {
          return arr[key](...args.map(toRaw));
        } else {
          return res;
        }
      };
    });
    ["push", "pop", "shift", "unshift", "splice"].forEach((key) => {
      instrumentations[key] = function(...args) {
        pauseTracking();
        const res = toRaw(this)[key].apply(this, args);
        resetTracking();
        return res;
      };
    });
    return instrumentations;
  }
  function hasOwnProperty(key) {
    const obj = toRaw(this);
    track(obj, "has", key);
    return obj.hasOwnProperty(key);
  }
  class BaseReactiveHandler {
    constructor(_isReadonly = false, _shallow = false) {
      this._isReadonly = _isReadonly;
      this._shallow = _shallow;
    }
    get(target, key, receiver) {
      const isReadonly2 = this._isReadonly, shallow = this._shallow;
      if (key === "__v_isReactive") {
        return !isReadonly2;
      } else if (key === "__v_isReadonly") {
        return isReadonly2;
      } else if (key === "__v_isShallow") {
        return shallow;
      } else if (key === "__v_raw" && receiver === (isReadonly2 ? shallow ? shallowReadonlyMap : readonlyMap : shallow ? shallowReactiveMap : reactiveMap).get(target)) {
        return target;
      }
      const targetIsArray = isArray(target);
      if (!isReadonly2) {
        if (targetIsArray && hasOwn(arrayInstrumentations, key)) {
          return Reflect.get(arrayInstrumentations, key, receiver);
        }
        if (key === "hasOwnProperty") {
          return hasOwnProperty;
        }
      }
      const res = Reflect.get(target, key, receiver);
      if (isSymbol(key) ? builtInSymbols.has(key) : isNonTrackableKeys(key)) {
        return res;
      }
      if (!isReadonly2) {
        track(target, "get", key);
      }
      if (shallow) {
        return res;
      }
      if (isRef(res)) {
        return targetIsArray && isIntegerKey(key) ? res : res.value;
      }
      if (isObject(res)) {
        return isReadonly2 ? readonly(res) : reactive(res);
      }
      return res;
    }
  }
  class MutableReactiveHandler extends BaseReactiveHandler {
    constructor(shallow = false) {
      super(false, shallow);
    }
    set(target, key, value, receiver) {
      let oldValue = target[key];
      if (isReadonly(oldValue) && isRef(oldValue) && !isRef(value)) {
        return false;
      }
      if (!this._shallow) {
        if (!isShallow(value) && !isReadonly(value)) {
          oldValue = toRaw(oldValue);
          value = toRaw(value);
        }
        if (!isArray(target) && isRef(oldValue) && !isRef(value)) {
          oldValue.value = value;
          return true;
        }
      }
      const hadKey = isArray(target) && isIntegerKey(key) ? Number(key) < target.length : hasOwn(target, key);
      const result = Reflect.set(target, key, value, receiver);
      if (target === toRaw(receiver)) {
        if (!hadKey) {
          trigger(target, "add", key, value);
        } else if (hasChanged(value, oldValue)) {
          trigger(target, "set", key, value);
        }
      }
      return result;
    }
    deleteProperty(target, key) {
      const hadKey = hasOwn(target, key);
      target[key];
      const result = Reflect.deleteProperty(target, key);
      if (result && hadKey) {
        trigger(target, "delete", key, void 0);
      }
      return result;
    }
    has(target, key) {
      const result = Reflect.has(target, key);
      if (!isSymbol(key) || !builtInSymbols.has(key)) {
        track(target, "has", key);
      }
      return result;
    }
    ownKeys(target) {
      track(
        target,
        "iterate",
        isArray(target) ? "length" : ITERATE_KEY
      );
      return Reflect.ownKeys(target);
    }
  }
  class ReadonlyReactiveHandler extends BaseReactiveHandler {
    constructor(shallow = false) {
      super(true, shallow);
    }
    set(target, key) {
      return true;
    }
    deleteProperty(target, key) {
      return true;
    }
  }
  const mutableHandlers = /* @__PURE__ */ new MutableReactiveHandler();
  const readonlyHandlers = /* @__PURE__ */ new ReadonlyReactiveHandler();
  const shallowReactiveHandlers = /* @__PURE__ */ new MutableReactiveHandler(
    true
  );
  const toShallow = (value) => value;
  const getProto = (v) => Reflect.getPrototypeOf(v);
  function get(target, key, isReadonly2 = false, isShallow2 = false) {
    target = target["__v_raw"];
    const rawTarget = toRaw(target);
    const rawKey = toRaw(key);
    if (!isReadonly2) {
      if (hasChanged(key, rawKey)) {
        track(rawTarget, "get", key);
      }
      track(rawTarget, "get", rawKey);
    }
    const { has: has2 } = getProto(rawTarget);
    const wrap = isShallow2 ? toShallow : isReadonly2 ? toReadonly : toReactive;
    if (has2.call(rawTarget, key)) {
      return wrap(target.get(key));
    } else if (has2.call(rawTarget, rawKey)) {
      return wrap(target.get(rawKey));
    } else if (target !== rawTarget) {
      target.get(key);
    }
  }
  function has(key, isReadonly2 = false) {
    const target = this["__v_raw"];
    const rawTarget = toRaw(target);
    const rawKey = toRaw(key);
    if (!isReadonly2) {
      if (hasChanged(key, rawKey)) {
        track(rawTarget, "has", key);
      }
      track(rawTarget, "has", rawKey);
    }
    return key === rawKey ? target.has(key) : target.has(key) || target.has(rawKey);
  }
  function size(target, isReadonly2 = false) {
    target = target["__v_raw"];
    !isReadonly2 && track(toRaw(target), "iterate", ITERATE_KEY);
    return Reflect.get(target, "size", target);
  }
  function add(value) {
    value = toRaw(value);
    const target = toRaw(this);
    const proto = getProto(target);
    const hadKey = proto.has.call(target, value);
    if (!hadKey) {
      target.add(value);
      trigger(target, "add", value, value);
    }
    return this;
  }
  function set(key, value) {
    value = toRaw(value);
    const target = toRaw(this);
    const { has: has2, get: get2 } = getProto(target);
    let hadKey = has2.call(target, key);
    if (!hadKey) {
      key = toRaw(key);
      hadKey = has2.call(target, key);
    }
    const oldValue = get2.call(target, key);
    target.set(key, value);
    if (!hadKey) {
      trigger(target, "add", key, value);
    } else if (hasChanged(value, oldValue)) {
      trigger(target, "set", key, value);
    }
    return this;
  }
  function deleteEntry(key) {
    const target = toRaw(this);
    const { has: has2, get: get2 } = getProto(target);
    let hadKey = has2.call(target, key);
    if (!hadKey) {
      key = toRaw(key);
      hadKey = has2.call(target, key);
    }
    get2 ? get2.call(target, key) : void 0;
    const result = target.delete(key);
    if (hadKey) {
      trigger(target, "delete", key, void 0);
    }
    return result;
  }
  function clear() {
    const target = toRaw(this);
    const hadItems = target.size !== 0;
    const result = target.clear();
    if (hadItems) {
      trigger(target, "clear", void 0, void 0);
    }
    return result;
  }
  function createForEach(isReadonly2, isShallow2) {
    return function forEach(callback, thisArg) {
      const observed = this;
      const target = observed["__v_raw"];
      const rawTarget = toRaw(target);
      const wrap = isShallow2 ? toShallow : isReadonly2 ? toReadonly : toReactive;
      !isReadonly2 && track(rawTarget, "iterate", ITERATE_KEY);
      return target.forEach((value, key) => {
        return callback.call(thisArg, wrap(value), wrap(key), observed);
      });
    };
  }
  function createIterableMethod(method, isReadonly2, isShallow2) {
    return function(...args) {
      const target = this["__v_raw"];
      const rawTarget = toRaw(target);
      const targetIsMap = isMap(rawTarget);
      const isPair = method === "entries" || method === Symbol.iterator && targetIsMap;
      const isKeyOnly = method === "keys" && targetIsMap;
      const innerIterator = target[method](...args);
      const wrap = isShallow2 ? toShallow : isReadonly2 ? toReadonly : toReactive;
      !isReadonly2 && track(
        rawTarget,
        "iterate",
        isKeyOnly ? MAP_KEY_ITERATE_KEY : ITERATE_KEY
      );
      return {
        // iterator protocol
        next() {
          const { value, done } = innerIterator.next();
          return done ? { value, done } : {
            value: isPair ? [wrap(value[0]), wrap(value[1])] : wrap(value),
            done
          };
        },
        // iterable protocol
        [Symbol.iterator]() {
          return this;
        }
      };
    };
  }
  function createReadonlyMethod(type) {
    return function(...args) {
      return type === "delete" ? false : this;
    };
  }
  function createInstrumentations() {
    const mutableInstrumentations2 = {
      get(key) {
        return get(this, key);
      },
      get size() {
        return size(this);
      },
      has,
      add,
      set,
      delete: deleteEntry,
      clear,
      forEach: createForEach(false, false)
    };
    const shallowInstrumentations2 = {
      get(key) {
        return get(this, key, false, true);
      },
      get size() {
        return size(this);
      },
      has,
      add,
      set,
      delete: deleteEntry,
      clear,
      forEach: createForEach(false, true)
    };
    const readonlyInstrumentations2 = {
      get(key) {
        return get(this, key, true);
      },
      get size() {
        return size(this, true);
      },
      has(key) {
        return has.call(this, key, true);
      },
      add: createReadonlyMethod("add"),
      set: createReadonlyMethod("set"),
      delete: createReadonlyMethod("delete"),
      clear: createReadonlyMethod("clear"),
      forEach: createForEach(true, false)
    };
    const shallowReadonlyInstrumentations2 = {
      get(key) {
        return get(this, key, true, true);
      },
      get size() {
        return size(this, true);
      },
      has(key) {
        return has.call(this, key, true);
      },
      add: createReadonlyMethod("add"),
      set: createReadonlyMethod("set"),
      delete: createReadonlyMethod("delete"),
      clear: createReadonlyMethod("clear"),
      forEach: createForEach(true, true)
    };
    const iteratorMethods = ["keys", "values", "entries", Symbol.iterator];
    iteratorMethods.forEach((method) => {
      mutableInstrumentations2[method] = createIterableMethod(
        method,
        false,
        false
      );
      readonlyInstrumentations2[method] = createIterableMethod(
        method,
        true,
        false
      );
      shallowInstrumentations2[method] = createIterableMethod(
        method,
        false,
        true
      );
      shallowReadonlyInstrumentations2[method] = createIterableMethod(
        method,
        true,
        true
      );
    });
    return [
      mutableInstrumentations2,
      readonlyInstrumentations2,
      shallowInstrumentations2,
      shallowReadonlyInstrumentations2
    ];
  }
  const [
    mutableInstrumentations,
    readonlyInstrumentations,
    shallowInstrumentations,
    shallowReadonlyInstrumentations
  ] = /* @__PURE__ */ createInstrumentations();
  function createInstrumentationGetter(isReadonly2, shallow) {
    const instrumentations = shallow ? isReadonly2 ? shallowReadonlyInstrumentations : shallowInstrumentations : isReadonly2 ? readonlyInstrumentations : mutableInstrumentations;
    return (target, key, receiver) => {
      if (key === "__v_isReactive") {
        return !isReadonly2;
      } else if (key === "__v_isReadonly") {
        return isReadonly2;
      } else if (key === "__v_raw") {
        return target;
      }
      return Reflect.get(
        hasOwn(instrumentations, key) && key in target ? instrumentations : target,
        key,
        receiver
      );
    };
  }
  const mutableCollectionHandlers = {
    get: /* @__PURE__ */ createInstrumentationGetter(false, false)
  };
  const shallowCollectionHandlers = {
    get: /* @__PURE__ */ createInstrumentationGetter(false, true)
  };
  const readonlyCollectionHandlers = {
    get: /* @__PURE__ */ createInstrumentationGetter(true, false)
  };
  const reactiveMap = /* @__PURE__ */ new WeakMap();
  const shallowReactiveMap = /* @__PURE__ */ new WeakMap();
  const readonlyMap = /* @__PURE__ */ new WeakMap();
  const shallowReadonlyMap = /* @__PURE__ */ new WeakMap();
  function targetTypeMap(rawType) {
    switch (rawType) {
      case "Object":
      case "Array":
        return 1;
      case "Map":
      case "Set":
      case "WeakMap":
      case "WeakSet":
        return 2;
      default:
        return 0;
    }
  }
  function getTargetType(value) {
    return value["__v_skip"] || !Object.isExtensible(value) ? 0 : targetTypeMap(toRawType(value));
  }
  function reactive(target) {
    if (isReadonly(target)) {
      return target;
    }
    return createReactiveObject(
      target,
      false,
      mutableHandlers,
      mutableCollectionHandlers,
      reactiveMap
    );
  }
  function shallowReactive(target) {
    return createReactiveObject(
      target,
      false,
      shallowReactiveHandlers,
      shallowCollectionHandlers,
      shallowReactiveMap
    );
  }
  function readonly(target) {
    return createReactiveObject(
      target,
      true,
      readonlyHandlers,
      readonlyCollectionHandlers,
      readonlyMap
    );
  }
  function createReactiveObject(target, isReadonly2, baseHandlers, collectionHandlers, proxyMap) {
    if (!isObject(target)) {
      return target;
    }
    if (target["__v_raw"] && !(isReadonly2 && target["__v_isReactive"])) {
      return target;
    }
    const existingProxy = proxyMap.get(target);
    if (existingProxy) {
      return existingProxy;
    }
    const targetType = getTargetType(target);
    if (targetType === 0) {
      return target;
    }
    const proxy = new Proxy(
      target,
      targetType === 2 ? collectionHandlers : baseHandlers
    );
    proxyMap.set(target, proxy);
    return proxy;
  }
  function isReactive(value) {
    if (isReadonly(value)) {
      return isReactive(value["__v_raw"]);
    }
    return !!(value && value["__v_isReactive"]);
  }
  function isReadonly(value) {
    return !!(value && value["__v_isReadonly"]);
  }
  function isShallow(value) {
    return !!(value && value["__v_isShallow"]);
  }
  function isProxy(value) {
    return isReactive(value) || isReadonly(value);
  }
  function toRaw(observed) {
    const raw = observed && observed["__v_raw"];
    return raw ? toRaw(raw) : observed;
  }
  function markRaw(value) {
    def(value, "__v_skip", true);
    return value;
  }
  const toReactive = (value) => isObject(value) ? reactive(value) : value;
  const toReadonly = (value) => isObject(value) ? readonly(value) : value;
  function trackRefValue(ref2) {
    if (shouldTrack && activeEffect) {
      ref2 = toRaw(ref2);
      {
        trackEffects(ref2.dep || (ref2.dep = createDep()));
      }
    }
  }
  function triggerRefValue(ref2, newVal) {
    ref2 = toRaw(ref2);
    const dep = ref2.dep;
    if (dep) {
      {
        triggerEffects(dep);
      }
    }
  }
  function isRef(r) {
    return !!(r && r.__v_isRef === true);
  }
  function ref(value) {
    return createRef(value, false);
  }
  function createRef(rawValue, shallow) {
    if (isRef(rawValue)) {
      return rawValue;
    }
    return new RefImpl(rawValue, shallow);
  }
  class RefImpl {
    constructor(value, __v_isShallow) {
      this.__v_isShallow = __v_isShallow;
      this.dep = void 0;
      this.__v_isRef = true;
      this._rawValue = __v_isShallow ? value : toRaw(value);
      this._value = __v_isShallow ? value : toReactive(value);
    }
    get value() {
      trackRefValue(this);
      return this._value;
    }
    set value(newVal) {
      const useDirectValue = this.__v_isShallow || isShallow(newVal) || isReadonly(newVal);
      newVal = useDirectValue ? newVal : toRaw(newVal);
      if (hasChanged(newVal, this._rawValue)) {
        this._rawValue = newVal;
        this._value = useDirectValue ? newVal : toReactive(newVal);
        triggerRefValue(this);
      }
    }
  }
  function unref(ref2) {
    return isRef(ref2) ? ref2.value : ref2;
  }
  const shallowUnwrapHandlers = {
    get: (target, key, receiver) => unref(Reflect.get(target, key, receiver)),
    set: (target, key, value, receiver) => {
      const oldValue = target[key];
      if (isRef(oldValue) && !isRef(value)) {
        oldValue.value = value;
        return true;
      } else {
        return Reflect.set(target, key, value, receiver);
      }
    }
  };
  function proxyRefs(objectWithRefs) {
    return isReactive(objectWithRefs) ? objectWithRefs : new Proxy(objectWithRefs, shallowUnwrapHandlers);
  }
  class ComputedRefImpl {
    constructor(getter, _setter, isReadonly2, isSSR) {
      this._setter = _setter;
      this.dep = void 0;
      this.__v_isRef = true;
      this["__v_isReadonly"] = false;
      this._dirty = true;
      this.effect = new ReactiveEffect(getter, () => {
        if (!this._dirty) {
          this._dirty = true;
          triggerRefValue(this);
        }
      });
      this.effect.computed = this;
      this.effect.active = this._cacheable = !isSSR;
      this["__v_isReadonly"] = isReadonly2;
    }
    get value() {
      const self2 = toRaw(this);
      trackRefValue(self2);
      if (self2._dirty || !self2._cacheable) {
        self2._dirty = false;
        self2._value = self2.effect.run();
      }
      return self2._value;
    }
    set value(newValue) {
      this._setter(newValue);
    }
  }
  function computed$1(getterOrOptions, debugOptions, isSSR = false) {
    let getter;
    let setter;
    const onlyGetter = isFunction(getterOrOptions);
    if (onlyGetter) {
      getter = getterOrOptions;
      setter = NOOP;
    } else {
      getter = getterOrOptions.get;
      setter = getterOrOptions.set;
    }
    const cRef = new ComputedRefImpl(getter, setter, onlyGetter || !setter, isSSR);
    return cRef;
  }
  function warn(msg, ...args) {
    return;
  }
  function callWithErrorHandling(fn, instance, type, args) {
    let res;
    try {
      res = args ? fn(...args) : fn();
    } catch (err) {
      handleError(err, instance, type);
    }
    return res;
  }
  function callWithAsyncErrorHandling(fn, instance, type, args) {
    if (isFunction(fn)) {
      const res = callWithErrorHandling(fn, instance, type, args);
      if (res && isPromise(res)) {
        res.catch((err) => {
          handleError(err, instance, type);
        });
      }
      return res;
    }
    const values = [];
    for (let i = 0; i < fn.length; i++) {
      values.push(callWithAsyncErrorHandling(fn[i], instance, type, args));
    }
    return values;
  }
  function handleError(err, instance, type, throwInDev = true) {
    const contextVNode = instance ? instance.vnode : null;
    if (instance) {
      let cur = instance.parent;
      const exposedInstance = instance.proxy;
      const errorInfo = type;
      while (cur) {
        const errorCapturedHooks = cur.ec;
        if (errorCapturedHooks) {
          for (let i = 0; i < errorCapturedHooks.length; i++) {
            if (errorCapturedHooks[i](err, exposedInstance, errorInfo) === false) {
              return;
            }
          }
        }
        cur = cur.parent;
      }
      const appErrorHandler = instance.appContext.config.errorHandler;
      if (appErrorHandler) {
        callWithErrorHandling(
          appErrorHandler,
          null,
          10,
          [err, exposedInstance, errorInfo]
        );
        return;
      }
    }
    logError(err, type, contextVNode, throwInDev);
  }
  function logError(err, type, contextVNode, throwInDev = true) {
    {
      console.error(err);
    }
  }
  let isFlushing = false;
  let isFlushPending = false;
  const queue = [];
  let flushIndex = 0;
  const pendingPostFlushCbs = [];
  let activePostFlushCbs = null;
  let postFlushIndex = 0;
  const resolvedPromise = /* @__PURE__ */ Promise.resolve();
  let currentFlushPromise = null;
  function nextTick(fn) {
    const p2 = currentFlushPromise || resolvedPromise;
    return fn ? p2.then(this ? fn.bind(this) : fn) : p2;
  }
  function findInsertionIndex(id) {
    let start = flushIndex + 1;
    let end = queue.length;
    while (start < end) {
      const middle = start + end >>> 1;
      const middleJob = queue[middle];
      const middleJobId = getId(middleJob);
      if (middleJobId < id || middleJobId === id && middleJob.pre) {
        start = middle + 1;
      } else {
        end = middle;
      }
    }
    return start;
  }
  function queueJob(job) {
    if (!queue.length || !queue.includes(
      job,
      isFlushing && job.allowRecurse ? flushIndex + 1 : flushIndex
    )) {
      if (job.id == null) {
        queue.push(job);
      } else {
        queue.splice(findInsertionIndex(job.id), 0, job);
      }
      queueFlush();
    }
  }
  function queueFlush() {
    if (!isFlushing && !isFlushPending) {
      isFlushPending = true;
      currentFlushPromise = resolvedPromise.then(flushJobs);
    }
  }
  function invalidateJob(job) {
    const i = queue.indexOf(job);
    if (i > flushIndex) {
      queue.splice(i, 1);
    }
  }
  function queuePostFlushCb(cb) {
    if (!isArray(cb)) {
      if (!activePostFlushCbs || !activePostFlushCbs.includes(
        cb,
        cb.allowRecurse ? postFlushIndex + 1 : postFlushIndex
      )) {
        pendingPostFlushCbs.push(cb);
      }
    } else {
      pendingPostFlushCbs.push(...cb);
    }
    queueFlush();
  }
  function flushPreFlushCbs(seen, i = isFlushing ? flushIndex + 1 : 0) {
    for (; i < queue.length; i++) {
      const cb = queue[i];
      if (cb && cb.pre) {
        queue.splice(i, 1);
        i--;
        cb();
      }
    }
  }
  function flushPostFlushCbs(seen) {
    if (pendingPostFlushCbs.length) {
      const deduped = [...new Set(pendingPostFlushCbs)];
      pendingPostFlushCbs.length = 0;
      if (activePostFlushCbs) {
        activePostFlushCbs.push(...deduped);
        return;
      }
      activePostFlushCbs = deduped;
      activePostFlushCbs.sort((a, b) => getId(a) - getId(b));
      for (postFlushIndex = 0; postFlushIndex < activePostFlushCbs.length; postFlushIndex++) {
        activePostFlushCbs[postFlushIndex]();
      }
      activePostFlushCbs = null;
      postFlushIndex = 0;
    }
  }
  const getId = (job) => job.id == null ? Infinity : job.id;
  const comparator = (a, b) => {
    const diff = getId(a) - getId(b);
    if (diff === 0) {
      if (a.pre && !b.pre)
        return -1;
      if (b.pre && !a.pre)
        return 1;
    }
    return diff;
  };
  function flushJobs(seen) {
    isFlushPending = false;
    isFlushing = true;
    queue.sort(comparator);
    const check = NOOP;
    try {
      for (flushIndex = 0; flushIndex < queue.length; flushIndex++) {
        const job = queue[flushIndex];
        if (job && job.active !== false) {
          if (!!({ "agent.jobstatus": "Succeeded", "AGENT_BUILDDIRECTORY": "X:\\agent\\_work\\212", "AGENT_DISABLELOGPLUGIN_TESTFILEPUBLISHERPLUGIN": "true", "AGENT_DISABLELOGPLUGIN_TESTRESULTLOGPLUGIN": "true", "AGENT_HOMEDIRECTORY": "X:\\agent", "AGENT_ID": "8", "AGENT_JOBNAME": "Agent job 1", "AGENT_JOBSTATUS": "Succeeded", "AGENT_MACHINENAME": "TFSBUILD1", "AGENT_NAME": "TFSBUILD1-Agent", "AGENT_OS": "Windows_NT", "AGENT_OSARCHITECTURE": "X64", "AGENT_READONLYVARIABLES": "true", "AGENT_RETAINDEFAULTENCODING": "false", "AGENT_ROOTDIRECTORY": "X:\\agent\\_work", "AGENT_SERVEROMDIRECTORY": "X:\\agent\\externals\\vstsom", "AGENT_TEMPDIRECTORY": "X:\\agent\\_work\\_temp", "AGENT_TOOLSDIRECTORY": "X:\\agent\\_work\\_tool", "AGENT_VERSION": "2.181.2", "AGENT_WORKFOLDER": "X:\\agent\\_work", "ALLUSERSPROFILE": "C:\\ProgramData", "APPDATA": "C:\\Users\\tfs_service\\AppData\\Roaming", "AZURE_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "BUILD_ARTIFACTSTAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "BUILD_BINARIESDIRECTORY": "X:\\agent\\_work\\212\\b", "BUILD_BUILDID": "52978", "BUILD_BUILDNUMBER": "52978", "BUILD_BUILDURI": "vstfs:///Build/Build/52978", "BUILD_CONTAINERID": "113236", "BUILD_DEFINITIONNAME": "MFE_Calendar", "BUILD_DEFINITIONVERSION": "4", "BUILD_QUEUEDBY": "jake.salmon", "BUILD_QUEUEDBYID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_REASON": "Manual", "BUILD_REPOSITORY_CLEAN": "True", "BUILD_REPOSITORY_GIT_SUBMODULECHECKOUT": "False", "BUILD_REPOSITORY_ID": "ca089350-a60d-4fa9-8d03-a92b61d738bd", "BUILD_REPOSITORY_LOCALPATH": "X:\\agent\\_work\\212\\s", "BUILD_REPOSITORY_NAME": "MFE-Calendar", "BUILD_REPOSITORY_PROVIDER": "TfsGit", "BUILD_REPOSITORY_URI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/TeamProject/_git/MFE-Calendar", "BUILD_REQUESTEDFOR": "jake.salmon", "BUILD_REQUESTEDFOREMAIL": "Jake.Salmon@tui.co.uk", "BUILD_REQUESTEDFORID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_SOURCEBRANCH": "refs/heads/master", "BUILD_SOURCEBRANCHNAME": "master", "BUILD_SOURCESDIRECTORY": "X:\\agent\\_work\\212\\s", "BUILD_SOURCEVERSION": "8be35ec0af51f99c9106ca475e91dd61918f373c", "BUILD_SOURCEVERSIONAUTHOR": "jake.salmon", "BUILD_SOURCEVERSIONMESSAGE": "Merged PR 12789: small fix for margin issues on Holiday details\n\nsmall fix for margin issues on HD", "BUILD_STAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "COLOR": "0", "CommonProgramFiles": "C:\\Program Files\\Common Files", "CommonProgramFiles(x86)": "C:\\Program Files (x86)\\Common Files", "CommonProgramW6432": "C:\\Program Files\\Common Files", "COMMON_TESTRESULTSDIRECTORY": "X:\\agent\\_work\\212\\TestResults", "COMPUTERNAME": "TFSBUILD1", "ComSpec": "C:\\Windows\\system32\\cmd.exe", "EDITOR": "C:\\Windows\\notepad.exe", "ENDPOINT_URL_SYSTEMVSSCONNECTION": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "GIT_TERMINAL_PROMPT": "0", "HOME": "C:\\Users\\tfs_service", "INIT_CWD": "X:\\agent\\_work\\212\\s", "INPUT_CUSTOMENDPOINT": "", "INPUT_CUSTOMFEED": "", "INPUT_PUBLISHENDPOINT": "", "INPUT_PUBLISHFEED": "", "LOCALAPPDATA": "C:\\Users\\tfs_service\\AppData\\Local", "MSDEPLOY_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "NODE": "C:\\Program Files\\nodejs\\node.exe", "NODE_ENV": "production", "NODE_EXE": "C:\\Program Files\\nodejs\\\\node.exe", "NODE_EXTRA_CA_CERTS": "C:\\Build\\node-extra-cert\\ca.crt", "NO_PROXY": "tfs.holidayhype.co.uk, *.holidayhype.co.uk, 10.3.*, 10.1.*, 10.0.*, localhost", "NPM_CLI_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-cli.js", "npm_command": "run-script", "npm_config_cache": "C:\\Users\\tfs_service\\AppData\\Local\\npm-cache", "npm_config_globalconfig": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\etc\\npmrc", "npm_config_global_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "npm_config_init_module": "C:\\Users\\tfs_service\\.npm-init.js", "npm_config_local_prefix": "X:\\agent\\_work\\212\\s", "npm_config_node_gyp": "C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\node-gyp\\bin\\node-gyp.js", "npm_config_noproxy": "", "npm_config_npm_version": "10.7.0", "npm_config_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "NPM_CONFIG_USERCONFIG": "X:\\agent\\_work\\212\\npm\\52978.npmrc", "npm_config_user_agent": "npm/10.7.0 node/v20.15.0 win32 x64 workspaces/false ci/azure-pipelines", "npm_execpath": "C:\\Program Files\\nodejs\\node_modules\\npm\\bin\\npm-cli.js", "npm_lifecycle_event": "build", "npm_lifecycle_script": "vite build", "npm_node_execpath": "C:\\Program Files\\nodejs\\node.exe", "npm_package_json": "X:\\agent\\_work\\212\\s\\package.json", "npm_package_name": "mfecalendar", "npm_package_version": "0.0.0", "NPM_PREFIX_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-prefix.js", "NPM_PREFIX_NPM_CLI_JS": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\node_modules\\npm\\bin\\npm-cli.js", "NUMBER_OF_PROCESSORS": "4", "OS": "Windows_NT", "Path": "X:\\agent\\_work\\212\\s\\node_modules\\.bin;X:\\agent\\_work\\212\\node_modules\\.bin;X:\\agent\\_work\\node_modules\\.bin;X:\\agent\\node_modules\\.bin;X:\\node_modules\\.bin;C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\@npmcli\\run-script\\lib\\node-gyp-bin;X:\\agent\\externals\\git\\cmd;C:\\Program Files\\Microsoft\\jdk-17.0.9.8-hotspot\\bin;C:\\Program Files\\python3.12.2\\Scripts;C:\\Program Files\\python3.12.2;C:\\Program Files\\python3.12.1\\Scripts;C:\\Program Files\\python3.12.1;C:\\Program Files\\python3.12.0\\Scripts;C:\\Program Files\\python3.12.0;C:\\Program Files\\python3.11.4\\Scripts;C:\\Program Files\\python3.11.4;C:\\Program Files\\Python310\\Scripts\\;C:\\Program Files\\Python310\\;C:\\Program Files\\Python39\\Scripts\\;C:\\Program Files\\Python39\\;C:\\Program Files\\Python38\\Scripts\\;C:\\Program Files\\Python38\\;C:\\Windows\\system32;C:\\Windows;C:\\Windows\\System32\\Wbem;C:\\Windows\\System32\\WindowsPowerShell\\v1.0\\;C:\\Program Files\\Amazon\\cfn-bootstrap\\;C:\\Users\\paul.steele\\.dnx\\bin;C:\\Program Files\\Microsoft DNX\\Dnvm\\;C:\\Program Files\\Microsoft SQL Server\\120\\Tools\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\130\\Tools\\Binn\\;C:\\Program Files\\dotnet\\;C:\\Program Files\\Microsoft SQL Server\\Client SDK\\ODBC\\170\\Tools\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\110\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\120\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\130\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\140\\DTS\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\150\\Tools\\Binn\\;C:\\Program Files\\nodejs\\;C:\\Users\\tfs_service\\AppData\\Local\\Microsoft\\WindowsApps;C:\\Users\\tfs_service\\.dotnet\\tools", "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.PY;.PYW", "PIPELINE_WORKSPACE": "X:\\agent\\_work\\212", "PROCESSOR_ARCHITECTURE": "AMD64", "PROCESSOR_IDENTIFIER": "Intel64 Family 6 Model 85 Stepping 7, GenuineIntel", "PROCESSOR_LEVEL": "6", "PROCESSOR_REVISION": "5507", "ProgramData": "C:\\ProgramData", "ProgramFiles": "C:\\Program Files", "ProgramFiles(x86)": "C:\\Program Files (x86)", "ProgramW6432": "C:\\Program Files", "PROMPT": "$P$G", "PSModulePath": "%ProgramFiles%\\WindowsPowerShell\\Modules;C:\\Windows\\system32\\WindowsPowerShell\\v1.0\\Modules;C:\\Program Files (x86)\\AWS Tools\\PowerShell\\", "PUBLIC": "C:\\Users\\Public", "RESOURCES_TRIGGERINGALIAS": "", "RESOURCES_TRIGGERINGCATEGORY": "", "SONAR_SCANNER_OPTS": "-Dhttps.proxyHost=10.112.32.58 -Dhttps.proxyPort=3128 -Dhttp.proxyHost=10.112.32.58 -Dhttp.proxyPort=3128", "SYSTEM": "build", "SystemDrive": "C:", "SystemRoot": "C:\\Windows", "SYSTEM_ARTIFACTSDIRECTORY": "X:\\agent\\_work\\212\\a", "SYSTEM_COLLECTIONID": "d23f2e11-b837-4b0d-a26f-f4e9a2297abe", "SYSTEM_COLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_CULTURE": "en-US", "SYSTEM_DEBUG": "false", "SYSTEM_DEFAULTWORKINGDIRECTORY": "X:\\agent\\_work\\212\\s", "SYSTEM_DEFINITIONID": "367", "SYSTEM_DEFINITIONNAME": "MFE_Calendar", "SYSTEM_HOSTTYPE": "build", "SYSTEM_ISSCHEDULED": "False", "SYSTEM_JOBATTEMPT": "1", "SYSTEM_JOBDISPLAYNAME": "Agent job 1", "SYSTEM_JOBID": "275f1d19-1bd8-5591-b06b-07d489ea915a", "SYSTEM_JOBIDENTIFIER": "Job_1.__default", "SYSTEM_JOBNAME": "__default", "SYSTEM_JOBPARALLELISMTAG": "Private", "SYSTEM_JOBPOSITIONINPHASE": "1", "SYSTEM_JOBTIMEOUT": "60", "SYSTEM_PHASEATTEMPT": "1", "SYSTEM_PHASEDISPLAYNAME": "Agent job 1", "SYSTEM_PHASEID": "2f97f1d8-943c-5cda-8782-cbcebf2b3d67", "SYSTEM_PHASENAME": "Job_1", "SYSTEM_PIPELINESTARTTIME": "2024-09-11 10:22:39+01:00", "SYSTEM_PLANID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_PULLREQUEST_ISFORK": "False", "SYSTEM_SERVERTYPE": "OnPremises", "SYSTEM_STAGEATTEMPT": "1", "SYSTEM_STAGEDISPLAYNAME": "__default", "SYSTEM_STAGEID": "96ac2280-8cb4-5df5-99de-dd2da759617d", "SYSTEM_STAGENAME": "__default", "SYSTEM_TASKDEFINITIONSURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TASKDISPLAYNAME": "npm build", "SYSTEM_TASKINSTANCEID": "b4978d5e-5988-54a5-1480-26654484e930", "SYSTEM_TASKINSTANCENAME": "Npm2", "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMFOUNDATIONSERVERURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMPROJECT": "TeamProject", "SYSTEM_TEAMPROJECTID": "5003cdd3-40b1-4795-85cf-78cfc778579a", "SYSTEM_TIMELINEID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_TOTALJOBSINPHASE": "1", "SYSTEM_WORKFOLDER": "X:\\agent\\_work", "TASK_DISPLAYNAME": "npm build", "TEMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "TF_BUILD": "True", "TMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "USERDNSDOMAIN": "DEV.HOLIDAYHYPE.CO.UK", "USERDOMAIN": "DEV", "USERNAME": "tfs_service", "USERPROFILE": "C:\\Users\\tfs_service", "VS140COMNTOOLS": "C:\\Program Files (x86)\\Microsoft Visual Studio 14.0\\Common7\\Tools\\", "VSTS_PROCESS_LOOKUP_ID": "vsts_6ed8324e-e7f5-4a0d-a666-99ffc8f089ba", "windir": "C:\\Windows" }.NODE_ENV !== "production") && check(job))
            ;
          callWithErrorHandling(job, null, 14);
        }
      }
    } finally {
      flushIndex = 0;
      queue.length = 0;
      flushPostFlushCbs();
      isFlushing = false;
      currentFlushPromise = null;
      if (queue.length || pendingPostFlushCbs.length) {
        flushJobs();
      }
    }
  }
  function emit(instance, event, ...rawArgs) {
    if (instance.isUnmounted)
      return;
    const props = instance.vnode.props || EMPTY_OBJ;
    let args = rawArgs;
    const isModelListener2 = event.startsWith("update:");
    const modelArg = isModelListener2 && event.slice(7);
    if (modelArg && modelArg in props) {
      const modifiersKey = `${modelArg === "modelValue" ? "model" : modelArg}Modifiers`;
      const { number, trim } = props[modifiersKey] || EMPTY_OBJ;
      if (trim) {
        args = rawArgs.map((a) => isString(a) ? a.trim() : a);
      }
      if (number) {
        args = rawArgs.map(looseToNumber);
      }
    }
    let handlerName;
    let handler = props[handlerName = toHandlerKey(event)] || // also try camelCase event handler (#2249)
    props[handlerName = toHandlerKey(camelize(event))];
    if (!handler && isModelListener2) {
      handler = props[handlerName = toHandlerKey(hyphenate(event))];
    }
    if (handler) {
      callWithAsyncErrorHandling(
        handler,
        instance,
        6,
        args
      );
    }
    const onceHandler = props[handlerName + `Once`];
    if (onceHandler) {
      if (!instance.emitted) {
        instance.emitted = {};
      } else if (instance.emitted[handlerName]) {
        return;
      }
      instance.emitted[handlerName] = true;
      callWithAsyncErrorHandling(
        onceHandler,
        instance,
        6,
        args
      );
    }
  }
  function normalizeEmitsOptions(comp, appContext, asMixin = false) {
    const cache = appContext.emitsCache;
    const cached = cache.get(comp);
    if (cached !== void 0) {
      return cached;
    }
    const raw = comp.emits;
    let normalized = {};
    let hasExtends = false;
    if (!isFunction(comp)) {
      const extendEmits = (raw2) => {
        const normalizedFromExtend = normalizeEmitsOptions(raw2, appContext, true);
        if (normalizedFromExtend) {
          hasExtends = true;
          extend(normalized, normalizedFromExtend);
        }
      };
      if (!asMixin && appContext.mixins.length) {
        appContext.mixins.forEach(extendEmits);
      }
      if (comp.extends) {
        extendEmits(comp.extends);
      }
      if (comp.mixins) {
        comp.mixins.forEach(extendEmits);
      }
    }
    if (!raw && !hasExtends) {
      if (isObject(comp)) {
        cache.set(comp, null);
      }
      return null;
    }
    if (isArray(raw)) {
      raw.forEach((key) => normalized[key] = null);
    } else {
      extend(normalized, raw);
    }
    if (isObject(comp)) {
      cache.set(comp, normalized);
    }
    return normalized;
  }
  function isEmitListener(options, key) {
    if (!options || !isOn(key)) {
      return false;
    }
    key = key.slice(2).replace(/Once$/, "");
    return hasOwn(options, key[0].toLowerCase() + key.slice(1)) || hasOwn(options, hyphenate(key)) || hasOwn(options, key);
  }
  let currentRenderingInstance = null;
  let currentScopeId = null;
  function setCurrentRenderingInstance(instance) {
    const prev = currentRenderingInstance;
    currentRenderingInstance = instance;
    currentScopeId = instance && instance.type.__scopeId || null;
    return prev;
  }
  function withCtx(fn, ctx = currentRenderingInstance, isNonScopedSlot) {
    if (!ctx)
      return fn;
    if (fn._n) {
      return fn;
    }
    const renderFnWithContext = (...args) => {
      if (renderFnWithContext._d) {
        setBlockTracking(-1);
      }
      const prevInstance = setCurrentRenderingInstance(ctx);
      let res;
      try {
        res = fn(...args);
      } finally {
        setCurrentRenderingInstance(prevInstance);
        if (renderFnWithContext._d) {
          setBlockTracking(1);
        }
      }
      return res;
    };
    renderFnWithContext._n = true;
    renderFnWithContext._c = true;
    renderFnWithContext._d = true;
    return renderFnWithContext;
  }
  function markAttrsAccessed() {
  }
  function renderComponentRoot(instance) {
    const {
      type: Component,
      vnode,
      proxy,
      withProxy,
      props,
      propsOptions: [propsOptions],
      slots,
      attrs,
      emit: emit2,
      render: render2,
      renderCache,
      data,
      setupState,
      ctx,
      inheritAttrs
    } = instance;
    let result;
    let fallthroughAttrs;
    const prev = setCurrentRenderingInstance(instance);
    try {
      if (vnode.shapeFlag & 4) {
        const proxyToUse = withProxy || proxy;
        result = normalizeVNode(
          render2.call(
            proxyToUse,
            proxyToUse,
            renderCache,
            props,
            setupState,
            data,
            ctx
          )
        );
        fallthroughAttrs = attrs;
      } else {
        const render22 = Component;
        if (!!({ "agent.jobstatus": "Succeeded", "AGENT_BUILDDIRECTORY": "X:\\agent\\_work\\212", "AGENT_DISABLELOGPLUGIN_TESTFILEPUBLISHERPLUGIN": "true", "AGENT_DISABLELOGPLUGIN_TESTRESULTLOGPLUGIN": "true", "AGENT_HOMEDIRECTORY": "X:\\agent", "AGENT_ID": "8", "AGENT_JOBNAME": "Agent job 1", "AGENT_JOBSTATUS": "Succeeded", "AGENT_MACHINENAME": "TFSBUILD1", "AGENT_NAME": "TFSBUILD1-Agent", "AGENT_OS": "Windows_NT", "AGENT_OSARCHITECTURE": "X64", "AGENT_READONLYVARIABLES": "true", "AGENT_RETAINDEFAULTENCODING": "false", "AGENT_ROOTDIRECTORY": "X:\\agent\\_work", "AGENT_SERVEROMDIRECTORY": "X:\\agent\\externals\\vstsom", "AGENT_TEMPDIRECTORY": "X:\\agent\\_work\\_temp", "AGENT_TOOLSDIRECTORY": "X:\\agent\\_work\\_tool", "AGENT_VERSION": "2.181.2", "AGENT_WORKFOLDER": "X:\\agent\\_work", "ALLUSERSPROFILE": "C:\\ProgramData", "APPDATA": "C:\\Users\\tfs_service\\AppData\\Roaming", "AZURE_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "BUILD_ARTIFACTSTAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "BUILD_BINARIESDIRECTORY": "X:\\agent\\_work\\212\\b", "BUILD_BUILDID": "52978", "BUILD_BUILDNUMBER": "52978", "BUILD_BUILDURI": "vstfs:///Build/Build/52978", "BUILD_CONTAINERID": "113236", "BUILD_DEFINITIONNAME": "MFE_Calendar", "BUILD_DEFINITIONVERSION": "4", "BUILD_QUEUEDBY": "jake.salmon", "BUILD_QUEUEDBYID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_REASON": "Manual", "BUILD_REPOSITORY_CLEAN": "True", "BUILD_REPOSITORY_GIT_SUBMODULECHECKOUT": "False", "BUILD_REPOSITORY_ID": "ca089350-a60d-4fa9-8d03-a92b61d738bd", "BUILD_REPOSITORY_LOCALPATH": "X:\\agent\\_work\\212\\s", "BUILD_REPOSITORY_NAME": "MFE-Calendar", "BUILD_REPOSITORY_PROVIDER": "TfsGit", "BUILD_REPOSITORY_URI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/TeamProject/_git/MFE-Calendar", "BUILD_REQUESTEDFOR": "jake.salmon", "BUILD_REQUESTEDFOREMAIL": "Jake.Salmon@tui.co.uk", "BUILD_REQUESTEDFORID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_SOURCEBRANCH": "refs/heads/master", "BUILD_SOURCEBRANCHNAME": "master", "BUILD_SOURCESDIRECTORY": "X:\\agent\\_work\\212\\s", "BUILD_SOURCEVERSION": "8be35ec0af51f99c9106ca475e91dd61918f373c", "BUILD_SOURCEVERSIONAUTHOR": "jake.salmon", "BUILD_SOURCEVERSIONMESSAGE": "Merged PR 12789: small fix for margin issues on Holiday details\n\nsmall fix for margin issues on HD", "BUILD_STAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "COLOR": "0", "CommonProgramFiles": "C:\\Program Files\\Common Files", "CommonProgramFiles(x86)": "C:\\Program Files (x86)\\Common Files", "CommonProgramW6432": "C:\\Program Files\\Common Files", "COMMON_TESTRESULTSDIRECTORY": "X:\\agent\\_work\\212\\TestResults", "COMPUTERNAME": "TFSBUILD1", "ComSpec": "C:\\Windows\\system32\\cmd.exe", "EDITOR": "C:\\Windows\\notepad.exe", "ENDPOINT_URL_SYSTEMVSSCONNECTION": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "GIT_TERMINAL_PROMPT": "0", "HOME": "C:\\Users\\tfs_service", "INIT_CWD": "X:\\agent\\_work\\212\\s", "INPUT_CUSTOMENDPOINT": "", "INPUT_CUSTOMFEED": "", "INPUT_PUBLISHENDPOINT": "", "INPUT_PUBLISHFEED": "", "LOCALAPPDATA": "C:\\Users\\tfs_service\\AppData\\Local", "MSDEPLOY_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "NODE": "C:\\Program Files\\nodejs\\node.exe", "NODE_ENV": "production", "NODE_EXE": "C:\\Program Files\\nodejs\\\\node.exe", "NODE_EXTRA_CA_CERTS": "C:\\Build\\node-extra-cert\\ca.crt", "NO_PROXY": "tfs.holidayhype.co.uk, *.holidayhype.co.uk, 10.3.*, 10.1.*, 10.0.*, localhost", "NPM_CLI_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-cli.js", "npm_command": "run-script", "npm_config_cache": "C:\\Users\\tfs_service\\AppData\\Local\\npm-cache", "npm_config_globalconfig": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\etc\\npmrc", "npm_config_global_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "npm_config_init_module": "C:\\Users\\tfs_service\\.npm-init.js", "npm_config_local_prefix": "X:\\agent\\_work\\212\\s", "npm_config_node_gyp": "C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\node-gyp\\bin\\node-gyp.js", "npm_config_noproxy": "", "npm_config_npm_version": "10.7.0", "npm_config_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "NPM_CONFIG_USERCONFIG": "X:\\agent\\_work\\212\\npm\\52978.npmrc", "npm_config_user_agent": "npm/10.7.0 node/v20.15.0 win32 x64 workspaces/false ci/azure-pipelines", "npm_execpath": "C:\\Program Files\\nodejs\\node_modules\\npm\\bin\\npm-cli.js", "npm_lifecycle_event": "build", "npm_lifecycle_script": "vite build", "npm_node_execpath": "C:\\Program Files\\nodejs\\node.exe", "npm_package_json": "X:\\agent\\_work\\212\\s\\package.json", "npm_package_name": "mfecalendar", "npm_package_version": "0.0.0", "NPM_PREFIX_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-prefix.js", "NPM_PREFIX_NPM_CLI_JS": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\node_modules\\npm\\bin\\npm-cli.js", "NUMBER_OF_PROCESSORS": "4", "OS": "Windows_NT", "Path": "X:\\agent\\_work\\212\\s\\node_modules\\.bin;X:\\agent\\_work\\212\\node_modules\\.bin;X:\\agent\\_work\\node_modules\\.bin;X:\\agent\\node_modules\\.bin;X:\\node_modules\\.bin;C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\@npmcli\\run-script\\lib\\node-gyp-bin;X:\\agent\\externals\\git\\cmd;C:\\Program Files\\Microsoft\\jdk-17.0.9.8-hotspot\\bin;C:\\Program Files\\python3.12.2\\Scripts;C:\\Program Files\\python3.12.2;C:\\Program Files\\python3.12.1\\Scripts;C:\\Program Files\\python3.12.1;C:\\Program Files\\python3.12.0\\Scripts;C:\\Program Files\\python3.12.0;C:\\Program Files\\python3.11.4\\Scripts;C:\\Program Files\\python3.11.4;C:\\Program Files\\Python310\\Scripts\\;C:\\Program Files\\Python310\\;C:\\Program Files\\Python39\\Scripts\\;C:\\Program Files\\Python39\\;C:\\Program Files\\Python38\\Scripts\\;C:\\Program Files\\Python38\\;C:\\Windows\\system32;C:\\Windows;C:\\Windows\\System32\\Wbem;C:\\Windows\\System32\\WindowsPowerShell\\v1.0\\;C:\\Program Files\\Amazon\\cfn-bootstrap\\;C:\\Users\\paul.steele\\.dnx\\bin;C:\\Program Files\\Microsoft DNX\\Dnvm\\;C:\\Program Files\\Microsoft SQL Server\\120\\Tools\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\130\\Tools\\Binn\\;C:\\Program Files\\dotnet\\;C:\\Program Files\\Microsoft SQL Server\\Client SDK\\ODBC\\170\\Tools\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\110\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\120\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\130\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\140\\DTS\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\150\\Tools\\Binn\\;C:\\Program Files\\nodejs\\;C:\\Users\\tfs_service\\AppData\\Local\\Microsoft\\WindowsApps;C:\\Users\\tfs_service\\.dotnet\\tools", "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.PY;.PYW", "PIPELINE_WORKSPACE": "X:\\agent\\_work\\212", "PROCESSOR_ARCHITECTURE": "AMD64", "PROCESSOR_IDENTIFIER": "Intel64 Family 6 Model 85 Stepping 7, GenuineIntel", "PROCESSOR_LEVEL": "6", "PROCESSOR_REVISION": "5507", "ProgramData": "C:\\ProgramData", "ProgramFiles": "C:\\Program Files", "ProgramFiles(x86)": "C:\\Program Files (x86)", "ProgramW6432": "C:\\Program Files", "PROMPT": "$P$G", "PSModulePath": "%ProgramFiles%\\WindowsPowerShell\\Modules;C:\\Windows\\system32\\WindowsPowerShell\\v1.0\\Modules;C:\\Program Files (x86)\\AWS Tools\\PowerShell\\", "PUBLIC": "C:\\Users\\Public", "RESOURCES_TRIGGERINGALIAS": "", "RESOURCES_TRIGGERINGCATEGORY": "", "SONAR_SCANNER_OPTS": "-Dhttps.proxyHost=10.112.32.58 -Dhttps.proxyPort=3128 -Dhttp.proxyHost=10.112.32.58 -Dhttp.proxyPort=3128", "SYSTEM": "build", "SystemDrive": "C:", "SystemRoot": "C:\\Windows", "SYSTEM_ARTIFACTSDIRECTORY": "X:\\agent\\_work\\212\\a", "SYSTEM_COLLECTIONID": "d23f2e11-b837-4b0d-a26f-f4e9a2297abe", "SYSTEM_COLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_CULTURE": "en-US", "SYSTEM_DEBUG": "false", "SYSTEM_DEFAULTWORKINGDIRECTORY": "X:\\agent\\_work\\212\\s", "SYSTEM_DEFINITIONID": "367", "SYSTEM_DEFINITIONNAME": "MFE_Calendar", "SYSTEM_HOSTTYPE": "build", "SYSTEM_ISSCHEDULED": "False", "SYSTEM_JOBATTEMPT": "1", "SYSTEM_JOBDISPLAYNAME": "Agent job 1", "SYSTEM_JOBID": "275f1d19-1bd8-5591-b06b-07d489ea915a", "SYSTEM_JOBIDENTIFIER": "Job_1.__default", "SYSTEM_JOBNAME": "__default", "SYSTEM_JOBPARALLELISMTAG": "Private", "SYSTEM_JOBPOSITIONINPHASE": "1", "SYSTEM_JOBTIMEOUT": "60", "SYSTEM_PHASEATTEMPT": "1", "SYSTEM_PHASEDISPLAYNAME": "Agent job 1", "SYSTEM_PHASEID": "2f97f1d8-943c-5cda-8782-cbcebf2b3d67", "SYSTEM_PHASENAME": "Job_1", "SYSTEM_PIPELINESTARTTIME": "2024-09-11 10:22:39+01:00", "SYSTEM_PLANID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_PULLREQUEST_ISFORK": "False", "SYSTEM_SERVERTYPE": "OnPremises", "SYSTEM_STAGEATTEMPT": "1", "SYSTEM_STAGEDISPLAYNAME": "__default", "SYSTEM_STAGEID": "96ac2280-8cb4-5df5-99de-dd2da759617d", "SYSTEM_STAGENAME": "__default", "SYSTEM_TASKDEFINITIONSURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TASKDISPLAYNAME": "npm build", "SYSTEM_TASKINSTANCEID": "b4978d5e-5988-54a5-1480-26654484e930", "SYSTEM_TASKINSTANCENAME": "Npm2", "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMFOUNDATIONSERVERURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMPROJECT": "TeamProject", "SYSTEM_TEAMPROJECTID": "5003cdd3-40b1-4795-85cf-78cfc778579a", "SYSTEM_TIMELINEID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_TOTALJOBSINPHASE": "1", "SYSTEM_WORKFOLDER": "X:\\agent\\_work", "TASK_DISPLAYNAME": "npm build", "TEMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "TF_BUILD": "True", "TMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "USERDNSDOMAIN": "DEV.HOLIDAYHYPE.CO.UK", "USERDOMAIN": "DEV", "USERNAME": "tfs_service", "USERPROFILE": "C:\\Users\\tfs_service", "VS140COMNTOOLS": "C:\\Program Files (x86)\\Microsoft Visual Studio 14.0\\Common7\\Tools\\", "VSTS_PROCESS_LOOKUP_ID": "vsts_6ed8324e-e7f5-4a0d-a666-99ffc8f089ba", "windir": "C:\\Windows" }.NODE_ENV !== "production") && attrs === props)
          ;
        result = normalizeVNode(
          render22.length > 1 ? render22(
            props,
            !!({ "agent.jobstatus": "Succeeded", "AGENT_BUILDDIRECTORY": "X:\\agent\\_work\\212", "AGENT_DISABLELOGPLUGIN_TESTFILEPUBLISHERPLUGIN": "true", "AGENT_DISABLELOGPLUGIN_TESTRESULTLOGPLUGIN": "true", "AGENT_HOMEDIRECTORY": "X:\\agent", "AGENT_ID": "8", "AGENT_JOBNAME": "Agent job 1", "AGENT_JOBSTATUS": "Succeeded", "AGENT_MACHINENAME": "TFSBUILD1", "AGENT_NAME": "TFSBUILD1-Agent", "AGENT_OS": "Windows_NT", "AGENT_OSARCHITECTURE": "X64", "AGENT_READONLYVARIABLES": "true", "AGENT_RETAINDEFAULTENCODING": "false", "AGENT_ROOTDIRECTORY": "X:\\agent\\_work", "AGENT_SERVEROMDIRECTORY": "X:\\agent\\externals\\vstsom", "AGENT_TEMPDIRECTORY": "X:\\agent\\_work\\_temp", "AGENT_TOOLSDIRECTORY": "X:\\agent\\_work\\_tool", "AGENT_VERSION": "2.181.2", "AGENT_WORKFOLDER": "X:\\agent\\_work", "ALLUSERSPROFILE": "C:\\ProgramData", "APPDATA": "C:\\Users\\tfs_service\\AppData\\Roaming", "AZURE_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "BUILD_ARTIFACTSTAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "BUILD_BINARIESDIRECTORY": "X:\\agent\\_work\\212\\b", "BUILD_BUILDID": "52978", "BUILD_BUILDNUMBER": "52978", "BUILD_BUILDURI": "vstfs:///Build/Build/52978", "BUILD_CONTAINERID": "113236", "BUILD_DEFINITIONNAME": "MFE_Calendar", "BUILD_DEFINITIONVERSION": "4", "BUILD_QUEUEDBY": "jake.salmon", "BUILD_QUEUEDBYID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_REASON": "Manual", "BUILD_REPOSITORY_CLEAN": "True", "BUILD_REPOSITORY_GIT_SUBMODULECHECKOUT": "False", "BUILD_REPOSITORY_ID": "ca089350-a60d-4fa9-8d03-a92b61d738bd", "BUILD_REPOSITORY_LOCALPATH": "X:\\agent\\_work\\212\\s", "BUILD_REPOSITORY_NAME": "MFE-Calendar", "BUILD_REPOSITORY_PROVIDER": "TfsGit", "BUILD_REPOSITORY_URI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/TeamProject/_git/MFE-Calendar", "BUILD_REQUESTEDFOR": "jake.salmon", "BUILD_REQUESTEDFOREMAIL": "Jake.Salmon@tui.co.uk", "BUILD_REQUESTEDFORID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_SOURCEBRANCH": "refs/heads/master", "BUILD_SOURCEBRANCHNAME": "master", "BUILD_SOURCESDIRECTORY": "X:\\agent\\_work\\212\\s", "BUILD_SOURCEVERSION": "8be35ec0af51f99c9106ca475e91dd61918f373c", "BUILD_SOURCEVERSIONAUTHOR": "jake.salmon", "BUILD_SOURCEVERSIONMESSAGE": "Merged PR 12789: small fix for margin issues on Holiday details\n\nsmall fix for margin issues on HD", "BUILD_STAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "COLOR": "0", "CommonProgramFiles": "C:\\Program Files\\Common Files", "CommonProgramFiles(x86)": "C:\\Program Files (x86)\\Common Files", "CommonProgramW6432": "C:\\Program Files\\Common Files", "COMMON_TESTRESULTSDIRECTORY": "X:\\agent\\_work\\212\\TestResults", "COMPUTERNAME": "TFSBUILD1", "ComSpec": "C:\\Windows\\system32\\cmd.exe", "EDITOR": "C:\\Windows\\notepad.exe", "ENDPOINT_URL_SYSTEMVSSCONNECTION": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "GIT_TERMINAL_PROMPT": "0", "HOME": "C:\\Users\\tfs_service", "INIT_CWD": "X:\\agent\\_work\\212\\s", "INPUT_CUSTOMENDPOINT": "", "INPUT_CUSTOMFEED": "", "INPUT_PUBLISHENDPOINT": "", "INPUT_PUBLISHFEED": "", "LOCALAPPDATA": "C:\\Users\\tfs_service\\AppData\\Local", "MSDEPLOY_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "NODE": "C:\\Program Files\\nodejs\\node.exe", "NODE_ENV": "production", "NODE_EXE": "C:\\Program Files\\nodejs\\\\node.exe", "NODE_EXTRA_CA_CERTS": "C:\\Build\\node-extra-cert\\ca.crt", "NO_PROXY": "tfs.holidayhype.co.uk, *.holidayhype.co.uk, 10.3.*, 10.1.*, 10.0.*, localhost", "NPM_CLI_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-cli.js", "npm_command": "run-script", "npm_config_cache": "C:\\Users\\tfs_service\\AppData\\Local\\npm-cache", "npm_config_globalconfig": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\etc\\npmrc", "npm_config_global_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "npm_config_init_module": "C:\\Users\\tfs_service\\.npm-init.js", "npm_config_local_prefix": "X:\\agent\\_work\\212\\s", "npm_config_node_gyp": "C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\node-gyp\\bin\\node-gyp.js", "npm_config_noproxy": "", "npm_config_npm_version": "10.7.0", "npm_config_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "NPM_CONFIG_USERCONFIG": "X:\\agent\\_work\\212\\npm\\52978.npmrc", "npm_config_user_agent": "npm/10.7.0 node/v20.15.0 win32 x64 workspaces/false ci/azure-pipelines", "npm_execpath": "C:\\Program Files\\nodejs\\node_modules\\npm\\bin\\npm-cli.js", "npm_lifecycle_event": "build", "npm_lifecycle_script": "vite build", "npm_node_execpath": "C:\\Program Files\\nodejs\\node.exe", "npm_package_json": "X:\\agent\\_work\\212\\s\\package.json", "npm_package_name": "mfecalendar", "npm_package_version": "0.0.0", "NPM_PREFIX_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-prefix.js", "NPM_PREFIX_NPM_CLI_JS": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\node_modules\\npm\\bin\\npm-cli.js", "NUMBER_OF_PROCESSORS": "4", "OS": "Windows_NT", "Path": "X:\\agent\\_work\\212\\s\\node_modules\\.bin;X:\\agent\\_work\\212\\node_modules\\.bin;X:\\agent\\_work\\node_modules\\.bin;X:\\agent\\node_modules\\.bin;X:\\node_modules\\.bin;C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\@npmcli\\run-script\\lib\\node-gyp-bin;X:\\agent\\externals\\git\\cmd;C:\\Program Files\\Microsoft\\jdk-17.0.9.8-hotspot\\bin;C:\\Program Files\\python3.12.2\\Scripts;C:\\Program Files\\python3.12.2;C:\\Program Files\\python3.12.1\\Scripts;C:\\Program Files\\python3.12.1;C:\\Program Files\\python3.12.0\\Scripts;C:\\Program Files\\python3.12.0;C:\\Program Files\\python3.11.4\\Scripts;C:\\Program Files\\python3.11.4;C:\\Program Files\\Python310\\Scripts\\;C:\\Program Files\\Python310\\;C:\\Program Files\\Python39\\Scripts\\;C:\\Program Files\\Python39\\;C:\\Program Files\\Python38\\Scripts\\;C:\\Program Files\\Python38\\;C:\\Windows\\system32;C:\\Windows;C:\\Windows\\System32\\Wbem;C:\\Windows\\System32\\WindowsPowerShell\\v1.0\\;C:\\Program Files\\Amazon\\cfn-bootstrap\\;C:\\Users\\paul.steele\\.dnx\\bin;C:\\Program Files\\Microsoft DNX\\Dnvm\\;C:\\Program Files\\Microsoft SQL Server\\120\\Tools\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\130\\Tools\\Binn\\;C:\\Program Files\\dotnet\\;C:\\Program Files\\Microsoft SQL Server\\Client SDK\\ODBC\\170\\Tools\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\110\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\120\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\130\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\140\\DTS\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\150\\Tools\\Binn\\;C:\\Program Files\\nodejs\\;C:\\Users\\tfs_service\\AppData\\Local\\Microsoft\\WindowsApps;C:\\Users\\tfs_service\\.dotnet\\tools", "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.PY;.PYW", "PIPELINE_WORKSPACE": "X:\\agent\\_work\\212", "PROCESSOR_ARCHITECTURE": "AMD64", "PROCESSOR_IDENTIFIER": "Intel64 Family 6 Model 85 Stepping 7, GenuineIntel", "PROCESSOR_LEVEL": "6", "PROCESSOR_REVISION": "5507", "ProgramData": "C:\\ProgramData", "ProgramFiles": "C:\\Program Files", "ProgramFiles(x86)": "C:\\Program Files (x86)", "ProgramW6432": "C:\\Program Files", "PROMPT": "$P$G", "PSModulePath": "%ProgramFiles%\\WindowsPowerShell\\Modules;C:\\Windows\\system32\\WindowsPowerShell\\v1.0\\Modules;C:\\Program Files (x86)\\AWS Tools\\PowerShell\\", "PUBLIC": "C:\\Users\\Public", "RESOURCES_TRIGGERINGALIAS": "", "RESOURCES_TRIGGERINGCATEGORY": "", "SONAR_SCANNER_OPTS": "-Dhttps.proxyHost=10.112.32.58 -Dhttps.proxyPort=3128 -Dhttp.proxyHost=10.112.32.58 -Dhttp.proxyPort=3128", "SYSTEM": "build", "SystemDrive": "C:", "SystemRoot": "C:\\Windows", "SYSTEM_ARTIFACTSDIRECTORY": "X:\\agent\\_work\\212\\a", "SYSTEM_COLLECTIONID": "d23f2e11-b837-4b0d-a26f-f4e9a2297abe", "SYSTEM_COLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_CULTURE": "en-US", "SYSTEM_DEBUG": "false", "SYSTEM_DEFAULTWORKINGDIRECTORY": "X:\\agent\\_work\\212\\s", "SYSTEM_DEFINITIONID": "367", "SYSTEM_DEFINITIONNAME": "MFE_Calendar", "SYSTEM_HOSTTYPE": "build", "SYSTEM_ISSCHEDULED": "False", "SYSTEM_JOBATTEMPT": "1", "SYSTEM_JOBDISPLAYNAME": "Agent job 1", "SYSTEM_JOBID": "275f1d19-1bd8-5591-b06b-07d489ea915a", "SYSTEM_JOBIDENTIFIER": "Job_1.__default", "SYSTEM_JOBNAME": "__default", "SYSTEM_JOBPARALLELISMTAG": "Private", "SYSTEM_JOBPOSITIONINPHASE": "1", "SYSTEM_JOBTIMEOUT": "60", "SYSTEM_PHASEATTEMPT": "1", "SYSTEM_PHASEDISPLAYNAME": "Agent job 1", "SYSTEM_PHASEID": "2f97f1d8-943c-5cda-8782-cbcebf2b3d67", "SYSTEM_PHASENAME": "Job_1", "SYSTEM_PIPELINESTARTTIME": "2024-09-11 10:22:39+01:00", "SYSTEM_PLANID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_PULLREQUEST_ISFORK": "False", "SYSTEM_SERVERTYPE": "OnPremises", "SYSTEM_STAGEATTEMPT": "1", "SYSTEM_STAGEDISPLAYNAME": "__default", "SYSTEM_STAGEID": "96ac2280-8cb4-5df5-99de-dd2da759617d", "SYSTEM_STAGENAME": "__default", "SYSTEM_TASKDEFINITIONSURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TASKDISPLAYNAME": "npm build", "SYSTEM_TASKINSTANCEID": "b4978d5e-5988-54a5-1480-26654484e930", "SYSTEM_TASKINSTANCENAME": "Npm2", "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMFOUNDATIONSERVERURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMPROJECT": "TeamProject", "SYSTEM_TEAMPROJECTID": "5003cdd3-40b1-4795-85cf-78cfc778579a", "SYSTEM_TIMELINEID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_TOTALJOBSINPHASE": "1", "SYSTEM_WORKFOLDER": "X:\\agent\\_work", "TASK_DISPLAYNAME": "npm build", "TEMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "TF_BUILD": "True", "TMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "USERDNSDOMAIN": "DEV.HOLIDAYHYPE.CO.UK", "USERDOMAIN": "DEV", "USERNAME": "tfs_service", "USERPROFILE": "C:\\Users\\tfs_service", "VS140COMNTOOLS": "C:\\Program Files (x86)\\Microsoft Visual Studio 14.0\\Common7\\Tools\\", "VSTS_PROCESS_LOOKUP_ID": "vsts_6ed8324e-e7f5-4a0d-a666-99ffc8f089ba", "windir": "C:\\Windows" }.NODE_ENV !== "production") ? {
              get attrs() {
                markAttrsAccessed();
                return attrs;
              },
              slots,
              emit: emit2
            } : { attrs, slots, emit: emit2 }
          ) : render22(
            props,
            null
            /* we know it doesn't need it */
          )
        );
        fallthroughAttrs = Component.props ? attrs : getFunctionalFallthrough(attrs);
      }
    } catch (err) {
      blockStack.length = 0;
      handleError(err, instance, 1);
      result = createVNode(Comment);
    }
    let root = result;
    if (fallthroughAttrs && inheritAttrs !== false) {
      const keys = Object.keys(fallthroughAttrs);
      const { shapeFlag } = root;
      if (keys.length) {
        if (shapeFlag & (1 | 6)) {
          if (propsOptions && keys.some(isModelListener)) {
            fallthroughAttrs = filterModelListeners(
              fallthroughAttrs,
              propsOptions
            );
          }
          root = cloneVNode(root, fallthroughAttrs);
        }
      }
    }
    if (vnode.dirs) {
      root = cloneVNode(root);
      root.dirs = root.dirs ? root.dirs.concat(vnode.dirs) : vnode.dirs;
    }
    if (vnode.transition) {
      root.transition = vnode.transition;
    }
    {
      result = root;
    }
    setCurrentRenderingInstance(prev);
    return result;
  }
  const getFunctionalFallthrough = (attrs) => {
    let res;
    for (const key in attrs) {
      if (key === "class" || key === "style" || isOn(key)) {
        (res || (res = {}))[key] = attrs[key];
      }
    }
    return res;
  };
  const filterModelListeners = (attrs, props) => {
    const res = {};
    for (const key in attrs) {
      if (!isModelListener(key) || !(key.slice(9) in props)) {
        res[key] = attrs[key];
      }
    }
    return res;
  };
  function shouldUpdateComponent(prevVNode, nextVNode, optimized) {
    const { props: prevProps, children: prevChildren, component } = prevVNode;
    const { props: nextProps, children: nextChildren, patchFlag } = nextVNode;
    const emits = component.emitsOptions;
    if (nextVNode.dirs || nextVNode.transition) {
      return true;
    }
    if (optimized && patchFlag >= 0) {
      if (patchFlag & 1024) {
        return true;
      }
      if (patchFlag & 16) {
        if (!prevProps) {
          return !!nextProps;
        }
        return hasPropsChanged(prevProps, nextProps, emits);
      } else if (patchFlag & 8) {
        const dynamicProps = nextVNode.dynamicProps;
        for (let i = 0; i < dynamicProps.length; i++) {
          const key = dynamicProps[i];
          if (nextProps[key] !== prevProps[key] && !isEmitListener(emits, key)) {
            return true;
          }
        }
      }
    } else {
      if (prevChildren || nextChildren) {
        if (!nextChildren || !nextChildren.$stable) {
          return true;
        }
      }
      if (prevProps === nextProps) {
        return false;
      }
      if (!prevProps) {
        return !!nextProps;
      }
      if (!nextProps) {
        return true;
      }
      return hasPropsChanged(prevProps, nextProps, emits);
    }
    return false;
  }
  function hasPropsChanged(prevProps, nextProps, emitsOptions) {
    const nextKeys = Object.keys(nextProps);
    if (nextKeys.length !== Object.keys(prevProps).length) {
      return true;
    }
    for (let i = 0; i < nextKeys.length; i++) {
      const key = nextKeys[i];
      if (nextProps[key] !== prevProps[key] && !isEmitListener(emitsOptions, key)) {
        return true;
      }
    }
    return false;
  }
  function updateHOCHostEl({ vnode, parent }, el) {
    while (parent && parent.subTree === vnode) {
      (vnode = parent.vnode).el = el;
      parent = parent.parent;
    }
  }
  const isSuspense = (type) => type.__isSuspense;
  function queueEffectWithSuspense(fn, suspense) {
    if (suspense && suspense.pendingBranch) {
      if (isArray(fn)) {
        suspense.effects.push(...fn);
      } else {
        suspense.effects.push(fn);
      }
    } else {
      queuePostFlushCb(fn);
    }
  }
  const INITIAL_WATCHER_VALUE = {};
  function watch(source, cb, options) {
    return doWatch(source, cb, options);
  }
  function doWatch(source, cb, { immediate, deep, flush, onTrack, onTrigger } = EMPTY_OBJ) {
    var _a;
    const instance = getCurrentScope() === ((_a = currentInstance) == null ? void 0 : _a.scope) ? currentInstance : null;
    let getter;
    let forceTrigger = false;
    let isMultiSource = false;
    if (isRef(source)) {
      getter = () => source.value;
      forceTrigger = isShallow(source);
    } else if (isReactive(source)) {
      getter = () => source;
      deep = true;
    } else if (isArray(source)) {
      isMultiSource = true;
      forceTrigger = source.some((s) => isReactive(s) || isShallow(s));
      getter = () => source.map((s) => {
        if (isRef(s)) {
          return s.value;
        } else if (isReactive(s)) {
          return traverse(s);
        } else if (isFunction(s)) {
          return callWithErrorHandling(s, instance, 2);
        } else
          ;
      });
    } else if (isFunction(source)) {
      if (cb) {
        getter = () => callWithErrorHandling(source, instance, 2);
      } else {
        getter = () => {
          if (instance && instance.isUnmounted) {
            return;
          }
          if (cleanup) {
            cleanup();
          }
          return callWithAsyncErrorHandling(
            source,
            instance,
            3,
            [onCleanup]
          );
        };
      }
    } else {
      getter = NOOP;
    }
    if (cb && deep) {
      const baseGetter = getter;
      getter = () => traverse(baseGetter());
    }
    let cleanup;
    let onCleanup = (fn) => {
      cleanup = effect.onStop = () => {
        callWithErrorHandling(fn, instance, 4);
      };
    };
    let ssrCleanup;
    if (isInSSRComponentSetup) {
      onCleanup = NOOP;
      if (!cb) {
        getter();
      } else if (immediate) {
        callWithAsyncErrorHandling(cb, instance, 3, [
          getter(),
          isMultiSource ? [] : void 0,
          onCleanup
        ]);
      }
      if (flush === "sync") {
        const ctx = useSSRContext();
        ssrCleanup = ctx.__watcherHandles || (ctx.__watcherHandles = []);
      } else {
        return NOOP;
      }
    }
    let oldValue = isMultiSource ? new Array(source.length).fill(INITIAL_WATCHER_VALUE) : INITIAL_WATCHER_VALUE;
    const job = () => {
      if (!effect.active) {
        return;
      }
      if (cb) {
        const newValue = effect.run();
        if (deep || forceTrigger || (isMultiSource ? newValue.some((v, i) => hasChanged(v, oldValue[i])) : hasChanged(newValue, oldValue)) || false) {
          if (cleanup) {
            cleanup();
          }
          callWithAsyncErrorHandling(cb, instance, 3, [
            newValue,
            // pass undefined as the old value when it's changed for the first time
            oldValue === INITIAL_WATCHER_VALUE ? void 0 : isMultiSource && oldValue[0] === INITIAL_WATCHER_VALUE ? [] : oldValue,
            onCleanup
          ]);
          oldValue = newValue;
        }
      } else {
        effect.run();
      }
    };
    job.allowRecurse = !!cb;
    let scheduler;
    if (flush === "sync") {
      scheduler = job;
    } else if (flush === "post") {
      scheduler = () => queuePostRenderEffect(job, instance && instance.suspense);
    } else {
      job.pre = true;
      if (instance)
        job.id = instance.uid;
      scheduler = () => queueJob(job);
    }
    const effect = new ReactiveEffect(getter, scheduler);
    if (cb) {
      if (immediate) {
        job();
      } else {
        oldValue = effect.run();
      }
    } else if (flush === "post") {
      queuePostRenderEffect(
        effect.run.bind(effect),
        instance && instance.suspense
      );
    } else {
      effect.run();
    }
    const unwatch = () => {
      effect.stop();
      if (instance && instance.scope) {
        remove(instance.scope.effects, effect);
      }
    };
    if (ssrCleanup)
      ssrCleanup.push(unwatch);
    return unwatch;
  }
  function instanceWatch(source, value, options) {
    const publicThis = this.proxy;
    const getter = isString(source) ? source.includes(".") ? createPathGetter(publicThis, source) : () => publicThis[source] : source.bind(publicThis, publicThis);
    let cb;
    if (isFunction(value)) {
      cb = value;
    } else {
      cb = value.handler;
      options = value;
    }
    const cur = currentInstance;
    setCurrentInstance(this);
    const res = doWatch(getter, cb.bind(publicThis), options);
    if (cur) {
      setCurrentInstance(cur);
    } else {
      unsetCurrentInstance();
    }
    return res;
  }
  function createPathGetter(ctx, path) {
    const segments = path.split(".");
    return () => {
      let cur = ctx;
      for (let i = 0; i < segments.length && cur; i++) {
        cur = cur[segments[i]];
      }
      return cur;
    };
  }
  function traverse(value, seen) {
    if (!isObject(value) || value["__v_skip"]) {
      return value;
    }
    seen = seen || /* @__PURE__ */ new Set();
    if (seen.has(value)) {
      return value;
    }
    seen.add(value);
    if (isRef(value)) {
      traverse(value.value, seen);
    } else if (isArray(value)) {
      for (let i = 0; i < value.length; i++) {
        traverse(value[i], seen);
      }
    } else if (isSet(value) || isMap(value)) {
      value.forEach((v) => {
        traverse(v, seen);
      });
    } else if (isPlainObject(value)) {
      for (const key in value) {
        traverse(value[key], seen);
      }
    }
    return value;
  }
  function withDirectives(vnode, directives) {
    const internalInstance = currentRenderingInstance;
    if (internalInstance === null) {
      return vnode;
    }
    const instance = getExposeProxy(internalInstance) || internalInstance.proxy;
    const bindings = vnode.dirs || (vnode.dirs = []);
    for (let i = 0; i < directives.length; i++) {
      let [dir, value, arg, modifiers = EMPTY_OBJ] = directives[i];
      if (dir) {
        if (isFunction(dir)) {
          dir = {
            mounted: dir,
            updated: dir
          };
        }
        if (dir.deep) {
          traverse(value);
        }
        bindings.push({
          dir,
          instance,
          value,
          oldValue: void 0,
          arg,
          modifiers
        });
      }
    }
    return vnode;
  }
  function invokeDirectiveHook(vnode, prevVNode, instance, name) {
    const bindings = vnode.dirs;
    const oldBindings = prevVNode && prevVNode.dirs;
    for (let i = 0; i < bindings.length; i++) {
      const binding = bindings[i];
      if (oldBindings) {
        binding.oldValue = oldBindings[i].value;
      }
      let hook = binding.dir[name];
      if (hook) {
        pauseTracking();
        callWithAsyncErrorHandling(hook, instance, 8, [
          vnode.el,
          binding,
          vnode,
          prevVNode
        ]);
        resetTracking();
      }
    }
  }
  /*! #__NO_SIDE_EFFECTS__ */
  // @__NO_SIDE_EFFECTS__
  function defineComponent(options, extraOptions) {
    return isFunction(options) ? (
      // #8326: extend call and options.name access are considered side-effects
      // by Rollup, so we have to wrap it in a pure-annotated IIFE.
      /* @__PURE__ */ (() => extend({ name: options.name }, extraOptions, { setup: options }))()
    ) : options;
  }
  const isAsyncWrapper = (i) => !!i.type.__asyncLoader;
  const isKeepAlive = (vnode) => vnode.type.__isKeepAlive;
  function onActivated(hook, target) {
    registerKeepAliveHook(hook, "a", target);
  }
  function onDeactivated(hook, target) {
    registerKeepAliveHook(hook, "da", target);
  }
  function registerKeepAliveHook(hook, type, target = currentInstance) {
    const wrappedHook = hook.__wdc || (hook.__wdc = () => {
      let current = target;
      while (current) {
        if (current.isDeactivated) {
          return;
        }
        current = current.parent;
      }
      return hook();
    });
    injectHook(type, wrappedHook, target);
    if (target) {
      let current = target.parent;
      while (current && current.parent) {
        if (isKeepAlive(current.parent.vnode)) {
          injectToKeepAliveRoot(wrappedHook, type, target, current);
        }
        current = current.parent;
      }
    }
  }
  function injectToKeepAliveRoot(hook, type, target, keepAliveRoot) {
    const injected = injectHook(
      type,
      hook,
      keepAliveRoot,
      true
      /* prepend */
    );
    onUnmounted(() => {
      remove(keepAliveRoot[type], injected);
    }, target);
  }
  function injectHook(type, hook, target = currentInstance, prepend = false) {
    if (target) {
      const hooks = target[type] || (target[type] = []);
      const wrappedHook = hook.__weh || (hook.__weh = (...args) => {
        if (target.isUnmounted) {
          return;
        }
        pauseTracking();
        setCurrentInstance(target);
        const res = callWithAsyncErrorHandling(hook, target, type, args);
        unsetCurrentInstance();
        resetTracking();
        return res;
      });
      if (prepend) {
        hooks.unshift(wrappedHook);
      } else {
        hooks.push(wrappedHook);
      }
      return wrappedHook;
    }
  }
  const createHook = (lifecycle) => (hook, target = currentInstance) => (
    // post-create lifecycle registrations are noops during SSR (except for serverPrefetch)
    (!isInSSRComponentSetup || lifecycle === "sp") && injectHook(lifecycle, (...args) => hook(...args), target)
  );
  const onBeforeMount = createHook("bm");
  const onMounted = createHook("m");
  const onBeforeUpdate = createHook("bu");
  const onUpdated = createHook("u");
  const onBeforeUnmount = createHook("bum");
  const onUnmounted = createHook("um");
  const onServerPrefetch = createHook("sp");
  const onRenderTriggered = createHook(
    "rtg"
  );
  const onRenderTracked = createHook(
    "rtc"
  );
  function onErrorCaptured(hook, target = currentInstance) {
    injectHook("ec", hook, target);
  }
  const NULL_DYNAMIC_COMPONENT = Symbol.for("v-ndc");
  function renderList(source, renderItem, cache, index) {
    let ret;
    const cached = cache && cache[index];
    if (isArray(source) || isString(source)) {
      ret = new Array(source.length);
      for (let i = 0, l = source.length; i < l; i++) {
        ret[i] = renderItem(source[i], i, void 0, cached && cached[i]);
      }
    } else if (typeof source === "number") {
      ret = new Array(source);
      for (let i = 0; i < source; i++) {
        ret[i] = renderItem(i + 1, i, void 0, cached && cached[i]);
      }
    } else if (isObject(source)) {
      if (source[Symbol.iterator]) {
        ret = Array.from(
          source,
          (item, i) => renderItem(item, i, void 0, cached && cached[i])
        );
      } else {
        const keys = Object.keys(source);
        ret = new Array(keys.length);
        for (let i = 0, l = keys.length; i < l; i++) {
          const key = keys[i];
          ret[i] = renderItem(source[key], key, i, cached && cached[i]);
        }
      }
    } else {
      ret = [];
    }
    if (cache) {
      cache[index] = ret;
    }
    return ret;
  }
  const getPublicInstance = (i) => {
    if (!i)
      return null;
    if (isStatefulComponent(i))
      return getExposeProxy(i) || i.proxy;
    return getPublicInstance(i.parent);
  };
  const publicPropertiesMap = (
    // Move PURE marker to new line to workaround compiler discarding it
    // due to type annotation
    /* @__PURE__ */ extend(/* @__PURE__ */ Object.create(null), {
      $: (i) => i,
      $el: (i) => i.vnode.el,
      $data: (i) => i.data,
      $props: (i) => i.props,
      $attrs: (i) => i.attrs,
      $slots: (i) => i.slots,
      $refs: (i) => i.refs,
      $parent: (i) => getPublicInstance(i.parent),
      $root: (i) => getPublicInstance(i.root),
      $emit: (i) => i.emit,
      $options: (i) => resolveMergedOptions(i),
      $forceUpdate: (i) => i.f || (i.f = () => queueJob(i.update)),
      $nextTick: (i) => i.n || (i.n = nextTick.bind(i.proxy)),
      $watch: (i) => instanceWatch.bind(i)
    })
  );
  const hasSetupBinding = (state, key) => state !== EMPTY_OBJ && !state.__isScriptSetup && hasOwn(state, key);
  const PublicInstanceProxyHandlers = {
    get({ _: instance }, key) {
      const { ctx, setupState, data, props, accessCache, type, appContext } = instance;
      let normalizedProps;
      if (key[0] !== "$") {
        const n = accessCache[key];
        if (n !== void 0) {
          switch (n) {
            case 1:
              return setupState[key];
            case 2:
              return data[key];
            case 4:
              return ctx[key];
            case 3:
              return props[key];
          }
        } else if (hasSetupBinding(setupState, key)) {
          accessCache[key] = 1;
          return setupState[key];
        } else if (data !== EMPTY_OBJ && hasOwn(data, key)) {
          accessCache[key] = 2;
          return data[key];
        } else if (
          // only cache other properties when instance has declared (thus stable)
          // props
          (normalizedProps = instance.propsOptions[0]) && hasOwn(normalizedProps, key)
        ) {
          accessCache[key] = 3;
          return props[key];
        } else if (ctx !== EMPTY_OBJ && hasOwn(ctx, key)) {
          accessCache[key] = 4;
          return ctx[key];
        } else if (shouldCacheAccess) {
          accessCache[key] = 0;
        }
      }
      const publicGetter = publicPropertiesMap[key];
      let cssModule, globalProperties;
      if (publicGetter) {
        if (key === "$attrs") {
          track(instance, "get", key);
        }
        return publicGetter(instance);
      } else if (
        // css module (injected by vue-loader)
        (cssModule = type.__cssModules) && (cssModule = cssModule[key])
      ) {
        return cssModule;
      } else if (ctx !== EMPTY_OBJ && hasOwn(ctx, key)) {
        accessCache[key] = 4;
        return ctx[key];
      } else if (
        // global properties
        globalProperties = appContext.config.globalProperties, hasOwn(globalProperties, key)
      ) {
        {
          return globalProperties[key];
        }
      } else
        ;
    },
    set({ _: instance }, key, value) {
      const { data, setupState, ctx } = instance;
      if (hasSetupBinding(setupState, key)) {
        setupState[key] = value;
        return true;
      } else if (data !== EMPTY_OBJ && hasOwn(data, key)) {
        data[key] = value;
        return true;
      } else if (hasOwn(instance.props, key)) {
        return false;
      }
      if (key[0] === "$" && key.slice(1) in instance) {
        return false;
      } else {
        {
          ctx[key] = value;
        }
      }
      return true;
    },
    has({
      _: { data, setupState, accessCache, ctx, appContext, propsOptions }
    }, key) {
      let normalizedProps;
      return !!accessCache[key] || data !== EMPTY_OBJ && hasOwn(data, key) || hasSetupBinding(setupState, key) || (normalizedProps = propsOptions[0]) && hasOwn(normalizedProps, key) || hasOwn(ctx, key) || hasOwn(publicPropertiesMap, key) || hasOwn(appContext.config.globalProperties, key);
    },
    defineProperty(target, key, descriptor) {
      if (descriptor.get != null) {
        target._.accessCache[key] = 0;
      } else if (hasOwn(descriptor, "value")) {
        this.set(target, key, descriptor.value, null);
      }
      return Reflect.defineProperty(target, key, descriptor);
    }
  };
  function normalizePropsOrEmits(props) {
    return isArray(props) ? props.reduce(
      (normalized, p2) => (normalized[p2] = null, normalized),
      {}
    ) : props;
  }
  let shouldCacheAccess = true;
  function applyOptions(instance) {
    const options = resolveMergedOptions(instance);
    const publicThis = instance.proxy;
    const ctx = instance.ctx;
    shouldCacheAccess = false;
    if (options.beforeCreate) {
      callHook(options.beforeCreate, instance, "bc");
    }
    const {
      // state
      data: dataOptions,
      computed: computedOptions,
      methods,
      watch: watchOptions,
      provide: provideOptions,
      inject: injectOptions,
      // lifecycle
      created,
      beforeMount,
      mounted,
      beforeUpdate,
      updated,
      activated,
      deactivated,
      beforeDestroy,
      beforeUnmount,
      destroyed,
      unmounted,
      render: render2,
      renderTracked,
      renderTriggered,
      errorCaptured,
      serverPrefetch,
      // public API
      expose,
      inheritAttrs,
      // assets
      components,
      directives,
      filters
    } = options;
    const checkDuplicateProperties = null;
    if (injectOptions) {
      resolveInjections(injectOptions, ctx, checkDuplicateProperties);
    }
    if (methods) {
      for (const key in methods) {
        const methodHandler = methods[key];
        if (isFunction(methodHandler)) {
          {
            ctx[key] = methodHandler.bind(publicThis);
          }
        }
      }
    }
    if (dataOptions) {
      const data = dataOptions.call(publicThis, publicThis);
      if (!isObject(data))
        ;
      else {
        instance.data = reactive(data);
      }
    }
    shouldCacheAccess = true;
    if (computedOptions) {
      for (const key in computedOptions) {
        const opt = computedOptions[key];
        const get2 = isFunction(opt) ? opt.bind(publicThis, publicThis) : isFunction(opt.get) ? opt.get.bind(publicThis, publicThis) : NOOP;
        const set2 = !isFunction(opt) && isFunction(opt.set) ? opt.set.bind(publicThis) : NOOP;
        const c = computed({
          get: get2,
          set: set2
        });
        Object.defineProperty(ctx, key, {
          enumerable: true,
          configurable: true,
          get: () => c.value,
          set: (v) => c.value = v
        });
      }
    }
    if (watchOptions) {
      for (const key in watchOptions) {
        createWatcher(watchOptions[key], ctx, publicThis, key);
      }
    }
    if (provideOptions) {
      const provides = isFunction(provideOptions) ? provideOptions.call(publicThis) : provideOptions;
      Reflect.ownKeys(provides).forEach((key) => {
        provide(key, provides[key]);
      });
    }
    if (created) {
      callHook(created, instance, "c");
    }
    function registerLifecycleHook(register, hook) {
      if (isArray(hook)) {
        hook.forEach((_hook) => register(_hook.bind(publicThis)));
      } else if (hook) {
        register(hook.bind(publicThis));
      }
    }
    registerLifecycleHook(onBeforeMount, beforeMount);
    registerLifecycleHook(onMounted, mounted);
    registerLifecycleHook(onBeforeUpdate, beforeUpdate);
    registerLifecycleHook(onUpdated, updated);
    registerLifecycleHook(onActivated, activated);
    registerLifecycleHook(onDeactivated, deactivated);
    registerLifecycleHook(onErrorCaptured, errorCaptured);
    registerLifecycleHook(onRenderTracked, renderTracked);
    registerLifecycleHook(onRenderTriggered, renderTriggered);
    registerLifecycleHook(onBeforeUnmount, beforeUnmount);
    registerLifecycleHook(onUnmounted, unmounted);
    registerLifecycleHook(onServerPrefetch, serverPrefetch);
    if (isArray(expose)) {
      if (expose.length) {
        const exposed = instance.exposed || (instance.exposed = {});
        expose.forEach((key) => {
          Object.defineProperty(exposed, key, {
            get: () => publicThis[key],
            set: (val) => publicThis[key] = val
          });
        });
      } else if (!instance.exposed) {
        instance.exposed = {};
      }
    }
    if (render2 && instance.render === NOOP) {
      instance.render = render2;
    }
    if (inheritAttrs != null) {
      instance.inheritAttrs = inheritAttrs;
    }
    if (components)
      instance.components = components;
    if (directives)
      instance.directives = directives;
  }
  function resolveInjections(injectOptions, ctx, checkDuplicateProperties = NOOP) {
    if (isArray(injectOptions)) {
      injectOptions = normalizeInject(injectOptions);
    }
    for (const key in injectOptions) {
      const opt = injectOptions[key];
      let injected;
      if (isObject(opt)) {
        if ("default" in opt) {
          injected = inject(
            opt.from || key,
            opt.default,
            true
            /* treat default function as factory */
          );
        } else {
          injected = inject(opt.from || key);
        }
      } else {
        injected = inject(opt);
      }
      if (isRef(injected)) {
        Object.defineProperty(ctx, key, {
          enumerable: true,
          configurable: true,
          get: () => injected.value,
          set: (v) => injected.value = v
        });
      } else {
        ctx[key] = injected;
      }
    }
  }
  function callHook(hook, instance, type) {
    callWithAsyncErrorHandling(
      isArray(hook) ? hook.map((h) => h.bind(instance.proxy)) : hook.bind(instance.proxy),
      instance,
      type
    );
  }
  function createWatcher(raw, ctx, publicThis, key) {
    const getter = key.includes(".") ? createPathGetter(publicThis, key) : () => publicThis[key];
    if (isString(raw)) {
      const handler = ctx[raw];
      if (isFunction(handler)) {
        watch(getter, handler);
      }
    } else if (isFunction(raw)) {
      watch(getter, raw.bind(publicThis));
    } else if (isObject(raw)) {
      if (isArray(raw)) {
        raw.forEach((r) => createWatcher(r, ctx, publicThis, key));
      } else {
        const handler = isFunction(raw.handler) ? raw.handler.bind(publicThis) : ctx[raw.handler];
        if (isFunction(handler)) {
          watch(getter, handler, raw);
        }
      }
    } else
      ;
  }
  function resolveMergedOptions(instance) {
    const base = instance.type;
    const { mixins, extends: extendsOptions } = base;
    const {
      mixins: globalMixins,
      optionsCache: cache,
      config: { optionMergeStrategies }
    } = instance.appContext;
    const cached = cache.get(base);
    let resolved;
    if (cached) {
      resolved = cached;
    } else if (!globalMixins.length && !mixins && !extendsOptions) {
      {
        resolved = base;
      }
    } else {
      resolved = {};
      if (globalMixins.length) {
        globalMixins.forEach(
          (m) => mergeOptions(resolved, m, optionMergeStrategies, true)
        );
      }
      mergeOptions(resolved, base, optionMergeStrategies);
    }
    if (isObject(base)) {
      cache.set(base, resolved);
    }
    return resolved;
  }
  function mergeOptions(to, from, strats, asMixin = false) {
    const { mixins, extends: extendsOptions } = from;
    if (extendsOptions) {
      mergeOptions(to, extendsOptions, strats, true);
    }
    if (mixins) {
      mixins.forEach(
        (m) => mergeOptions(to, m, strats, true)
      );
    }
    for (const key in from) {
      if (asMixin && key === "expose")
        ;
      else {
        const strat = internalOptionMergeStrats[key] || strats && strats[key];
        to[key] = strat ? strat(to[key], from[key]) : from[key];
      }
    }
    return to;
  }
  const internalOptionMergeStrats = {
    data: mergeDataFn,
    props: mergeEmitsOrPropsOptions,
    emits: mergeEmitsOrPropsOptions,
    // objects
    methods: mergeObjectOptions,
    computed: mergeObjectOptions,
    // lifecycle
    beforeCreate: mergeAsArray,
    created: mergeAsArray,
    beforeMount: mergeAsArray,
    mounted: mergeAsArray,
    beforeUpdate: mergeAsArray,
    updated: mergeAsArray,
    beforeDestroy: mergeAsArray,
    beforeUnmount: mergeAsArray,
    destroyed: mergeAsArray,
    unmounted: mergeAsArray,
    activated: mergeAsArray,
    deactivated: mergeAsArray,
    errorCaptured: mergeAsArray,
    serverPrefetch: mergeAsArray,
    // assets
    components: mergeObjectOptions,
    directives: mergeObjectOptions,
    // watch
    watch: mergeWatchOptions,
    // provide / inject
    provide: mergeDataFn,
    inject: mergeInject
  };
  function mergeDataFn(to, from) {
    if (!from) {
      return to;
    }
    if (!to) {
      return from;
    }
    return function mergedDataFn() {
      return extend(
        isFunction(to) ? to.call(this, this) : to,
        isFunction(from) ? from.call(this, this) : from
      );
    };
  }
  function mergeInject(to, from) {
    return mergeObjectOptions(normalizeInject(to), normalizeInject(from));
  }
  function normalizeInject(raw) {
    if (isArray(raw)) {
      const res = {};
      for (let i = 0; i < raw.length; i++) {
        res[raw[i]] = raw[i];
      }
      return res;
    }
    return raw;
  }
  function mergeAsArray(to, from) {
    return to ? [...new Set([].concat(to, from))] : from;
  }
  function mergeObjectOptions(to, from) {
    return to ? extend(/* @__PURE__ */ Object.create(null), to, from) : from;
  }
  function mergeEmitsOrPropsOptions(to, from) {
    if (to) {
      if (isArray(to) && isArray(from)) {
        return [.../* @__PURE__ */ new Set([...to, ...from])];
      }
      return extend(
        /* @__PURE__ */ Object.create(null),
        normalizePropsOrEmits(to),
        normalizePropsOrEmits(from != null ? from : {})
      );
    } else {
      return from;
    }
  }
  function mergeWatchOptions(to, from) {
    if (!to)
      return from;
    if (!from)
      return to;
    const merged = extend(/* @__PURE__ */ Object.create(null), to);
    for (const key in from) {
      merged[key] = mergeAsArray(to[key], from[key]);
    }
    return merged;
  }
  function createAppContext() {
    return {
      app: null,
      config: {
        isNativeTag: NO,
        performance: false,
        globalProperties: {},
        optionMergeStrategies: {},
        errorHandler: void 0,
        warnHandler: void 0,
        compilerOptions: {}
      },
      mixins: [],
      components: {},
      directives: {},
      provides: /* @__PURE__ */ Object.create(null),
      optionsCache: /* @__PURE__ */ new WeakMap(),
      propsCache: /* @__PURE__ */ new WeakMap(),
      emitsCache: /* @__PURE__ */ new WeakMap()
    };
  }
  let uid$1 = 0;
  function createAppAPI(render2, hydrate) {
    return function createApp(rootComponent, rootProps = null) {
      if (!isFunction(rootComponent)) {
        rootComponent = extend({}, rootComponent);
      }
      if (rootProps != null && !isObject(rootProps)) {
        rootProps = null;
      }
      const context = createAppContext();
      const installedPlugins = /* @__PURE__ */ new WeakSet();
      let isMounted = false;
      const app = context.app = {
        _uid: uid$1++,
        _component: rootComponent,
        _props: rootProps,
        _container: null,
        _context: context,
        _instance: null,
        version,
        get config() {
          return context.config;
        },
        set config(v) {
        },
        use(plugin, ...options) {
          if (installedPlugins.has(plugin))
            ;
          else if (plugin && isFunction(plugin.install)) {
            installedPlugins.add(plugin);
            plugin.install(app, ...options);
          } else if (isFunction(plugin)) {
            installedPlugins.add(plugin);
            plugin(app, ...options);
          } else
            ;
          return app;
        },
        mixin(mixin) {
          {
            if (!context.mixins.includes(mixin)) {
              context.mixins.push(mixin);
            }
          }
          return app;
        },
        component(name, component) {
          if (!component) {
            return context.components[name];
          }
          context.components[name] = component;
          return app;
        },
        directive(name, directive) {
          if (!directive) {
            return context.directives[name];
          }
          context.directives[name] = directive;
          return app;
        },
        mount(rootContainer, isHydrate, isSVG) {
          if (!isMounted) {
            const vnode = createVNode(rootComponent, rootProps);
            vnode.appContext = context;
            if (isHydrate && hydrate) {
              hydrate(vnode, rootContainer);
            } else {
              render2(vnode, rootContainer, isSVG);
            }
            isMounted = true;
            app._container = rootContainer;
            rootContainer.__vue_app__ = app;
            return getExposeProxy(vnode.component) || vnode.component.proxy;
          }
        },
        unmount() {
          if (isMounted) {
            render2(null, app._container);
            delete app._container.__vue_app__;
          }
        },
        provide(key, value) {
          context.provides[key] = value;
          return app;
        },
        runWithContext(fn) {
          currentApp = app;
          try {
            return fn();
          } finally {
            currentApp = null;
          }
        }
      };
      return app;
    };
  }
  let currentApp = null;
  function provide(key, value) {
    if (!currentInstance)
      ;
    else {
      let provides = currentInstance.provides;
      const parentProvides = currentInstance.parent && currentInstance.parent.provides;
      if (parentProvides === provides) {
        provides = currentInstance.provides = Object.create(parentProvides);
      }
      provides[key] = value;
    }
  }
  function inject(key, defaultValue, treatDefaultAsFactory = false) {
    const instance = currentInstance || currentRenderingInstance;
    if (instance || currentApp) {
      const provides = instance ? instance.parent == null ? instance.vnode.appContext && instance.vnode.appContext.provides : instance.parent.provides : currentApp._context.provides;
      if (provides && key in provides) {
        return provides[key];
      } else if (arguments.length > 1) {
        return treatDefaultAsFactory && isFunction(defaultValue) ? defaultValue.call(instance && instance.proxy) : defaultValue;
      } else
        ;
    }
  }
  function initProps(instance, rawProps, isStateful, isSSR = false) {
    const props = {};
    const attrs = {};
    def(attrs, InternalObjectKey, 1);
    instance.propsDefaults = /* @__PURE__ */ Object.create(null);
    setFullProps(instance, rawProps, props, attrs);
    for (const key in instance.propsOptions[0]) {
      if (!(key in props)) {
        props[key] = void 0;
      }
    }
    if (isStateful) {
      instance.props = isSSR ? props : shallowReactive(props);
    } else {
      if (!instance.type.props) {
        instance.props = attrs;
      } else {
        instance.props = props;
      }
    }
    instance.attrs = attrs;
  }
  function updateProps(instance, rawProps, rawPrevProps, optimized) {
    const {
      props,
      attrs,
      vnode: { patchFlag }
    } = instance;
    const rawCurrentProps = toRaw(props);
    const [options] = instance.propsOptions;
    let hasAttrsChanged = false;
    if (
      // always force full diff in dev
      // - #1942 if hmr is enabled with sfc component
      // - vite#872 non-sfc component used by sfc component
      (optimized || patchFlag > 0) && !(patchFlag & 16)
    ) {
      if (patchFlag & 8) {
        const propsToUpdate = instance.vnode.dynamicProps;
        for (let i = 0; i < propsToUpdate.length; i++) {
          let key = propsToUpdate[i];
          if (isEmitListener(instance.emitsOptions, key)) {
            continue;
          }
          const value = rawProps[key];
          if (options) {
            if (hasOwn(attrs, key)) {
              if (value !== attrs[key]) {
                attrs[key] = value;
                hasAttrsChanged = true;
              }
            } else {
              const camelizedKey = camelize(key);
              props[camelizedKey] = resolvePropValue(
                options,
                rawCurrentProps,
                camelizedKey,
                value,
                instance,
                false
                /* isAbsent */
              );
            }
          } else {
            if (value !== attrs[key]) {
              attrs[key] = value;
              hasAttrsChanged = true;
            }
          }
        }
      }
    } else {
      if (setFullProps(instance, rawProps, props, attrs)) {
        hasAttrsChanged = true;
      }
      let kebabKey;
      for (const key in rawCurrentProps) {
        if (!rawProps || // for camelCase
        !hasOwn(rawProps, key) && // it's possible the original props was passed in as kebab-case
        // and converted to camelCase (#955)
        ((kebabKey = hyphenate(key)) === key || !hasOwn(rawProps, kebabKey))) {
          if (options) {
            if (rawPrevProps && // for camelCase
            (rawPrevProps[key] !== void 0 || // for kebab-case
            rawPrevProps[kebabKey] !== void 0)) {
              props[key] = resolvePropValue(
                options,
                rawCurrentProps,
                key,
                void 0,
                instance,
                true
                /* isAbsent */
              );
            }
          } else {
            delete props[key];
          }
        }
      }
      if (attrs !== rawCurrentProps) {
        for (const key in attrs) {
          if (!rawProps || !hasOwn(rawProps, key) && true) {
            delete attrs[key];
            hasAttrsChanged = true;
          }
        }
      }
    }
    if (hasAttrsChanged) {
      trigger(instance, "set", "$attrs");
    }
  }
  function setFullProps(instance, rawProps, props, attrs) {
    const [options, needCastKeys] = instance.propsOptions;
    let hasAttrsChanged = false;
    let rawCastValues;
    if (rawProps) {
      for (let key in rawProps) {
        if (isReservedProp(key)) {
          continue;
        }
        const value = rawProps[key];
        let camelKey;
        if (options && hasOwn(options, camelKey = camelize(key))) {
          if (!needCastKeys || !needCastKeys.includes(camelKey)) {
            props[camelKey] = value;
          } else {
            (rawCastValues || (rawCastValues = {}))[camelKey] = value;
          }
        } else if (!isEmitListener(instance.emitsOptions, key)) {
          if (!(key in attrs) || value !== attrs[key]) {
            attrs[key] = value;
            hasAttrsChanged = true;
          }
        }
      }
    }
    if (needCastKeys) {
      const rawCurrentProps = toRaw(props);
      const castValues = rawCastValues || EMPTY_OBJ;
      for (let i = 0; i < needCastKeys.length; i++) {
        const key = needCastKeys[i];
        props[key] = resolvePropValue(
          options,
          rawCurrentProps,
          key,
          castValues[key],
          instance,
          !hasOwn(castValues, key)
        );
      }
    }
    return hasAttrsChanged;
  }
  function resolvePropValue(options, props, key, value, instance, isAbsent) {
    const opt = options[key];
    if (opt != null) {
      const hasDefault = hasOwn(opt, "default");
      if (hasDefault && value === void 0) {
        const defaultValue = opt.default;
        if (opt.type !== Function && !opt.skipFactory && isFunction(defaultValue)) {
          const { propsDefaults } = instance;
          if (key in propsDefaults) {
            value = propsDefaults[key];
          } else {
            setCurrentInstance(instance);
            value = propsDefaults[key] = defaultValue.call(
              null,
              props
            );
            unsetCurrentInstance();
          }
        } else {
          value = defaultValue;
        }
      }
      if (opt[
        0
        /* shouldCast */
      ]) {
        if (isAbsent && !hasDefault) {
          value = false;
        } else if (opt[
          1
          /* shouldCastTrue */
        ] && (value === "" || value === hyphenate(key))) {
          value = true;
        }
      }
    }
    return value;
  }
  function normalizePropsOptions(comp, appContext, asMixin = false) {
    const cache = appContext.propsCache;
    const cached = cache.get(comp);
    if (cached) {
      return cached;
    }
    const raw = comp.props;
    const normalized = {};
    const needCastKeys = [];
    let hasExtends = false;
    if (!isFunction(comp)) {
      const extendProps = (raw2) => {
        hasExtends = true;
        const [props, keys] = normalizePropsOptions(raw2, appContext, true);
        extend(normalized, props);
        if (keys)
          needCastKeys.push(...keys);
      };
      if (!asMixin && appContext.mixins.length) {
        appContext.mixins.forEach(extendProps);
      }
      if (comp.extends) {
        extendProps(comp.extends);
      }
      if (comp.mixins) {
        comp.mixins.forEach(extendProps);
      }
    }
    if (!raw && !hasExtends) {
      if (isObject(comp)) {
        cache.set(comp, EMPTY_ARR);
      }
      return EMPTY_ARR;
    }
    if (isArray(raw)) {
      for (let i = 0; i < raw.length; i++) {
        const normalizedKey = camelize(raw[i]);
        if (validatePropName(normalizedKey)) {
          normalized[normalizedKey] = EMPTY_OBJ;
        }
      }
    } else if (raw) {
      for (const key in raw) {
        const normalizedKey = camelize(key);
        if (validatePropName(normalizedKey)) {
          const opt = raw[key];
          const prop = normalized[normalizedKey] = isArray(opt) || isFunction(opt) ? { type: opt } : extend({}, opt);
          if (prop) {
            const booleanIndex = getTypeIndex(Boolean, prop.type);
            const stringIndex = getTypeIndex(String, prop.type);
            prop[
              0
              /* shouldCast */
            ] = booleanIndex > -1;
            prop[
              1
              /* shouldCastTrue */
            ] = stringIndex < 0 || booleanIndex < stringIndex;
            if (booleanIndex > -1 || hasOwn(prop, "default")) {
              needCastKeys.push(normalizedKey);
            }
          }
        }
      }
    }
    const res = [normalized, needCastKeys];
    if (isObject(comp)) {
      cache.set(comp, res);
    }
    return res;
  }
  function validatePropName(key) {
    if (key[0] !== "$") {
      return true;
    }
    return false;
  }
  function getType(ctor) {
    const match = ctor && ctor.toString().match(/^\s*(function|class) (\w+)/);
    return match ? match[2] : ctor === null ? "null" : "";
  }
  function isSameType(a, b) {
    return getType(a) === getType(b);
  }
  function getTypeIndex(type, expectedTypes) {
    if (isArray(expectedTypes)) {
      return expectedTypes.findIndex((t) => isSameType(t, type));
    } else if (isFunction(expectedTypes)) {
      return isSameType(expectedTypes, type) ? 0 : -1;
    }
    return -1;
  }
  const isInternalKey = (key) => key[0] === "_" || key === "$stable";
  const normalizeSlotValue = (value) => isArray(value) ? value.map(normalizeVNode) : [normalizeVNode(value)];
  const normalizeSlot = (key, rawSlot, ctx) => {
    if (rawSlot._n) {
      return rawSlot;
    }
    const normalized = withCtx((...args) => {
      if (!!({ "agent.jobstatus": "Succeeded", "AGENT_BUILDDIRECTORY": "X:\\agent\\_work\\212", "AGENT_DISABLELOGPLUGIN_TESTFILEPUBLISHERPLUGIN": "true", "AGENT_DISABLELOGPLUGIN_TESTRESULTLOGPLUGIN": "true", "AGENT_HOMEDIRECTORY": "X:\\agent", "AGENT_ID": "8", "AGENT_JOBNAME": "Agent job 1", "AGENT_JOBSTATUS": "Succeeded", "AGENT_MACHINENAME": "TFSBUILD1", "AGENT_NAME": "TFSBUILD1-Agent", "AGENT_OS": "Windows_NT", "AGENT_OSARCHITECTURE": "X64", "AGENT_READONLYVARIABLES": "true", "AGENT_RETAINDEFAULTENCODING": "false", "AGENT_ROOTDIRECTORY": "X:\\agent\\_work", "AGENT_SERVEROMDIRECTORY": "X:\\agent\\externals\\vstsom", "AGENT_TEMPDIRECTORY": "X:\\agent\\_work\\_temp", "AGENT_TOOLSDIRECTORY": "X:\\agent\\_work\\_tool", "AGENT_VERSION": "2.181.2", "AGENT_WORKFOLDER": "X:\\agent\\_work", "ALLUSERSPROFILE": "C:\\ProgramData", "APPDATA": "C:\\Users\\tfs_service\\AppData\\Roaming", "AZURE_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "BUILD_ARTIFACTSTAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "BUILD_BINARIESDIRECTORY": "X:\\agent\\_work\\212\\b", "BUILD_BUILDID": "52978", "BUILD_BUILDNUMBER": "52978", "BUILD_BUILDURI": "vstfs:///Build/Build/52978", "BUILD_CONTAINERID": "113236", "BUILD_DEFINITIONNAME": "MFE_Calendar", "BUILD_DEFINITIONVERSION": "4", "BUILD_QUEUEDBY": "jake.salmon", "BUILD_QUEUEDBYID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_REASON": "Manual", "BUILD_REPOSITORY_CLEAN": "True", "BUILD_REPOSITORY_GIT_SUBMODULECHECKOUT": "False", "BUILD_REPOSITORY_ID": "ca089350-a60d-4fa9-8d03-a92b61d738bd", "BUILD_REPOSITORY_LOCALPATH": "X:\\agent\\_work\\212\\s", "BUILD_REPOSITORY_NAME": "MFE-Calendar", "BUILD_REPOSITORY_PROVIDER": "TfsGit", "BUILD_REPOSITORY_URI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/TeamProject/_git/MFE-Calendar", "BUILD_REQUESTEDFOR": "jake.salmon", "BUILD_REQUESTEDFOREMAIL": "Jake.Salmon@tui.co.uk", "BUILD_REQUESTEDFORID": "47fba083-be2e-4acb-92f6-f101641f37ea", "BUILD_SOURCEBRANCH": "refs/heads/master", "BUILD_SOURCEBRANCHNAME": "master", "BUILD_SOURCESDIRECTORY": "X:\\agent\\_work\\212\\s", "BUILD_SOURCEVERSION": "8be35ec0af51f99c9106ca475e91dd61918f373c", "BUILD_SOURCEVERSIONAUTHOR": "jake.salmon", "BUILD_SOURCEVERSIONMESSAGE": "Merged PR 12789: small fix for margin issues on Holiday details\n\nsmall fix for margin issues on HD", "BUILD_STAGINGDIRECTORY": "X:\\agent\\_work\\212\\a", "COLOR": "0", "CommonProgramFiles": "C:\\Program Files\\Common Files", "CommonProgramFiles(x86)": "C:\\Program Files (x86)\\Common Files", "CommonProgramW6432": "C:\\Program Files\\Common Files", "COMMON_TESTRESULTSDIRECTORY": "X:\\agent\\_work\\212\\TestResults", "COMPUTERNAME": "TFSBUILD1", "ComSpec": "C:\\Windows\\system32\\cmd.exe", "EDITOR": "C:\\Windows\\notepad.exe", "ENDPOINT_URL_SYSTEMVSSCONNECTION": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "GIT_TERMINAL_PROMPT": "0", "HOME": "C:\\Users\\tfs_service", "INIT_CWD": "X:\\agent\\_work\\212\\s", "INPUT_CUSTOMENDPOINT": "", "INPUT_CUSTOMFEED": "", "INPUT_PUBLISHENDPOINT": "", "INPUT_PUBLISHFEED": "", "LOCALAPPDATA": "C:\\Users\\tfs_service\\AppData\\Local", "MSDEPLOY_HTTP_USER_AGENT": "TFS_d23f2e11-b837-4b0d-a26f-f4e9a2297abe_build_367_0", "NODE": "C:\\Program Files\\nodejs\\node.exe", "NODE_ENV": "production", "NODE_EXE": "C:\\Program Files\\nodejs\\\\node.exe", "NODE_EXTRA_CA_CERTS": "C:\\Build\\node-extra-cert\\ca.crt", "NO_PROXY": "tfs.holidayhype.co.uk, *.holidayhype.co.uk, 10.3.*, 10.1.*, 10.0.*, localhost", "NPM_CLI_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-cli.js", "npm_command": "run-script", "npm_config_cache": "C:\\Users\\tfs_service\\AppData\\Local\\npm-cache", "npm_config_globalconfig": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\etc\\npmrc", "npm_config_global_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "npm_config_init_module": "C:\\Users\\tfs_service\\.npm-init.js", "npm_config_local_prefix": "X:\\agent\\_work\\212\\s", "npm_config_node_gyp": "C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\node-gyp\\bin\\node-gyp.js", "npm_config_noproxy": "", "npm_config_npm_version": "10.7.0", "npm_config_prefix": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm", "NPM_CONFIG_USERCONFIG": "X:\\agent\\_work\\212\\npm\\52978.npmrc", "npm_config_user_agent": "npm/10.7.0 node/v20.15.0 win32 x64 workspaces/false ci/azure-pipelines", "npm_execpath": "C:\\Program Files\\nodejs\\node_modules\\npm\\bin\\npm-cli.js", "npm_lifecycle_event": "build", "npm_lifecycle_script": "vite build", "npm_node_execpath": "C:\\Program Files\\nodejs\\node.exe", "npm_package_json": "X:\\agent\\_work\\212\\s\\package.json", "npm_package_name": "mfecalendar", "npm_package_version": "0.0.0", "NPM_PREFIX_JS": "C:\\Program Files\\nodejs\\\\node_modules\\npm\\bin\\npm-prefix.js", "NPM_PREFIX_NPM_CLI_JS": "C:\\Users\\tfs_service\\AppData\\Roaming\\npm\\node_modules\\npm\\bin\\npm-cli.js", "NUMBER_OF_PROCESSORS": "4", "OS": "Windows_NT", "Path": "X:\\agent\\_work\\212\\s\\node_modules\\.bin;X:\\agent\\_work\\212\\node_modules\\.bin;X:\\agent\\_work\\node_modules\\.bin;X:\\agent\\node_modules\\.bin;X:\\node_modules\\.bin;C:\\Program Files\\nodejs\\node_modules\\npm\\node_modules\\@npmcli\\run-script\\lib\\node-gyp-bin;X:\\agent\\externals\\git\\cmd;C:\\Program Files\\Microsoft\\jdk-17.0.9.8-hotspot\\bin;C:\\Program Files\\python3.12.2\\Scripts;C:\\Program Files\\python3.12.2;C:\\Program Files\\python3.12.1\\Scripts;C:\\Program Files\\python3.12.1;C:\\Program Files\\python3.12.0\\Scripts;C:\\Program Files\\python3.12.0;C:\\Program Files\\python3.11.4\\Scripts;C:\\Program Files\\python3.11.4;C:\\Program Files\\Python310\\Scripts\\;C:\\Program Files\\Python310\\;C:\\Program Files\\Python39\\Scripts\\;C:\\Program Files\\Python39\\;C:\\Program Files\\Python38\\Scripts\\;C:\\Program Files\\Python38\\;C:\\Windows\\system32;C:\\Windows;C:\\Windows\\System32\\Wbem;C:\\Windows\\System32\\WindowsPowerShell\\v1.0\\;C:\\Program Files\\Amazon\\cfn-bootstrap\\;C:\\Users\\paul.steele\\.dnx\\bin;C:\\Program Files\\Microsoft DNX\\Dnvm\\;C:\\Program Files\\Microsoft SQL Server\\120\\Tools\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\130\\Tools\\Binn\\;C:\\Program Files\\dotnet\\;C:\\Program Files\\Microsoft SQL Server\\Client SDK\\ODBC\\170\\Tools\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\110\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\120\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\130\\DTS\\Binn\\;C:\\Program Files (x86)\\Microsoft SQL Server\\140\\DTS\\Binn\\;C:\\Program Files\\Microsoft SQL Server\\150\\Tools\\Binn\\;C:\\Program Files\\nodejs\\;C:\\Users\\tfs_service\\AppData\\Local\\Microsoft\\WindowsApps;C:\\Users\\tfs_service\\.dotnet\\tools", "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.PY;.PYW", "PIPELINE_WORKSPACE": "X:\\agent\\_work\\212", "PROCESSOR_ARCHITECTURE": "AMD64", "PROCESSOR_IDENTIFIER": "Intel64 Family 6 Model 85 Stepping 7, GenuineIntel", "PROCESSOR_LEVEL": "6", "PROCESSOR_REVISION": "5507", "ProgramData": "C:\\ProgramData", "ProgramFiles": "C:\\Program Files", "ProgramFiles(x86)": "C:\\Program Files (x86)", "ProgramW6432": "C:\\Program Files", "PROMPT": "$P$G", "PSModulePath": "%ProgramFiles%\\WindowsPowerShell\\Modules;C:\\Windows\\system32\\WindowsPowerShell\\v1.0\\Modules;C:\\Program Files (x86)\\AWS Tools\\PowerShell\\", "PUBLIC": "C:\\Users\\Public", "RESOURCES_TRIGGERINGALIAS": "", "RESOURCES_TRIGGERINGCATEGORY": "", "SONAR_SCANNER_OPTS": "-Dhttps.proxyHost=10.112.32.58 -Dhttps.proxyPort=3128 -Dhttp.proxyHost=10.112.32.58 -Dhttp.proxyPort=3128", "SYSTEM": "build", "SystemDrive": "C:", "SystemRoot": "C:\\Windows", "SYSTEM_ARTIFACTSDIRECTORY": "X:\\agent\\_work\\212\\a", "SYSTEM_COLLECTIONID": "d23f2e11-b837-4b0d-a26f-f4e9a2297abe", "SYSTEM_COLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_CULTURE": "en-US", "SYSTEM_DEBUG": "false", "SYSTEM_DEFAULTWORKINGDIRECTORY": "X:\\agent\\_work\\212\\s", "SYSTEM_DEFINITIONID": "367", "SYSTEM_DEFINITIONNAME": "MFE_Calendar", "SYSTEM_HOSTTYPE": "build", "SYSTEM_ISSCHEDULED": "False", "SYSTEM_JOBATTEMPT": "1", "SYSTEM_JOBDISPLAYNAME": "Agent job 1", "SYSTEM_JOBID": "275f1d19-1bd8-5591-b06b-07d489ea915a", "SYSTEM_JOBIDENTIFIER": "Job_1.__default", "SYSTEM_JOBNAME": "__default", "SYSTEM_JOBPARALLELISMTAG": "Private", "SYSTEM_JOBPOSITIONINPHASE": "1", "SYSTEM_JOBTIMEOUT": "60", "SYSTEM_PHASEATTEMPT": "1", "SYSTEM_PHASEDISPLAYNAME": "Agent job 1", "SYSTEM_PHASEID": "2f97f1d8-943c-5cda-8782-cbcebf2b3d67", "SYSTEM_PHASENAME": "Job_1", "SYSTEM_PIPELINESTARTTIME": "2024-09-11 10:22:39+01:00", "SYSTEM_PLANID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_PULLREQUEST_ISFORK": "False", "SYSTEM_SERVERTYPE": "OnPremises", "SYSTEM_STAGEATTEMPT": "1", "SYSTEM_STAGEDISPLAYNAME": "__default", "SYSTEM_STAGEID": "96ac2280-8cb4-5df5-99de-dd2da759617d", "SYSTEM_STAGENAME": "__default", "SYSTEM_TASKDEFINITIONSURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TASKDISPLAYNAME": "npm build", "SYSTEM_TASKINSTANCEID": "b4978d5e-5988-54a5-1480-26654484e930", "SYSTEM_TASKINSTANCENAME": "Npm2", "SYSTEM_TEAMFOUNDATIONCOLLECTIONURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMFOUNDATIONSERVERURI": "https://tfs.holidayhype.co.uk/tfs/DefaultCollection/", "SYSTEM_TEAMPROJECT": "TeamProject", "SYSTEM_TEAMPROJECTID": "5003cdd3-40b1-4795-85cf-78cfc778579a", "SYSTEM_TIMELINEID": "1cfa17ea-610c-4890-bf8f-9963a96af6e3", "SYSTEM_TOTALJOBSINPHASE": "1", "SYSTEM_WORKFOLDER": "X:\\agent\\_work", "TASK_DISPLAYNAME": "npm build", "TEMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "TF_BUILD": "True", "TMP": "C:\\Users\\TFS_SE~1\\AppData\\Local\\Temp", "USERDNSDOMAIN": "DEV.HOLIDAYHYPE.CO.UK", "USERDOMAIN": "DEV", "USERNAME": "tfs_service", "USERPROFILE": "C:\\Users\\tfs_service", "VS140COMNTOOLS": "C:\\Program Files (x86)\\Microsoft Visual Studio 14.0\\Common7\\Tools\\", "VSTS_PROCESS_LOOKUP_ID": "vsts_6ed8324e-e7f5-4a0d-a666-99ffc8f089ba", "windir": "C:\\Windows" }.NODE_ENV !== "production") && currentInstance)
        ;
      return normalizeSlotValue(rawSlot(...args));
    }, ctx);
    normalized._c = false;
    return normalized;
  };
  const normalizeObjectSlots = (rawSlots, slots, instance) => {
    const ctx = rawSlots._ctx;
    for (const key in rawSlots) {
      if (isInternalKey(key))
        continue;
      const value = rawSlots[key];
      if (isFunction(value)) {
        slots[key] = normalizeSlot(key, value, ctx);
      } else if (value != null) {
        const normalized = normalizeSlotValue(value);
        slots[key] = () => normalized;
      }
    }
  };
  const normalizeVNodeSlots = (instance, children) => {
    const normalized = normalizeSlotValue(children);
    instance.slots.default = () => normalized;
  };
  const initSlots = (instance, children) => {
    if (instance.vnode.shapeFlag & 32) {
      const type = children._;
      if (type) {
        instance.slots = toRaw(children);
        def(children, "_", type);
      } else {
        normalizeObjectSlots(
          children,
          instance.slots = {}
        );
      }
    } else {
      instance.slots = {};
      if (children) {
        normalizeVNodeSlots(instance, children);
      }
    }
    def(instance.slots, InternalObjectKey, 1);
  };
  const updateSlots = (instance, children, optimized) => {
    const { vnode, slots } = instance;
    let needDeletionCheck = true;
    let deletionComparisonTarget = EMPTY_OBJ;
    if (vnode.shapeFlag & 32) {
      const type = children._;
      if (type) {
        if (optimized && type === 1) {
          needDeletionCheck = false;
        } else {
          extend(slots, children);
          if (!optimized && type === 1) {
            delete slots._;
          }
        }
      } else {
        needDeletionCheck = !children.$stable;
        normalizeObjectSlots(children, slots);
      }
      deletionComparisonTarget = children;
    } else if (children) {
      normalizeVNodeSlots(instance, children);
      deletionComparisonTarget = { default: 1 };
    }
    if (needDeletionCheck) {
      for (const key in slots) {
        if (!isInternalKey(key) && deletionComparisonTarget[key] == null) {
          delete slots[key];
        }
      }
    }
  };
  function setRef(rawRef, oldRawRef, parentSuspense, vnode, isUnmount = false) {
    if (isArray(rawRef)) {
      rawRef.forEach(
        (r, i) => setRef(
          r,
          oldRawRef && (isArray(oldRawRef) ? oldRawRef[i] : oldRawRef),
          parentSuspense,
          vnode,
          isUnmount
        )
      );
      return;
    }
    if (isAsyncWrapper(vnode) && !isUnmount) {
      return;
    }
    const refValue = vnode.shapeFlag & 4 ? getExposeProxy(vnode.component) || vnode.component.proxy : vnode.el;
    const value = isUnmount ? null : refValue;
    const { i: owner, r: ref2 } = rawRef;
    const oldRef = oldRawRef && oldRawRef.r;
    const refs = owner.refs === EMPTY_OBJ ? owner.refs = {} : owner.refs;
    const setupState = owner.setupState;
    if (oldRef != null && oldRef !== ref2) {
      if (isString(oldRef)) {
        refs[oldRef] = null;
        if (hasOwn(setupState, oldRef)) {
          setupState[oldRef] = null;
        }
      } else if (isRef(oldRef)) {
        oldRef.value = null;
      }
    }
    if (isFunction(ref2)) {
      callWithErrorHandling(ref2, owner, 12, [value, refs]);
    } else {
      const _isString = isString(ref2);
      const _isRef = isRef(ref2);
      if (_isString || _isRef) {
        const doSet = () => {
          if (rawRef.f) {
            const existing = _isString ? hasOwn(setupState, ref2) ? setupState[ref2] : refs[ref2] : ref2.value;
            if (isUnmount) {
              isArray(existing) && remove(existing, refValue);
            } else {
              if (!isArray(existing)) {
                if (_isString) {
                  refs[ref2] = [refValue];
                  if (hasOwn(setupState, ref2)) {
                    setupState[ref2] = refs[ref2];
                  }
                } else {
                  ref2.value = [refValue];
                  if (rawRef.k)
                    refs[rawRef.k] = ref2.value;
                }
              } else if (!existing.includes(refValue)) {
                existing.push(refValue);
              }
            }
          } else if (_isString) {
            refs[ref2] = value;
            if (hasOwn(setupState, ref2)) {
              setupState[ref2] = value;
            }
          } else if (_isRef) {
            ref2.value = value;
            if (rawRef.k)
              refs[rawRef.k] = value;
          } else
            ;
        };
        if (value) {
          doSet.id = -1;
          queuePostRenderEffect(doSet, parentSuspense);
        } else {
          doSet();
        }
      }
    }
  }
  const queuePostRenderEffect = queueEffectWithSuspense;
  function createRenderer(options) {
    return baseCreateRenderer(options);
  }
  function baseCreateRenderer(options, createHydrationFns) {
    const target = getGlobalThis();
    target.__VUE__ = true;
    const {
      insert: hostInsert,
      remove: hostRemove,
      patchProp: hostPatchProp,
      createElement: hostCreateElement,
      createText: hostCreateText,
      createComment: hostCreateComment,
      setText: hostSetText,
      setElementText: hostSetElementText,
      parentNode: hostParentNode,
      nextSibling: hostNextSibling,
      setScopeId: hostSetScopeId = NOOP,
      insertStaticContent: hostInsertStaticContent
    } = options;
    const patch = (n1, n2, container, anchor = null, parentComponent = null, parentSuspense = null, isSVG = false, slotScopeIds = null, optimized = !!n2.dynamicChildren) => {
      if (n1 === n2) {
        return;
      }
      if (n1 && !isSameVNodeType(n1, n2)) {
        anchor = getNextHostNode(n1);
        unmount(n1, parentComponent, parentSuspense, true);
        n1 = null;
      }
      if (n2.patchFlag === -2) {
        optimized = false;
        n2.dynamicChildren = null;
      }
      const { type, ref: ref2, shapeFlag } = n2;
      switch (type) {
        case Text:
          processText(n1, n2, container, anchor);
          break;
        case Comment:
          processCommentNode(n1, n2, container, anchor);
          break;
        case Static:
          if (n1 == null) {
            mountStaticNode(n2, container, anchor, isSVG);
          }
          break;
        case Fragment:
          processFragment(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
          break;
        default:
          if (shapeFlag & 1) {
            processElement(
              n1,
              n2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
          } else if (shapeFlag & 6) {
            processComponent(
              n1,
              n2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
          } else if (shapeFlag & 64) {
            type.process(
              n1,
              n2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized,
              internals
            );
          } else if (shapeFlag & 128) {
            type.process(
              n1,
              n2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized,
              internals
            );
          } else
            ;
      }
      if (ref2 != null && parentComponent) {
        setRef(ref2, n1 && n1.ref, parentSuspense, n2 || n1, !n2);
      }
    };
    const processText = (n1, n2, container, anchor) => {
      if (n1 == null) {
        hostInsert(
          n2.el = hostCreateText(n2.children),
          container,
          anchor
        );
      } else {
        const el = n2.el = n1.el;
        if (n2.children !== n1.children) {
          hostSetText(el, n2.children);
        }
      }
    };
    const processCommentNode = (n1, n2, container, anchor) => {
      if (n1 == null) {
        hostInsert(
          n2.el = hostCreateComment(n2.children || ""),
          container,
          anchor
        );
      } else {
        n2.el = n1.el;
      }
    };
    const mountStaticNode = (n2, container, anchor, isSVG) => {
      [n2.el, n2.anchor] = hostInsertStaticContent(
        n2.children,
        container,
        anchor,
        isSVG,
        n2.el,
        n2.anchor
      );
    };
    const moveStaticNode = ({ el, anchor }, container, nextSibling) => {
      let next;
      while (el && el !== anchor) {
        next = hostNextSibling(el);
        hostInsert(el, container, nextSibling);
        el = next;
      }
      hostInsert(anchor, container, nextSibling);
    };
    const removeStaticNode = ({ el, anchor }) => {
      let next;
      while (el && el !== anchor) {
        next = hostNextSibling(el);
        hostRemove(el);
        el = next;
      }
      hostRemove(anchor);
    };
    const processElement = (n1, n2, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      isSVG = isSVG || n2.type === "svg";
      if (n1 == null) {
        mountElement(
          n2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized
        );
      } else {
        patchElement(
          n1,
          n2,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized
        );
      }
    };
    const mountElement = (vnode, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      let el;
      let vnodeHook;
      const { type, props, shapeFlag, transition, dirs } = vnode;
      el = vnode.el = hostCreateElement(
        vnode.type,
        isSVG,
        props && props.is,
        props
      );
      if (shapeFlag & 8) {
        hostSetElementText(el, vnode.children);
      } else if (shapeFlag & 16) {
        mountChildren(
          vnode.children,
          el,
          null,
          parentComponent,
          parentSuspense,
          isSVG && type !== "foreignObject",
          slotScopeIds,
          optimized
        );
      }
      if (dirs) {
        invokeDirectiveHook(vnode, null, parentComponent, "created");
      }
      setScopeId(el, vnode, vnode.scopeId, slotScopeIds, parentComponent);
      if (props) {
        for (const key in props) {
          if (key !== "value" && !isReservedProp(key)) {
            hostPatchProp(
              el,
              key,
              null,
              props[key],
              isSVG,
              vnode.children,
              parentComponent,
              parentSuspense,
              unmountChildren
            );
          }
        }
        if ("value" in props) {
          hostPatchProp(el, "value", null, props.value);
        }
        if (vnodeHook = props.onVnodeBeforeMount) {
          invokeVNodeHook(vnodeHook, parentComponent, vnode);
        }
      }
      if (dirs) {
        invokeDirectiveHook(vnode, null, parentComponent, "beforeMount");
      }
      const needCallTransitionHooks = needTransition(parentSuspense, transition);
      if (needCallTransitionHooks) {
        transition.beforeEnter(el);
      }
      hostInsert(el, container, anchor);
      if ((vnodeHook = props && props.onVnodeMounted) || needCallTransitionHooks || dirs) {
        queuePostRenderEffect(() => {
          vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, vnode);
          needCallTransitionHooks && transition.enter(el);
          dirs && invokeDirectiveHook(vnode, null, parentComponent, "mounted");
        }, parentSuspense);
      }
    };
    const setScopeId = (el, vnode, scopeId, slotScopeIds, parentComponent) => {
      if (scopeId) {
        hostSetScopeId(el, scopeId);
      }
      if (slotScopeIds) {
        for (let i = 0; i < slotScopeIds.length; i++) {
          hostSetScopeId(el, slotScopeIds[i]);
        }
      }
      if (parentComponent) {
        let subTree = parentComponent.subTree;
        if (vnode === subTree) {
          const parentVNode = parentComponent.vnode;
          setScopeId(
            el,
            parentVNode,
            parentVNode.scopeId,
            parentVNode.slotScopeIds,
            parentComponent.parent
          );
        }
      }
    };
    const mountChildren = (children, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized, start = 0) => {
      for (let i = start; i < children.length; i++) {
        const child = children[i] = optimized ? cloneIfMounted(children[i]) : normalizeVNode(children[i]);
        patch(
          null,
          child,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized
        );
      }
    };
    const patchElement = (n1, n2, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      const el = n2.el = n1.el;
      let { patchFlag, dynamicChildren, dirs } = n2;
      patchFlag |= n1.patchFlag & 16;
      const oldProps = n1.props || EMPTY_OBJ;
      const newProps = n2.props || EMPTY_OBJ;
      let vnodeHook;
      parentComponent && toggleRecurse(parentComponent, false);
      if (vnodeHook = newProps.onVnodeBeforeUpdate) {
        invokeVNodeHook(vnodeHook, parentComponent, n2, n1);
      }
      if (dirs) {
        invokeDirectiveHook(n2, n1, parentComponent, "beforeUpdate");
      }
      parentComponent && toggleRecurse(parentComponent, true);
      const areChildrenSVG = isSVG && n2.type !== "foreignObject";
      if (dynamicChildren) {
        patchBlockChildren(
          n1.dynamicChildren,
          dynamicChildren,
          el,
          parentComponent,
          parentSuspense,
          areChildrenSVG,
          slotScopeIds
        );
      } else if (!optimized) {
        patchChildren(
          n1,
          n2,
          el,
          null,
          parentComponent,
          parentSuspense,
          areChildrenSVG,
          slotScopeIds,
          false
        );
      }
      if (patchFlag > 0) {
        if (patchFlag & 16) {
          patchProps(
            el,
            n2,
            oldProps,
            newProps,
            parentComponent,
            parentSuspense,
            isSVG
          );
        } else {
          if (patchFlag & 2) {
            if (oldProps.class !== newProps.class) {
              hostPatchProp(el, "class", null, newProps.class, isSVG);
            }
          }
          if (patchFlag & 4) {
            hostPatchProp(el, "style", oldProps.style, newProps.style, isSVG);
          }
          if (patchFlag & 8) {
            const propsToUpdate = n2.dynamicProps;
            for (let i = 0; i < propsToUpdate.length; i++) {
              const key = propsToUpdate[i];
              const prev = oldProps[key];
              const next = newProps[key];
              if (next !== prev || key === "value") {
                hostPatchProp(
                  el,
                  key,
                  prev,
                  next,
                  isSVG,
                  n1.children,
                  parentComponent,
                  parentSuspense,
                  unmountChildren
                );
              }
            }
          }
        }
        if (patchFlag & 1) {
          if (n1.children !== n2.children) {
            hostSetElementText(el, n2.children);
          }
        }
      } else if (!optimized && dynamicChildren == null) {
        patchProps(
          el,
          n2,
          oldProps,
          newProps,
          parentComponent,
          parentSuspense,
          isSVG
        );
      }
      if ((vnodeHook = newProps.onVnodeUpdated) || dirs) {
        queuePostRenderEffect(() => {
          vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, n2, n1);
          dirs && invokeDirectiveHook(n2, n1, parentComponent, "updated");
        }, parentSuspense);
      }
    };
    const patchBlockChildren = (oldChildren, newChildren, fallbackContainer, parentComponent, parentSuspense, isSVG, slotScopeIds) => {
      for (let i = 0; i < newChildren.length; i++) {
        const oldVNode = oldChildren[i];
        const newVNode = newChildren[i];
        const container = (
          // oldVNode may be an errored async setup() component inside Suspense
          // which will not have a mounted element
          oldVNode.el && // - In the case of a Fragment, we need to provide the actual parent
          // of the Fragment itself so it can move its children.
          (oldVNode.type === Fragment || // - In the case of different nodes, there is going to be a replacement
          // which also requires the correct parent container
          !isSameVNodeType(oldVNode, newVNode) || // - In the case of a component, it could contain anything.
          oldVNode.shapeFlag & (6 | 64)) ? hostParentNode(oldVNode.el) : (
            // In other cases, the parent container is not actually used so we
            // just pass the block element here to avoid a DOM parentNode call.
            fallbackContainer
          )
        );
        patch(
          oldVNode,
          newVNode,
          container,
          null,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          true
        );
      }
    };
    const patchProps = (el, vnode, oldProps, newProps, parentComponent, parentSuspense, isSVG) => {
      if (oldProps !== newProps) {
        if (oldProps !== EMPTY_OBJ) {
          for (const key in oldProps) {
            if (!isReservedProp(key) && !(key in newProps)) {
              hostPatchProp(
                el,
                key,
                oldProps[key],
                null,
                isSVG,
                vnode.children,
                parentComponent,
                parentSuspense,
                unmountChildren
              );
            }
          }
        }
        for (const key in newProps) {
          if (isReservedProp(key))
            continue;
          const next = newProps[key];
          const prev = oldProps[key];
          if (next !== prev && key !== "value") {
            hostPatchProp(
              el,
              key,
              prev,
              next,
              isSVG,
              vnode.children,
              parentComponent,
              parentSuspense,
              unmountChildren
            );
          }
        }
        if ("value" in newProps) {
          hostPatchProp(el, "value", oldProps.value, newProps.value);
        }
      }
    };
    const processFragment = (n1, n2, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      const fragmentStartAnchor = n2.el = n1 ? n1.el : hostCreateText("");
      const fragmentEndAnchor = n2.anchor = n1 ? n1.anchor : hostCreateText("");
      let { patchFlag, dynamicChildren, slotScopeIds: fragmentSlotScopeIds } = n2;
      if (fragmentSlotScopeIds) {
        slotScopeIds = slotScopeIds ? slotScopeIds.concat(fragmentSlotScopeIds) : fragmentSlotScopeIds;
      }
      if (n1 == null) {
        hostInsert(fragmentStartAnchor, container, anchor);
        hostInsert(fragmentEndAnchor, container, anchor);
        mountChildren(
          n2.children,
          container,
          fragmentEndAnchor,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized
        );
      } else {
        if (patchFlag > 0 && patchFlag & 64 && dynamicChildren && // #2715 the previous fragment could've been a BAILed one as a result
        // of renderSlot() with no valid children
        n1.dynamicChildren) {
          patchBlockChildren(
            n1.dynamicChildren,
            dynamicChildren,
            container,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds
          );
          if (
            // #2080 if the stable fragment has a key, it's a <template v-for> that may
            //  get moved around. Make sure all root level vnodes inherit el.
            // #2134 or if it's a component root, it may also get moved around
            // as the component is being moved.
            n2.key != null || parentComponent && n2 === parentComponent.subTree
          ) {
            traverseStaticChildren(
              n1,
              n2,
              true
              /* shallow */
            );
          }
        } else {
          patchChildren(
            n1,
            n2,
            container,
            fragmentEndAnchor,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
        }
      }
    };
    const processComponent = (n1, n2, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      n2.slotScopeIds = slotScopeIds;
      if (n1 == null) {
        if (n2.shapeFlag & 512) {
          parentComponent.ctx.activate(
            n2,
            container,
            anchor,
            isSVG,
            optimized
          );
        } else {
          mountComponent(
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            isSVG,
            optimized
          );
        }
      } else {
        updateComponent(n1, n2, optimized);
      }
    };
    const mountComponent = (initialVNode, container, anchor, parentComponent, parentSuspense, isSVG, optimized) => {
      const instance = initialVNode.component = createComponentInstance(
        initialVNode,
        parentComponent,
        parentSuspense
      );
      if (isKeepAlive(initialVNode)) {
        instance.ctx.renderer = internals;
      }
      {
        setupComponent(instance);
      }
      if (instance.asyncDep) {
        parentSuspense && parentSuspense.registerDep(instance, setupRenderEffect);
        if (!initialVNode.el) {
          const placeholder = instance.subTree = createVNode(Comment);
          processCommentNode(null, placeholder, container, anchor);
        }
        return;
      }
      setupRenderEffect(
        instance,
        initialVNode,
        container,
        anchor,
        parentSuspense,
        isSVG,
        optimized
      );
    };
    const updateComponent = (n1, n2, optimized) => {
      const instance = n2.component = n1.component;
      if (shouldUpdateComponent(n1, n2, optimized)) {
        if (instance.asyncDep && !instance.asyncResolved) {
          updateComponentPreRender(instance, n2, optimized);
          return;
        } else {
          instance.next = n2;
          invalidateJob(instance.update);
          instance.update();
        }
      } else {
        n2.el = n1.el;
        instance.vnode = n2;
      }
    };
    const setupRenderEffect = (instance, initialVNode, container, anchor, parentSuspense, isSVG, optimized) => {
      const componentUpdateFn = () => {
        if (!instance.isMounted) {
          let vnodeHook;
          const { el, props } = initialVNode;
          const { bm, m, parent } = instance;
          const isAsyncWrapperVNode = isAsyncWrapper(initialVNode);
          toggleRecurse(instance, false);
          if (bm) {
            invokeArrayFns(bm);
          }
          if (!isAsyncWrapperVNode && (vnodeHook = props && props.onVnodeBeforeMount)) {
            invokeVNodeHook(vnodeHook, parent, initialVNode);
          }
          toggleRecurse(instance, true);
          if (el && hydrateNode) {
            const hydrateSubTree = () => {
              instance.subTree = renderComponentRoot(instance);
              hydrateNode(
                el,
                instance.subTree,
                instance,
                parentSuspense,
                null
              );
            };
            if (isAsyncWrapperVNode) {
              initialVNode.type.__asyncLoader().then(
                // note: we are moving the render call into an async callback,
                // which means it won't track dependencies - but it's ok because
                // a server-rendered async wrapper is already in resolved state
                // and it will never need to change.
                () => !instance.isUnmounted && hydrateSubTree()
              );
            } else {
              hydrateSubTree();
            }
          } else {
            const subTree = instance.subTree = renderComponentRoot(instance);
            if (instance && instance.parent) {
              if (!(instance.parent.type.__asyncLoader && instance.parent.isCE)) {
                const styles = instance.isCEChild && instance.type.styles || null;
                if (instance.addCEChildStyle && styles) {
                  instance.addCEChildStyle(styles, instance);
                }
              }
            }
            patch(
              null,
              subTree,
              container,
              anchor,
              instance,
              parentSuspense,
              isSVG
            );
            initialVNode.el = subTree.el;
          }
          if (m) {
            queuePostRenderEffect(m, parentSuspense);
          }
          if (!isAsyncWrapperVNode && (vnodeHook = props && props.onVnodeMounted)) {
            const scopedInitialVNode = initialVNode;
            queuePostRenderEffect(
              () => invokeVNodeHook(vnodeHook, parent, scopedInitialVNode),
              parentSuspense
            );
          }
          if (initialVNode.shapeFlag & 256 || parent && isAsyncWrapper(parent.vnode) && parent.vnode.shapeFlag & 256) {
            instance.a && queuePostRenderEffect(instance.a, parentSuspense);
          }
          instance.isMounted = true;
          initialVNode = container = anchor = null;
        } else {
          let { next, bu, u, parent, vnode } = instance;
          let originNext = next;
          let vnodeHook;
          toggleRecurse(instance, false);
          if (next) {
            next.el = vnode.el;
            updateComponentPreRender(instance, next, optimized);
          } else {
            next = vnode;
          }
          if (bu) {
            invokeArrayFns(bu);
          }
          if (vnodeHook = next.props && next.props.onVnodeBeforeUpdate) {
            invokeVNodeHook(vnodeHook, parent, next, vnode);
          }
          toggleRecurse(instance, true);
          const nextTree = renderComponentRoot(instance);
          const prevTree = instance.subTree;
          instance.subTree = nextTree;
          patch(
            prevTree,
            nextTree,
            // parent may have changed if it's in a teleport
            hostParentNode(prevTree.el),
            // anchor may have changed if it's in a fragment
            getNextHostNode(prevTree),
            instance,
            parentSuspense,
            isSVG
          );
          next.el = nextTree.el;
          if (originNext === null) {
            updateHOCHostEl(instance, nextTree.el);
          }
          if (u) {
            queuePostRenderEffect(u, parentSuspense);
          }
          if (vnodeHook = next.props && next.props.onVnodeUpdated) {
            queuePostRenderEffect(
              () => invokeVNodeHook(vnodeHook, parent, next, vnode),
              parentSuspense
            );
          }
        }
      };
      const effect = instance.effect = new ReactiveEffect(
        componentUpdateFn,
        () => queueJob(update),
        instance.scope
        // track it in component's effect scope
      );
      const update = instance.update = () => effect.run();
      update.id = instance.uid;
      toggleRecurse(instance, true);
      update();
    };
    const updateComponentPreRender = (instance, nextVNode, optimized) => {
      nextVNode.component = instance;
      const prevProps = instance.vnode.props;
      instance.vnode = nextVNode;
      instance.next = null;
      updateProps(instance, nextVNode.props, prevProps, optimized);
      updateSlots(instance, nextVNode.children, optimized);
      pauseTracking();
      flushPreFlushCbs();
      resetTracking();
    };
    const patchChildren = (n1, n2, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized = false) => {
      const c1 = n1 && n1.children;
      const prevShapeFlag = n1 ? n1.shapeFlag : 0;
      const c2 = n2.children;
      const { patchFlag, shapeFlag } = n2;
      if (patchFlag > 0) {
        if (patchFlag & 128) {
          patchKeyedChildren(
            c1,
            c2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
          return;
        } else if (patchFlag & 256) {
          patchUnkeyedChildren(
            c1,
            c2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
          return;
        }
      }
      if (shapeFlag & 8) {
        if (prevShapeFlag & 16) {
          unmountChildren(c1, parentComponent, parentSuspense);
        }
        if (c2 !== c1) {
          hostSetElementText(container, c2);
        }
      } else {
        if (prevShapeFlag & 16) {
          if (shapeFlag & 16) {
            patchKeyedChildren(
              c1,
              c2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
          } else {
            unmountChildren(c1, parentComponent, parentSuspense, true);
          }
        } else {
          if (prevShapeFlag & 8) {
            hostSetElementText(container, "");
          }
          if (shapeFlag & 16) {
            mountChildren(
              c2,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
          }
        }
      }
    };
    const patchUnkeyedChildren = (c1, c2, container, anchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      c1 = c1 || EMPTY_ARR;
      c2 = c2 || EMPTY_ARR;
      const oldLength = c1.length;
      const newLength = c2.length;
      const commonLength = Math.min(oldLength, newLength);
      let i;
      for (i = 0; i < commonLength; i++) {
        const nextChild = c2[i] = optimized ? cloneIfMounted(c2[i]) : normalizeVNode(c2[i]);
        patch(
          c1[i],
          nextChild,
          container,
          null,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized
        );
      }
      if (oldLength > newLength) {
        unmountChildren(
          c1,
          parentComponent,
          parentSuspense,
          true,
          false,
          commonLength
        );
      } else {
        mountChildren(
          c2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          isSVG,
          slotScopeIds,
          optimized,
          commonLength
        );
      }
    };
    const patchKeyedChildren = (c1, c2, container, parentAnchor, parentComponent, parentSuspense, isSVG, slotScopeIds, optimized) => {
      let i = 0;
      const l2 = c2.length;
      let e1 = c1.length - 1;
      let e2 = l2 - 1;
      while (i <= e1 && i <= e2) {
        const n1 = c1[i];
        const n2 = c2[i] = optimized ? cloneIfMounted(c2[i]) : normalizeVNode(c2[i]);
        if (isSameVNodeType(n1, n2)) {
          patch(
            n1,
            n2,
            container,
            null,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
        } else {
          break;
        }
        i++;
      }
      while (i <= e1 && i <= e2) {
        const n1 = c1[e1];
        const n2 = c2[e2] = optimized ? cloneIfMounted(c2[e2]) : normalizeVNode(c2[e2]);
        if (isSameVNodeType(n1, n2)) {
          patch(
            n1,
            n2,
            container,
            null,
            parentComponent,
            parentSuspense,
            isSVG,
            slotScopeIds,
            optimized
          );
        } else {
          break;
        }
        e1--;
        e2--;
      }
      if (i > e1) {
        if (i <= e2) {
          const nextPos = e2 + 1;
          const anchor = nextPos < l2 ? c2[nextPos].el : parentAnchor;
          while (i <= e2) {
            patch(
              null,
              c2[i] = optimized ? cloneIfMounted(c2[i]) : normalizeVNode(c2[i]),
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
            i++;
          }
        }
      } else if (i > e2) {
        while (i <= e1) {
          unmount(c1[i], parentComponent, parentSuspense, true);
          i++;
        }
      } else {
        const s1 = i;
        const s2 = i;
        const keyToNewIndexMap = /* @__PURE__ */ new Map();
        for (i = s2; i <= e2; i++) {
          const nextChild = c2[i] = optimized ? cloneIfMounted(c2[i]) : normalizeVNode(c2[i]);
          if (nextChild.key != null) {
            keyToNewIndexMap.set(nextChild.key, i);
          }
        }
        let j;
        let patched = 0;
        const toBePatched = e2 - s2 + 1;
        let moved = false;
        let maxNewIndexSoFar = 0;
        const newIndexToOldIndexMap = new Array(toBePatched);
        for (i = 0; i < toBePatched; i++)
          newIndexToOldIndexMap[i] = 0;
        for (i = s1; i <= e1; i++) {
          const prevChild = c1[i];
          if (patched >= toBePatched) {
            unmount(prevChild, parentComponent, parentSuspense, true);
            continue;
          }
          let newIndex;
          if (prevChild.key != null) {
            newIndex = keyToNewIndexMap.get(prevChild.key);
          } else {
            for (j = s2; j <= e2; j++) {
              if (newIndexToOldIndexMap[j - s2] === 0 && isSameVNodeType(prevChild, c2[j])) {
                newIndex = j;
                break;
              }
            }
          }
          if (newIndex === void 0) {
            unmount(prevChild, parentComponent, parentSuspense, true);
          } else {
            newIndexToOldIndexMap[newIndex - s2] = i + 1;
            if (newIndex >= maxNewIndexSoFar) {
              maxNewIndexSoFar = newIndex;
            } else {
              moved = true;
            }
            patch(
              prevChild,
              c2[newIndex],
              container,
              null,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
            patched++;
          }
        }
        const increasingNewIndexSequence = moved ? getSequence(newIndexToOldIndexMap) : EMPTY_ARR;
        j = increasingNewIndexSequence.length - 1;
        for (i = toBePatched - 1; i >= 0; i--) {
          const nextIndex = s2 + i;
          const nextChild = c2[nextIndex];
          const anchor = nextIndex + 1 < l2 ? c2[nextIndex + 1].el : parentAnchor;
          if (newIndexToOldIndexMap[i] === 0) {
            patch(
              null,
              nextChild,
              container,
              anchor,
              parentComponent,
              parentSuspense,
              isSVG,
              slotScopeIds,
              optimized
            );
          } else if (moved) {
            if (j < 0 || i !== increasingNewIndexSequence[j]) {
              move(nextChild, container, anchor, 2);
            } else {
              j--;
            }
          }
        }
      }
    };
    const move = (vnode, container, anchor, moveType, parentSuspense = null) => {
      const { el, type, transition, children, shapeFlag } = vnode;
      if (shapeFlag & 6) {
        move(vnode.component.subTree, container, anchor, moveType);
        return;
      }
      if (shapeFlag & 128) {
        vnode.suspense.move(container, anchor, moveType);
        return;
      }
      if (shapeFlag & 64) {
        type.move(vnode, container, anchor, internals);
        return;
      }
      if (type === Fragment) {
        hostInsert(el, container, anchor);
        for (let i = 0; i < children.length; i++) {
          move(children[i], container, anchor, moveType);
        }
        hostInsert(vnode.anchor, container, anchor);
        return;
      }
      if (type === Static) {
        moveStaticNode(vnode, container, anchor);
        return;
      }
      const needTransition2 = moveType !== 2 && shapeFlag & 1 && transition;
      if (needTransition2) {
        if (moveType === 0) {
          transition.beforeEnter(el);
          hostInsert(el, container, anchor);
          queuePostRenderEffect(() => transition.enter(el), parentSuspense);
        } else {
          const { leave, delayLeave, afterLeave } = transition;
          const remove22 = () => hostInsert(el, container, anchor);
          const performLeave = () => {
            leave(el, () => {
              remove22();
              afterLeave && afterLeave();
            });
          };
          if (delayLeave) {
            delayLeave(el, remove22, performLeave);
          } else {
            performLeave();
          }
        }
      } else {
        hostInsert(el, container, anchor);
      }
    };
    const unmount = (vnode, parentComponent, parentSuspense, doRemove = false, optimized = false) => {
      const {
        type,
        props,
        ref: ref2,
        children,
        dynamicChildren,
        shapeFlag,
        patchFlag,
        dirs
      } = vnode;
      if (ref2 != null) {
        setRef(ref2, null, parentSuspense, vnode, true);
      }
      if (shapeFlag & 256) {
        parentComponent.ctx.deactivate(vnode);
        return;
      }
      const shouldInvokeDirs = shapeFlag & 1 && dirs;
      const shouldInvokeVnodeHook = !isAsyncWrapper(vnode);
      let vnodeHook;
      if (shouldInvokeVnodeHook && (vnodeHook = props && props.onVnodeBeforeUnmount)) {
        invokeVNodeHook(vnodeHook, parentComponent, vnode);
      }
      if (shapeFlag & 6) {
        if (vnode.component.isCEChild && vnode.component.removeCEChildStyle) {
          vnode.component.removeCEChildStyle(
            vnode.component.type.styles,
            vnode.component.uid
          );
        }
        unmountComponent(vnode.component, parentSuspense, doRemove);
      } else {
        if (shapeFlag & 128) {
          vnode.suspense.unmount(parentSuspense, doRemove);
          return;
        }
        if (shouldInvokeDirs) {
          invokeDirectiveHook(vnode, null, parentComponent, "beforeUnmount");
        }
        if (shapeFlag & 64) {
          vnode.type.remove(
            vnode,
            parentComponent,
            parentSuspense,
            optimized,
            internals,
            doRemove
          );
        } else if (dynamicChildren && // #1153: fast path should not be taken for non-stable (v-for) fragments
        (type !== Fragment || patchFlag > 0 && patchFlag & 64)) {
          unmountChildren(
            dynamicChildren,
            parentComponent,
            parentSuspense,
            false,
            true
          );
        } else if (type === Fragment && patchFlag & (128 | 256) || !optimized && shapeFlag & 16) {
          unmountChildren(children, parentComponent, parentSuspense);
        }
        if (doRemove) {
          remove2(vnode);
        }
      }
      if (shouldInvokeVnodeHook && (vnodeHook = props && props.onVnodeUnmounted) || shouldInvokeDirs) {
        queuePostRenderEffect(() => {
          vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, vnode);
          shouldInvokeDirs && invokeDirectiveHook(vnode, null, parentComponent, "unmounted");
        }, parentSuspense);
      }
    };
    const remove2 = (vnode) => {
      const { type, el, anchor, transition } = vnode;
      if (type === Fragment) {
        {
          removeFragment(el, anchor);
        }
        return;
      }
      if (type === Static) {
        removeStaticNode(vnode);
        return;
      }
      const performRemove = () => {
        hostRemove(el);
        if (transition && !transition.persisted && transition.afterLeave) {
          transition.afterLeave();
        }
      };
      if (vnode.shapeFlag & 1 && transition && !transition.persisted) {
        const { leave, delayLeave } = transition;
        const performLeave = () => leave(el, performRemove);
        if (delayLeave) {
          delayLeave(vnode.el, performRemove, performLeave);
        } else {
          performLeave();
        }
      } else {
        performRemove();
      }
    };
    const removeFragment = (cur, end) => {
      let next;
      while (cur !== end) {
        next = hostNextSibling(cur);
        hostRemove(cur);
        cur = next;
      }
      hostRemove(end);
    };
    const unmountComponent = (instance, parentSuspense, doRemove) => {
      const { bum, scope, update, subTree, um } = instance;
      if (bum) {
        invokeArrayFns(bum);
      }
      scope.stop();
      if (update) {
        update.active = false;
        unmount(subTree, instance, parentSuspense, doRemove);
      }
      if (um) {
        queuePostRenderEffect(um, parentSuspense);
      }
      queuePostRenderEffect(() => {
        instance.isUnmounted = true;
      }, parentSuspense);
      if (parentSuspense && parentSuspense.pendingBranch && !parentSuspense.isUnmounted && instance.asyncDep && !instance.asyncResolved && instance.suspenseId === parentSuspense.pendingId) {
        parentSuspense.deps--;
        if (parentSuspense.deps === 0) {
          parentSuspense.resolve();
        }
      }
    };
    const unmountChildren = (children, parentComponent, parentSuspense, doRemove = false, optimized = false, start = 0) => {
      for (let i = start; i < children.length; i++) {
        unmount(children[i], parentComponent, parentSuspense, doRemove, optimized);
      }
    };
    const getNextHostNode = (vnode) => {
      if (vnode.shapeFlag & 6) {
        return getNextHostNode(vnode.component.subTree);
      }
      if (vnode.shapeFlag & 128) {
        return vnode.suspense.next();
      }
      return hostNextSibling(vnode.anchor || vnode.el);
    };
    const render2 = (vnode, container, isSVG) => {
      if (vnode == null) {
        if (container._vnode) {
          unmount(container._vnode, null, null, true);
        }
      } else {
        patch(container._vnode || null, vnode, container, null, null, null, isSVG);
      }
      flushPreFlushCbs();
      flushPostFlushCbs();
      container._vnode = vnode;
    };
    const internals = {
      p: patch,
      um: unmount,
      m: move,
      r: remove2,
      mt: mountComponent,
      mc: mountChildren,
      pc: patchChildren,
      pbc: patchBlockChildren,
      n: getNextHostNode,
      o: options
    };
    let hydrate;
    let hydrateNode;
    if (createHydrationFns) {
      [hydrate, hydrateNode] = createHydrationFns(
        internals
      );
    }
    return {
      render: render2,
      hydrate,
      createApp: createAppAPI(render2, hydrate)
    };
  }
  function toggleRecurse({ effect, update }, allowed) {
    effect.allowRecurse = update.allowRecurse = allowed;
  }
  function needTransition(parentSuspense, transition) {
    return (!parentSuspense || parentSuspense && !parentSuspense.pendingBranch) && transition && !transition.persisted;
  }
  function traverseStaticChildren(n1, n2, shallow = false) {
    const ch1 = n1.children;
    const ch2 = n2.children;
    if (isArray(ch1) && isArray(ch2)) {
      for (let i = 0; i < ch1.length; i++) {
        const c1 = ch1[i];
        let c2 = ch2[i];
        if (c2.shapeFlag & 1 && !c2.dynamicChildren) {
          if (c2.patchFlag <= 0 || c2.patchFlag === 32) {
            c2 = ch2[i] = cloneIfMounted(ch2[i]);
            c2.el = c1.el;
          }
          if (!shallow)
            traverseStaticChildren(c1, c2);
        }
        if (c2.type === Text) {
          c2.el = c1.el;
        }
      }
    }
  }
  function getSequence(arr) {
    const p2 = arr.slice();
    const result = [0];
    let i, j, u, v, c;
    const len = arr.length;
    for (i = 0; i < len; i++) {
      const arrI = arr[i];
      if (arrI !== 0) {
        j = result[result.length - 1];
        if (arr[j] < arrI) {
          p2[i] = j;
          result.push(i);
          continue;
        }
        u = 0;
        v = result.length - 1;
        while (u < v) {
          c = u + v >> 1;
          if (arr[result[c]] < arrI) {
            u = c + 1;
          } else {
            v = c;
          }
        }
        if (arrI < arr[result[u]]) {
          if (u > 0) {
            p2[i] = result[u - 1];
          }
          result[u] = i;
        }
      }
    }
    u = result.length;
    v = result[u - 1];
    while (u-- > 0) {
      result[u] = v;
      v = p2[v];
    }
    return result;
  }
  const isTeleport = (type) => type.__isTeleport;
  const Fragment = Symbol.for("v-fgt");
  const Text = Symbol.for("v-txt");
  const Comment = Symbol.for("v-cmt");
  const Static = Symbol.for("v-stc");
  const blockStack = [];
  let currentBlock = null;
  function openBlock(disableTracking = false) {
    blockStack.push(currentBlock = disableTracking ? null : []);
  }
  function closeBlock() {
    blockStack.pop();
    currentBlock = blockStack[blockStack.length - 1] || null;
  }
  let isBlockTreeEnabled = 1;
  function setBlockTracking(value) {
    isBlockTreeEnabled += value;
  }
  function setupBlock(vnode) {
    vnode.dynamicChildren = isBlockTreeEnabled > 0 ? currentBlock || EMPTY_ARR : null;
    closeBlock();
    if (isBlockTreeEnabled > 0 && currentBlock) {
      currentBlock.push(vnode);
    }
    return vnode;
  }
  function createElementBlock(type, props, children, patchFlag, dynamicProps, shapeFlag) {
    return setupBlock(
      createBaseVNode(
        type,
        props,
        children,
        patchFlag,
        dynamicProps,
        shapeFlag,
        true
        /* isBlock */
      )
    );
  }
  function createBlock(type, props, children, patchFlag, dynamicProps) {
    return setupBlock(
      createVNode(
        type,
        props,
        children,
        patchFlag,
        dynamicProps,
        true
        /* isBlock: prevent a block from tracking itself */
      )
    );
  }
  function isVNode(value) {
    return value ? value.__v_isVNode === true : false;
  }
  function isSameVNodeType(n1, n2) {
    return n1.type === n2.type && n1.key === n2.key;
  }
  const InternalObjectKey = `__vInternal`;
  const normalizeKey = ({ key }) => key != null ? key : null;
  const normalizeRef = ({
    ref: ref2,
    ref_key,
    ref_for
  }) => {
    if (typeof ref2 === "number") {
      ref2 = "" + ref2;
    }
    return ref2 != null ? isString(ref2) || isRef(ref2) || isFunction(ref2) ? { i: currentRenderingInstance, r: ref2, k: ref_key, f: !!ref_for } : ref2 : null;
  };
  function createBaseVNode(type, props = null, children = null, patchFlag = 0, dynamicProps = null, shapeFlag = type === Fragment ? 0 : 1, isBlockNode = false, needFullChildrenNormalization = false) {
    const vnode = {
      __v_isVNode: true,
      __v_skip: true,
      type,
      props,
      key: props && normalizeKey(props),
      ref: props && normalizeRef(props),
      scopeId: currentScopeId,
      slotScopeIds: null,
      children,
      component: null,
      suspense: null,
      ssContent: null,
      ssFallback: null,
      dirs: null,
      transition: null,
      el: null,
      anchor: null,
      target: null,
      targetAnchor: null,
      staticCount: 0,
      shapeFlag,
      patchFlag,
      dynamicProps,
      dynamicChildren: null,
      appContext: null,
      ctx: currentRenderingInstance
    };
    if (needFullChildrenNormalization) {
      normalizeChildren(vnode, children);
      if (shapeFlag & 128) {
        type.normalize(vnode);
      }
    } else if (children) {
      vnode.shapeFlag |= isString(children) ? 8 : 16;
    }
    if (isBlockTreeEnabled > 0 && // avoid a block node from tracking itself
    !isBlockNode && // has current parent block
    currentBlock && // presence of a patch flag indicates this node needs patching on updates.
    // component nodes also should always be patched, because even if the
    // component doesn't need to update, it needs to persist the instance on to
    // the next vnode so that it can be properly unmounted later.
    (vnode.patchFlag > 0 || shapeFlag & 6) && // the EVENTS flag is only for hydration and if it is the only flag, the
    // vnode should not be considered dynamic due to handler caching.
    vnode.patchFlag !== 32) {
      currentBlock.push(vnode);
    }
    return vnode;
  }
  const createVNode = _createVNode;
  function _createVNode(type, props = null, children = null, patchFlag = 0, dynamicProps = null, isBlockNode = false) {
    if (!type || type === NULL_DYNAMIC_COMPONENT) {
      type = Comment;
    }
    if (isVNode(type)) {
      const cloned = cloneVNode(
        type,
        props,
        true
        /* mergeRef: true */
      );
      if (children) {
        normalizeChildren(cloned, children);
      }
      if (isBlockTreeEnabled > 0 && !isBlockNode && currentBlock) {
        if (cloned.shapeFlag & 6) {
          currentBlock[currentBlock.indexOf(type)] = cloned;
        } else {
          currentBlock.push(cloned);
        }
      }
      cloned.patchFlag |= -2;
      return cloned;
    }
    if (isClassComponent(type)) {
      type = type.__vccOpts;
    }
    if (props) {
      props = guardReactiveProps(props);
      let { class: klass, style } = props;
      if (klass && !isString(klass)) {
        props.class = normalizeClass(klass);
      }
      if (isObject(style)) {
        if (isProxy(style) && !isArray(style)) {
          style = extend({}, style);
        }
        props.style = normalizeStyle(style);
      }
    }
    const shapeFlag = isString(type) ? 1 : isSuspense(type) ? 128 : isTeleport(type) ? 64 : isObject(type) ? 4 : isFunction(type) ? 2 : 0;
    return createBaseVNode(
      type,
      props,
      children,
      patchFlag,
      dynamicProps,
      shapeFlag,
      isBlockNode,
      true
    );
  }
  function guardReactiveProps(props) {
    if (!props)
      return null;
    return isProxy(props) || InternalObjectKey in props ? extend({}, props) : props;
  }
  function cloneVNode(vnode, extraProps, mergeRef = false) {
    const { props, ref: ref2, patchFlag, children } = vnode;
    const mergedProps = extraProps ? mergeProps(props || {}, extraProps) : props;
    const cloned = {
      __v_isVNode: true,
      __v_skip: true,
      type: vnode.type,
      props: mergedProps,
      key: mergedProps && normalizeKey(mergedProps),
      ref: extraProps && extraProps.ref ? (
        // #2078 in the case of <component :is="vnode" ref="extra"/>
        // if the vnode itself already has a ref, cloneVNode will need to merge
        // the refs so the single vnode can be set on multiple refs
        mergeRef && ref2 ? isArray(ref2) ? ref2.concat(normalizeRef(extraProps)) : [ref2, normalizeRef(extraProps)] : normalizeRef(extraProps)
      ) : ref2,
      scopeId: vnode.scopeId,
      slotScopeIds: vnode.slotScopeIds,
      children,
      target: vnode.target,
      targetAnchor: vnode.targetAnchor,
      staticCount: vnode.staticCount,
      shapeFlag: vnode.shapeFlag,
      // if the vnode is cloned with extra props, we can no longer assume its
      // existing patch flag to be reliable and need to add the FULL_PROPS flag.
      // note: preserve flag for fragments since they use the flag for children
      // fast paths only.
      patchFlag: extraProps && vnode.type !== Fragment ? patchFlag === -1 ? 16 : patchFlag | 16 : patchFlag,
      dynamicProps: vnode.dynamicProps,
      dynamicChildren: vnode.dynamicChildren,
      appContext: vnode.appContext,
      dirs: vnode.dirs,
      transition: vnode.transition,
      // These should technically only be non-null on mounted VNodes. However,
      // they *should* be copied for kept-alive vnodes. So we just always copy
      // them since them being non-null during a mount doesn't affect the logic as
      // they will simply be overwritten.
      component: vnode.component,
      suspense: vnode.suspense,
      ssContent: vnode.ssContent && cloneVNode(vnode.ssContent),
      ssFallback: vnode.ssFallback && cloneVNode(vnode.ssFallback),
      el: vnode.el,
      anchor: vnode.anchor,
      ctx: vnode.ctx,
      ce: vnode.ce
    };
    return cloned;
  }
  function createTextVNode(text = " ", flag = 0) {
    return createVNode(Text, null, text, flag);
  }
  function createStaticVNode(content, numberOfNodes) {
    const vnode = createVNode(Static, null, content);
    vnode.staticCount = numberOfNodes;
    return vnode;
  }
  function createCommentVNode(text = "", asBlock = false) {
    return asBlock ? (openBlock(), createBlock(Comment, null, text)) : createVNode(Comment, null, text);
  }
  function normalizeVNode(child) {
    if (child == null || typeof child === "boolean") {
      return createVNode(Comment);
    } else if (isArray(child)) {
      return createVNode(
        Fragment,
        null,
        // #3666, avoid reference pollution when reusing vnode
        child.slice()
      );
    } else if (typeof child === "object") {
      return cloneIfMounted(child);
    } else {
      return createVNode(Text, null, String(child));
    }
  }
  function cloneIfMounted(child) {
    return child.el === null && child.patchFlag !== -1 || child.memo ? child : cloneVNode(child);
  }
  function normalizeChildren(vnode, children) {
    let type = 0;
    const { shapeFlag } = vnode;
    if (children == null) {
      children = null;
    } else if (isArray(children)) {
      type = 16;
    } else if (typeof children === "object") {
      if (shapeFlag & (1 | 64)) {
        const slot = children.default;
        if (slot) {
          slot._c && (slot._d = false);
          normalizeChildren(vnode, slot());
          slot._c && (slot._d = true);
        }
        return;
      } else {
        type = 32;
        const slotFlag = children._;
        if (!slotFlag && !(InternalObjectKey in children)) {
          children._ctx = currentRenderingInstance;
        } else if (slotFlag === 3 && currentRenderingInstance) {
          if (currentRenderingInstance.slots._ === 1) {
            children._ = 1;
          } else {
            children._ = 2;
            vnode.patchFlag |= 1024;
          }
        }
      }
    } else if (isFunction(children)) {
      children = { default: children, _ctx: currentRenderingInstance };
      type = 32;
    } else {
      children = String(children);
      if (shapeFlag & 64) {
        type = 16;
        children = [createTextVNode(children)];
      } else {
        type = 8;
      }
    }
    vnode.children = children;
    vnode.shapeFlag |= type;
  }
  function mergeProps(...args) {
    const ret = {};
    for (let i = 0; i < args.length; i++) {
      const toMerge = args[i];
      for (const key in toMerge) {
        if (key === "class") {
          if (ret.class !== toMerge.class) {
            ret.class = normalizeClass([ret.class, toMerge.class]);
          }
        } else if (key === "style") {
          ret.style = normalizeStyle([ret.style, toMerge.style]);
        } else if (isOn(key)) {
          const existing = ret[key];
          const incoming = toMerge[key];
          if (incoming && existing !== incoming && !(isArray(existing) && existing.includes(incoming))) {
            ret[key] = existing ? [].concat(existing, incoming) : incoming;
          }
        } else if (key !== "") {
          ret[key] = toMerge[key];
        }
      }
    }
    return ret;
  }
  function invokeVNodeHook(hook, instance, vnode, prevVNode = null) {
    callWithAsyncErrorHandling(hook, instance, 7, [
      vnode,
      prevVNode
    ]);
  }
  const emptyAppContext = createAppContext();
  let uid = 0;
  function createComponentInstance(vnode, parent, suspense) {
    const type = vnode.type;
    const appContext = (parent ? parent.appContext : vnode.appContext) || emptyAppContext;
    const instance = {
      isCEChild: parent && (parent.isCE || parent.isCEChild),
      addCEChildStyle: parent && parent.addCEChildStyle ? parent.addCEChildStyle : null,
      removeCEChildStyle: parent && parent.removeCEChildStyle ? parent.removeCEChildStyle : null,
      cecStyleIds: null,
      uid: uid++,
      vnode,
      type,
      parent,
      appContext,
      root: null,
      // to be immediately set
      next: null,
      subTree: null,
      // will be set synchronously right after creation
      effect: null,
      update: null,
      // will be set synchronously right after creation
      scope: new EffectScope(
        true
        /* detached */
      ),
      render: null,
      proxy: null,
      exposed: null,
      exposeProxy: null,
      withProxy: null,
      provides: parent ? parent.provides : Object.create(appContext.provides),
      accessCache: null,
      renderCache: [],
      // local resolved assets
      components: null,
      directives: null,
      // resolved props and emits options
      propsOptions: normalizePropsOptions(type, appContext),
      emitsOptions: normalizeEmitsOptions(type, appContext),
      // emit
      emit: null,
      // to be set immediately
      emitted: null,
      // props default value
      propsDefaults: EMPTY_OBJ,
      // inheritAttrs
      inheritAttrs: type.inheritAttrs,
      // state
      ctx: EMPTY_OBJ,
      data: EMPTY_OBJ,
      props: EMPTY_OBJ,
      attrs: EMPTY_OBJ,
      slots: EMPTY_OBJ,
      refs: EMPTY_OBJ,
      setupState: EMPTY_OBJ,
      setupContext: null,
      attrsProxy: null,
      slotsProxy: null,
      // suspense related
      suspense,
      suspenseId: suspense ? suspense.pendingId : 0,
      asyncDep: null,
      asyncResolved: false,
      // lifecycle hooks
      // not using enums here because it results in computed properties
      isMounted: false,
      isUnmounted: false,
      isDeactivated: false,
      bc: null,
      c: null,
      bm: null,
      m: null,
      bu: null,
      u: null,
      um: null,
      bum: null,
      da: null,
      a: null,
      rtg: null,
      rtc: null,
      ec: null,
      sp: null
    };
    {
      instance.ctx = { _: instance };
    }
    instance.root = parent ? parent.root : instance;
    instance.emit = emit.bind(null, instance);
    if (vnode.ce) {
      vnode.ce(instance);
    }
    return instance;
  }
  let currentInstance = null;
  let internalSetCurrentInstance;
  let globalCurrentInstanceSetters;
  let settersKey = "__VUE_INSTANCE_SETTERS__";
  {
    if (!(globalCurrentInstanceSetters = getGlobalThis()[settersKey])) {
      globalCurrentInstanceSetters = getGlobalThis()[settersKey] = [];
    }
    globalCurrentInstanceSetters.push((i) => currentInstance = i);
    internalSetCurrentInstance = (instance) => {
      if (globalCurrentInstanceSetters.length > 1) {
        globalCurrentInstanceSetters.forEach((s) => s(instance));
      } else {
        globalCurrentInstanceSetters[0](instance);
      }
    };
  }
  const setCurrentInstance = (instance) => {
    internalSetCurrentInstance(instance);
    instance.scope.on();
  };
  const unsetCurrentInstance = () => {
    currentInstance && currentInstance.scope.off();
    internalSetCurrentInstance(null);
  };
  function isStatefulComponent(instance) {
    return instance.vnode.shapeFlag & 4;
  }
  let isInSSRComponentSetup = false;
  function setupComponent(instance, isSSR = false) {
    isInSSRComponentSetup = isSSR;
    const { props, children } = instance.vnode;
    const isStateful = isStatefulComponent(instance);
    initProps(instance, props, isStateful, isSSR);
    initSlots(instance, children);
    const setupResult = isStateful ? setupStatefulComponent(instance, isSSR) : void 0;
    isInSSRComponentSetup = false;
    return setupResult;
  }
  function setupStatefulComponent(instance, isSSR) {
    const Component = instance.type;
    instance.accessCache = /* @__PURE__ */ Object.create(null);
    instance.proxy = markRaw(new Proxy(instance.ctx, PublicInstanceProxyHandlers));
    const { setup } = Component;
    if (setup) {
      const setupContext = instance.setupContext = setup.length > 1 ? createSetupContext(instance) : null;
      setCurrentInstance(instance);
      pauseTracking();
      const setupResult = callWithErrorHandling(
        setup,
        instance,
        0,
        [instance.props, setupContext]
      );
      resetTracking();
      unsetCurrentInstance();
      if (isPromise(setupResult)) {
        setupResult.then(unsetCurrentInstance, unsetCurrentInstance);
        if (isSSR) {
          return setupResult.then((resolvedResult) => {
            handleSetupResult(instance, resolvedResult, isSSR);
          }).catch((e) => {
            handleError(e, instance, 0);
          });
        } else {
          instance.asyncDep = setupResult;
        }
      } else {
        handleSetupResult(instance, setupResult, isSSR);
      }
    } else {
      finishComponentSetup(instance, isSSR);
    }
  }
  function handleSetupResult(instance, setupResult, isSSR) {
    if (isFunction(setupResult)) {
      if (instance.type.__ssrInlineRender) {
        instance.ssrRender = setupResult;
      } else {
        instance.render = setupResult;
      }
    } else if (isObject(setupResult)) {
      instance.setupState = proxyRefs(setupResult);
    } else
      ;
    finishComponentSetup(instance, isSSR);
  }
  let compile;
  function finishComponentSetup(instance, isSSR, skipOptions) {
    const Component = instance.type;
    if (!instance.render) {
      if (!isSSR && compile && !Component.render) {
        const template = Component.template || resolveMergedOptions(instance).template;
        if (template) {
          const { isCustomElement, compilerOptions } = instance.appContext.config;
          const { delimiters, compilerOptions: componentCompilerOptions } = Component;
          const finalCompilerOptions = extend(
            extend(
              {
                isCustomElement,
                delimiters
              },
              compilerOptions
            ),
            componentCompilerOptions
          );
          Component.render = compile(template, finalCompilerOptions);
        }
      }
      instance.render = Component.render || NOOP;
    }
    {
      setCurrentInstance(instance);
      pauseTracking();
      try {
        applyOptions(instance);
      } finally {
        resetTracking();
        unsetCurrentInstance();
      }
    }
  }
  function getAttrsProxy(instance) {
    return instance.attrsProxy || (instance.attrsProxy = new Proxy(
      instance.attrs,
      {
        get(target, key) {
          track(instance, "get", "$attrs");
          return target[key];
        }
      }
    ));
  }
  function createSetupContext(instance) {
    const expose = (exposed) => {
      instance.exposed = exposed || {};
    };
    {
      return {
        get attrs() {
          return getAttrsProxy(instance);
        },
        slots: instance.slots,
        emit: instance.emit,
        expose
      };
    }
  }
  function getExposeProxy(instance) {
    if (instance.exposed) {
      return instance.exposeProxy || (instance.exposeProxy = new Proxy(proxyRefs(markRaw(instance.exposed)), {
        get(target, key) {
          if (key in target) {
            return target[key];
          } else if (key in publicPropertiesMap) {
            return publicPropertiesMap[key](instance);
          }
        },
        has(target, key) {
          return key in target || key in publicPropertiesMap;
        }
      }));
    }
  }
  function isClassComponent(value) {
    return isFunction(value) && "__vccOpts" in value;
  }
  const computed = (getterOrOptions, debugOptions) => {
    return computed$1(getterOrOptions, debugOptions, isInSSRComponentSetup);
  };
  const ssrContextKey = Symbol.for("v-scx");
  const useSSRContext = () => {
    {
      const ctx = inject(ssrContextKey);
      return ctx;
    }
  };
  const version = "3.3.7";
  const ceChildStyleMap = /* @__PURE__ */ new Map();
  const svgNS = "http://www.w3.org/2000/svg";
  const doc = typeof document !== "undefined" ? document : null;
  const templateContainer = doc && /* @__PURE__ */ doc.createElement("template");
  const nodeOps = {
    insert: (child, parent, anchor) => {
      parent.insertBefore(child, anchor || null);
    },
    remove: (child) => {
      const parent = child.parentNode;
      if (parent) {
        parent.removeChild(child);
      }
    },
    createElement: (tag, isSVG, is, props) => {
      const el = isSVG ? doc.createElementNS(svgNS, tag) : doc.createElement(tag, is ? { is } : void 0);
      if (tag === "select" && props && props.multiple != null) {
        el.setAttribute("multiple", props.multiple);
      }
      return el;
    },
    createText: (text) => doc.createTextNode(text),
    createComment: (text) => doc.createComment(text),
    setText: (node, text) => {
      node.nodeValue = text;
    },
    setElementText: (el, text) => {
      el.textContent = text;
    },
    parentNode: (node) => node.parentNode,
    nextSibling: (node) => node.nextSibling,
    querySelector: (selector) => doc.querySelector(selector),
    setScopeId(el, id) {
      el.setAttribute(id, "");
    },
    // __UNSAFE__
    // Reason: innerHTML.
    // Static content here can only come from compiled templates.
    // As long as the user only uses trusted templates, this is safe.
    insertStaticContent(content, parent, anchor, isSVG, start, end) {
      const before = anchor ? anchor.previousSibling : parent.lastChild;
      if (start && (start === end || start.nextSibling)) {
        while (true) {
          parent.insertBefore(start.cloneNode(true), anchor);
          if (start === end || !(start = start.nextSibling))
            break;
        }
      } else {
        templateContainer.innerHTML = isSVG ? `<svg>${content}</svg>` : content;
        const template = templateContainer.content;
        if (isSVG) {
          const wrapper = template.firstChild;
          while (wrapper.firstChild) {
            template.appendChild(wrapper.firstChild);
          }
          template.removeChild(wrapper);
        }
        parent.insertBefore(template, anchor);
      }
      return [
        // first
        before ? before.nextSibling : parent.firstChild,
        // last
        anchor ? anchor.previousSibling : parent.lastChild
      ];
    }
  };
  const vtcKey = Symbol("_vtc");
  function patchClass(el, value, isSVG) {
    const transitionClasses = el[vtcKey];
    if (transitionClasses) {
      value = (value ? [value, ...transitionClasses] : [...transitionClasses]).join(" ");
    }
    if (value == null) {
      el.removeAttribute("class");
    } else if (isSVG) {
      el.setAttribute("class", value);
    } else {
      el.className = value;
    }
  }
  const vShowOldKey = Symbol("_vod");
  const vShow = {
    beforeMount(el, { value }, { transition }) {
      el[vShowOldKey] = el.style.display === "none" ? "" : el.style.display;
      if (transition && value) {
        transition.beforeEnter(el);
      } else {
        setDisplay(el, value);
      }
    },
    mounted(el, { value }, { transition }) {
      if (transition && value) {
        transition.enter(el);
      }
    },
    updated(el, { value, oldValue }, { transition }) {
      if (!value === !oldValue)
        return;
      if (transition) {
        if (value) {
          transition.beforeEnter(el);
          setDisplay(el, true);
          transition.enter(el);
        } else {
          transition.leave(el, () => {
            setDisplay(el, false);
          });
        }
      } else {
        setDisplay(el, value);
      }
    },
    beforeUnmount(el, { value }) {
      setDisplay(el, value);
    }
  };
  function setDisplay(el, value) {
    el.style.display = value ? el[vShowOldKey] : "none";
  }
  function patchStyle(el, prev, next) {
    const style = el.style;
    const isCssString = isString(next);
    if (next && !isCssString) {
      if (prev && !isString(prev)) {
        for (const key in prev) {
          if (next[key] == null) {
            setStyle(style, key, "");
          }
        }
      }
      for (const key in next) {
        setStyle(style, key, next[key]);
      }
    } else {
      const currentDisplay = style.display;
      if (isCssString) {
        if (prev !== next) {
          style.cssText = next;
        }
      } else if (prev) {
        el.removeAttribute("style");
      }
      if (vShowOldKey in el) {
        style.display = currentDisplay;
      }
    }
  }
  const importantRE = /\s*!important$/;
  function setStyle(style, name, val) {
    if (isArray(val)) {
      val.forEach((v) => setStyle(style, name, v));
    } else {
      if (val == null)
        val = "";
      if (name.startsWith("--")) {
        style.setProperty(name, val);
      } else {
        const prefixed = autoPrefix(style, name);
        if (importantRE.test(val)) {
          style.setProperty(
            hyphenate(prefixed),
            val.replace(importantRE, ""),
            "important"
          );
        } else {
          style[prefixed] = val;
        }
      }
    }
  }
  const prefixes = ["Webkit", "Moz", "ms"];
  const prefixCache = {};
  function autoPrefix(style, rawName) {
    const cached = prefixCache[rawName];
    if (cached) {
      return cached;
    }
    let name = camelize(rawName);
    if (name !== "filter" && name in style) {
      return prefixCache[rawName] = name;
    }
    name = capitalize(name);
    for (let i = 0; i < prefixes.length; i++) {
      const prefixed = prefixes[i] + name;
      if (prefixed in style) {
        return prefixCache[rawName] = prefixed;
      }
    }
    return rawName;
  }
  const xlinkNS = "http://www.w3.org/1999/xlink";
  function patchAttr(el, key, value, isSVG, instance) {
    if (isSVG && key.startsWith("xlink:")) {
      if (value == null) {
        el.removeAttributeNS(xlinkNS, key.slice(6, key.length));
      } else {
        el.setAttributeNS(xlinkNS, key, value);
      }
    } else {
      const isBoolean = isSpecialBooleanAttr(key);
      if (value == null || isBoolean && !includeBooleanAttr(value)) {
        el.removeAttribute(key);
      } else {
        el.setAttribute(key, isBoolean ? "" : value);
      }
    }
  }
  function patchDOMProp(el, key, value, prevChildren, parentComponent, parentSuspense, unmountChildren) {
    if (key === "innerHTML" || key === "textContent") {
      if (prevChildren) {
        unmountChildren(prevChildren, parentComponent, parentSuspense);
      }
      el[key] = value == null ? "" : value;
      return;
    }
    const tag = el.tagName;
    if (key === "value" && tag !== "PROGRESS" && // custom elements may use _value internally
    !tag.includes("-")) {
      el._value = value;
      const oldValue = tag === "OPTION" ? el.getAttribute("value") : el.value;
      const newValue = value == null ? "" : value;
      if (oldValue !== newValue) {
        el.value = newValue;
      }
      if (value == null) {
        el.removeAttribute(key);
      }
      return;
    }
    let needRemove = false;
    if (value === "" || value == null) {
      const type = typeof el[key];
      if (type === "boolean") {
        value = includeBooleanAttr(value);
      } else if (value == null && type === "string") {
        value = "";
        needRemove = true;
      } else if (type === "number") {
        value = 0;
        needRemove = true;
      }
    }
    try {
      el[key] = value;
    } catch (e) {
    }
    needRemove && el.removeAttribute(key);
  }
  function addEventListener(el, event, handler, options) {
    el.addEventListener(event, handler, options);
  }
  function removeEventListener(el, event, handler, options) {
    el.removeEventListener(event, handler, options);
  }
  const veiKey = Symbol("_vei");
  function patchEvent(el, rawName, prevValue, nextValue, instance = null) {
    const invokers = el[veiKey] || (el[veiKey] = {});
    const existingInvoker = invokers[rawName];
    if (nextValue && existingInvoker) {
      existingInvoker.value = nextValue;
    } else {
      const [name, options] = parseName(rawName);
      if (nextValue) {
        const invoker = invokers[rawName] = createInvoker(nextValue, instance);
        addEventListener(el, name, invoker, options);
      } else if (existingInvoker) {
        removeEventListener(el, name, existingInvoker, options);
        invokers[rawName] = void 0;
      }
    }
  }
  const optionsModifierRE = /(?:Once|Passive|Capture)$/;
  function parseName(name) {
    let options;
    if (optionsModifierRE.test(name)) {
      options = {};
      let m;
      while (m = name.match(optionsModifierRE)) {
        name = name.slice(0, name.length - m[0].length);
        options[m[0].toLowerCase()] = true;
      }
    }
    const event = name[2] === ":" ? name.slice(3) : hyphenate(name.slice(2));
    return [event, options];
  }
  let cachedNow = 0;
  const p = /* @__PURE__ */ Promise.resolve();
  const getNow = () => cachedNow || (p.then(() => cachedNow = 0), cachedNow = Date.now());
  function createInvoker(initialValue, instance) {
    const invoker = (e) => {
      if (!e._vts) {
        e._vts = Date.now();
      } else if (e._vts <= invoker.attached) {
        return;
      }
      callWithAsyncErrorHandling(
        patchStopImmediatePropagation(e, invoker.value),
        instance,
        5,
        [e]
      );
    };
    invoker.value = initialValue;
    invoker.attached = getNow();
    return invoker;
  }
  function patchStopImmediatePropagation(e, value) {
    if (isArray(value)) {
      const originalStop = e.stopImmediatePropagation;
      e.stopImmediatePropagation = () => {
        originalStop.call(e);
        e._stopped = true;
      };
      return value.map((fn) => (e2) => !e2._stopped && fn && fn(e2));
    } else {
      return value;
    }
  }
  const nativeOnRE = /^on[a-z]/;
  const patchProp = (el, key, prevValue, nextValue, isSVG = false, prevChildren, parentComponent, parentSuspense, unmountChildren) => {
    if (key === "class") {
      patchClass(el, nextValue, isSVG);
    } else if (key === "style") {
      patchStyle(el, prevValue, nextValue);
    } else if (isOn(key)) {
      if (!isModelListener(key)) {
        patchEvent(el, key, prevValue, nextValue, parentComponent);
      }
    } else if (key[0] === "." ? (key = key.slice(1), true) : key[0] === "^" ? (key = key.slice(1), false) : shouldSetAsProp(el, key, nextValue, isSVG)) {
      patchDOMProp(
        el,
        key,
        nextValue,
        prevChildren,
        parentComponent,
        parentSuspense,
        unmountChildren
      );
    } else {
      if (key === "true-value") {
        el._trueValue = nextValue;
      } else if (key === "false-value") {
        el._falseValue = nextValue;
      }
      patchAttr(el, key, nextValue, isSVG);
    }
  };
  function shouldSetAsProp(el, key, value, isSVG) {
    if (isSVG) {
      if (key === "innerHTML" || key === "textContent") {
        return true;
      }
      if (key in el && nativeOnRE.test(key) && isFunction(value)) {
        return true;
      }
      return false;
    }
    if (key === "spellcheck" || key === "draggable" || key === "translate") {
      return false;
    }
    if (key === "form") {
      return false;
    }
    if (key === "list" && el.tagName === "INPUT") {
      return false;
    }
    if (key === "type" && el.tagName === "TEXTAREA") {
      return false;
    }
    if (nativeOnRE.test(key) && isString(value)) {
      return false;
    }
    return key in el;
  }
  /*! #__NO_SIDE_EFFECTS__ */
  // @__NO_SIDE_EFFECTS__
  function defineCustomElement(options, hydrate2) {
    const Comp = /* @__PURE__ */ defineComponent(options);
    class VueCustomElement extends VueElement {
      constructor(initialProps) {
        super(Comp, initialProps, hydrate2);
      }
    }
    VueCustomElement.def = Comp;
    return VueCustomElement;
  }
  const BaseClass = typeof HTMLElement !== "undefined" ? HTMLElement : class {
  };
  class VueElement extends BaseClass {
    constructor(_def, _props = {}, hydrate2) {
      super();
      this._childStylesAnchor = null;
      this._def = _def;
      this._props = _props;
      this._instance = null;
      this._connected = false;
      this._resolved = false;
      this._numberProps = null;
      this._ob = null;
      if (this.shadowRoot && hydrate2) {
        hydrate2(this._createVNode(), this.shadowRoot);
      } else {
        this.attachShadow({ mode: "open" });
        if (!this._def.__asyncLoader) {
          this._resolveProps(this._def);
        }
      }
    }
    connectedCallback() {
      this._connected = true;
      if (!this._instance) {
        if (this._resolved) {
          this._update();
        } else {
          this._resolveDef();
        }
      }
    }
    disconnectedCallback() {
      this._connected = false;
      if (this._ob) {
        this._ob.disconnect();
        this._ob = null;
      }
      nextTick(() => {
        if (!this._connected) {
          render(null, this.shadowRoot);
          this._instance = null;
        }
      });
    }
    /**
     * resolve inner component definition (handle possible async component)
     */
    _resolveDef() {
      this._resolved = true;
      for (let i = 0; i < this.attributes.length; i++) {
        this._setAttr(this.attributes[i].name);
      }
      this._ob = new MutationObserver((mutations) => {
        for (const m of mutations) {
          this._setAttr(m.attributeName);
        }
      });
      this._ob.observe(this, { attributes: true });
      const resolve = (def2, isAsync = false) => {
        const { props, styles } = def2;
        let numberProps;
        if (props && !isArray(props)) {
          for (const key in props) {
            const opt = props[key];
            if (opt === Number || opt && opt.type === Number) {
              if (key in this._props) {
                this._props[key] = toNumber(this._props[key]);
              }
              (numberProps || (numberProps = /* @__PURE__ */ Object.create(null)))[camelize(key)] = true;
            }
          }
        }
        this._numberProps = numberProps;
        if (isAsync) {
          this._resolveProps(def2);
        }
        this._applyStyles(styles);
        this._update();
      };
      const asyncDef = this._def.__asyncLoader;
      if (asyncDef) {
        asyncDef().then((def2) => resolve(def2, true));
      } else {
        resolve(this._def);
      }
    }
    _resolveProps(def2) {
      const { props } = def2;
      const declaredPropKeys = isArray(props) ? props : Object.keys(props || {});
      for (const key of Object.keys(this)) {
        if (key[0] !== "_" && declaredPropKeys.includes(key)) {
          this._setProp(key, this[key], true, false);
        }
      }
      for (const key of declaredPropKeys.map(camelize)) {
        Object.defineProperty(this, key, {
          get() {
            return this._getProp(key);
          },
          set(val) {
            this._setProp(key, val);
          }
        });
      }
    }
    _setAttr(key) {
      let value = this.getAttribute(key);
      const camelKey = camelize(key);
      if (this._numberProps && this._numberProps[camelKey]) {
        value = toNumber(value);
      }
      this._setProp(camelKey, value, false);
    }
    /**
     * @internal
     */
    _getProp(key) {
      return this._props[key];
    }
    /**
     * @internal
     */
    _setProp(key, val, shouldReflect = true, shouldUpdate = true) {
      if (val !== this._props[key]) {
        this._props[key] = val;
        if (shouldUpdate && this._instance) {
          this._update();
        }
        if (shouldReflect) {
          if (val === true) {
            this.setAttribute(hyphenate(key), "");
          } else if (typeof val === "string" || typeof val === "number") {
            this.setAttribute(hyphenate(key), val + "");
          } else if (!val) {
            this.removeAttribute(hyphenate(key));
          }
        }
      }
    }
    _update() {
      render(this._createVNode(), this.shadowRoot);
    }
    _createVNode() {
      const vnode = createVNode(this._def, extend({}, this._props));
      if (!this._instance) {
        vnode.ce = (instance) => {
          this._instance = instance;
          instance.addCEChildStyle = this._addChildStyles.bind(this);
          instance.removeCEChildStyle = this._removeChildStyles.bind(this);
          instance.isCE = true;
          const dispatch = (event, args) => {
            this.dispatchEvent(
              new CustomEvent(event, {
                detail: args
              })
            );
          };
          instance.emit = (event, ...args) => {
            dispatch(event, args);
            if (hyphenate(event) !== event) {
              dispatch(hyphenate(event), args);
            }
          };
          let parent = this;
          while (parent = parent && (parent.parentNode || parent.host)) {
            if (parent instanceof VueElement) {
              instance.parent = parent._instance;
              instance.provides = parent._instance.provides;
              break;
            }
          }
        };
      }
      return vnode;
    }
    _applyStyles(styles) {
      if (styles) {
        styles.forEach((css) => {
          const s = document.createElement("style");
          s.textContent = css;
          this.shadowRoot.appendChild(s);
          this._childStylesAnchor = s;
        });
      }
    }
    _addChildStyles(styles, instance) {
      if (styles) {
        const styleContent = styles.join();
        const ceKey = `__${this._instance.uid}`;
        let ceKeySet = /* @__PURE__ */ new Set();
        if (ceChildStyleMap.has(styleContent)) {
          ceKeySet = ceChildStyleMap.get(styleContent);
          if (ceKeySet.has(ceKey)) {
            ceKeySet.add(ceKey);
            ceChildStyleMap.set(styleContent, ceKeySet);
            return;
          }
        }
        ceKeySet.add(ceKey);
        ceChildStyleMap.set(styleContent, ceKeySet);
        const ceStyleId = `data-v-ce-${instance.uid}`;
        styles.forEach((css, index) => {
          const s = document.createElement("style");
          s.textContent = css;
          s.setAttribute(ceStyleId, "");
          if (this._childStylesAnchor) {
            this.shadowRoot.insertBefore(
              s,
              this._childStylesAnchor
            );
          } else {
            this.shadowRoot.appendChild(s);
          }
          this._childStylesAnchor = s;
          {
            (this._styles || (this._styles = [])).push(s);
          }
        });
      }
    }
    _removeChildStyles(styles, uid2) {
      if (styles) {
        const styleContent = styles.join();
        let cecStyle = /* @__PURE__ */ new Set();
        if (ceChildStyleMap.has(styleContent)) {
          const ceKey = `__${this._instance.uid}`;
          cecStyle = ceChildStyleMap.get(styleContent);
          cecStyle.delete(ceKey);
          if (cecStyle.size === 0) {
            const sList = this.shadowRoot.querySelectorAll(`[data-v-ce-${uid2}]`);
            sList.length > 0 && sList.forEach((s) => this.shadowRoot.removeChild(s));
            const archor = this.shadowRoot.querySelectorAll("style");
            this._childStylesAnchor = archor.length > 0 ? archor[archor.length - 1] : void 0;
            ceChildStyleMap.delete(styleContent);
          } else {
            ceChildStyleMap.set(styleContent, cecStyle);
          }
        }
      }
    }
  }
  const getModelAssigner = (vnode) => {
    const fn = vnode.props["onUpdate:modelValue"] || false;
    return isArray(fn) ? (value) => invokeArrayFns(fn, value) : fn;
  };
  const assignKey = Symbol("_assign");
  const vModelSelect = {
    // <select multiple> value need to be deep traversed
    deep: true,
    created(el, { value, modifiers: { number } }, vnode) {
      const isSetModel = isSet(value);
      addEventListener(el, "change", () => {
        const selectedVal = Array.prototype.filter.call(el.options, (o) => o.selected).map(
          (o) => number ? looseToNumber(getValue(o)) : getValue(o)
        );
        el[assignKey](
          el.multiple ? isSetModel ? new Set(selectedVal) : selectedVal : selectedVal[0]
        );
      });
      el[assignKey] = getModelAssigner(vnode);
    },
    // set value in mounted & updated because <select> relies on its children
    // <option>s.
    mounted(el, { value }) {
      setSelected(el, value);
    },
    beforeUpdate(el, _binding, vnode) {
      el[assignKey] = getModelAssigner(vnode);
    },
    updated(el, { value }) {
      setSelected(el, value);
    }
  };
  function setSelected(el, value) {
    const isMultiple = el.multiple;
    if (isMultiple && !isArray(value) && !isSet(value)) {
      return;
    }
    for (let i = 0, l = el.options.length; i < l; i++) {
      const option = el.options[i];
      const optionValue = getValue(option);
      if (isMultiple) {
        if (isArray(value)) {
          option.selected = looseIndexOf(value, optionValue) > -1;
        } else {
          option.selected = value.has(optionValue);
        }
      } else {
        if (looseEqual(getValue(option), value)) {
          if (el.selectedIndex !== i)
            el.selectedIndex = i;
          return;
        }
      }
    }
    if (!isMultiple && el.selectedIndex !== -1) {
      el.selectedIndex = -1;
    }
  }
  function getValue(el) {
    return "_value" in el ? el._value : el.value;
  }
  const systemModifiers = ["ctrl", "shift", "alt", "meta"];
  const modifierGuards = {
    stop: (e) => e.stopPropagation(),
    prevent: (e) => e.preventDefault(),
    self: (e) => e.target !== e.currentTarget,
    ctrl: (e) => !e.ctrlKey,
    shift: (e) => !e.shiftKey,
    alt: (e) => !e.altKey,
    meta: (e) => !e.metaKey,
    left: (e) => "button" in e && e.button !== 0,
    middle: (e) => "button" in e && e.button !== 1,
    right: (e) => "button" in e && e.button !== 2,
    exact: (e, modifiers) => systemModifiers.some((m) => e[`${m}Key`] && !modifiers.includes(m))
  };
  const withModifiers = (fn, modifiers) => {
    return (event, ...args) => {
      for (let i = 0; i < modifiers.length; i++) {
        const guard = modifierGuards[modifiers[i]];
        if (guard && guard(event, modifiers))
          return;
      }
      return fn(event, ...args);
    };
  };
  const rendererOptions = /* @__PURE__ */ extend({ patchProp }, nodeOps);
  let renderer;
  function ensureRenderer() {
    return renderer || (renderer = createRenderer(rendererOptions));
  }
  const render = (...args) => {
    ensureRenderer().render(...args);
  };
  const _style_0$3 = ".svg-wrapper {\n  opacity: 0;\n}\n.svg-wrapper--loaded {\n  animation: fadeInAnimation ease 0.5s;\n  animation-iteration-count: 1;\n  animation-fill-mode: forwards;\n}\n@keyframes fadeInAnimation {\n0% {\n    opacity: 0;\n}\n100% {\n    opacity: 1;\n}\n}";
  const _export_sfc = (sfc, props) => {
    const target = sfc.__vccOpts || sfc;
    for (const [key, val] of props) {
      target[key] = val;
    }
    return target;
  };
  const _hoisted_1$3 = ["src"];
  const _sfc_main$3 = {
    __name: "SVGWrapper.ce",
    props: {
      iconClass: String,
      iconName: String,
      theme: String,
      retailBaseUrl: String
    },
    setup(__props) {
      const iconLoaded = ref(true);
      return (_ctx, _cache) => {
        return openBlock(), createElementBlock("img", {
          class: normalizeClass(["icon svg-wrapper", { "svg-wrapper--loaded": iconLoaded.value, [__props.theme]: __props.theme, [__props.iconClass]: __props.iconClass }]),
          src: `${__props.retailBaseUrl}/icons/${__props.iconName}.svg`,
          onload: "SVGInject(this)"
        }, null, 10, _hoisted_1$3);
      };
    }
  };
  const SVGWrapper = /* @__PURE__ */ _export_sfc(_sfc_main$3, [["styles", [_style_0$3]]]);
  const _style_0$2 = '.calendar-days__day-container {\n  overflow: hidden;\n  height: 80px;\n  flex: 0 0 13.8%;\n  margin-top: 4px;\n  position: relative;\n  cursor: pointer;\n  background: #FFF;\n}\n.calendar-days__day-container--disabled {\n  cursor: default;\n  pointer-events: none;\n}\n.calendar-days__day-date {\n  font-size: 0.8rem;\n  width: 1.4rem;\n  height: 1.4rem;\n  line-height: 1.4rem;\n  text-align: center;\n  position: absolute;\n  top: 0;\n  left: 0;\n}\n.calendar-days__day-lowest-indicator {\n  font-size: 0.8rem;\n  width: 4rem;\n  height: 1.4rem;\n  line-height: 1.4rem;\n  text-align: center;\n  position: absolute;\n  top: 1px;\n  right: 1px;\n  text-transform: uppercase;\n}\n.calendar-days__day-lowest-indicator--mobile {\n  display: none;\n}\n.calendar-days__day-lowest-indicator--desktop {\n  display: block;\n}\n.calendar-days__day-fcp-indicator {\n  background: #AAD800;\n  color: #242424;\n  font-size: 0.8rem;\n  width: calc(100% - 2px);\n  height: 1.4rem;\n  line-height: 1.5rem;\n  text-align: center;\n  position: absolute;\n  bottom: 1px;\n  left: 1px;\n  text-transform: uppercase;\n  font-weight: bold;\n}\n.calendar-days__day-fcp-indicator--mobile {\n  display: none;\n}\n.calendar-days__day-fcp-indicator--desktop {\n  display: block;\n}\n.calendar-days__day-lowest-and-fcp-indicator {\n  display: none;\n  flex-direction: column;\n  line-height: normal;\n  margin: auto 40px auto auto;\n  min-width: 5rem;\n  width: 5rem;\n}\n.calendar-days__day-lowest-and-fcp-indicator span {\n  line-height: 20px;\n  height: 20px;\n  width: 100% !important;\n  margin-left: 0 !important;\n  margin-right: 0 !important;\n}\n.calendar-days__day-lowest-and-fcp-indicator > * + * {\n  margin-top: 5px;\n}\n.calendar-days__day-price-wrapper {\n  width: 100%;\n  height: 80px;\n  line-height: 80px;\n  text-align: center;\n  font-weight: 700;\n}\n.calendar-days__day-price-wrapper strong {\n  font-size: 1.5rem;\n}\n.calendar-days__day-price-wrapper small {\n  font-size: 0.8rem;\n}\n.calendar-days__weekday-text, .calendar-days__mobile-cta {\n  display: none;\n}\n.calendar-days--default .calendar-days__day-container {\n  background: #EEEEEE;\n}\n.calendar-days--default .calendar-days__day-container--disabled {\n  background: #F6F6F6;\n}\n.calendar-days--default .calendar-days__day-container:hover:not(.calendar-days__day-container--disabled) {\n  background: #efefef;\n}\n.calendar-days--default .calendar-days__day-date {\n  background: #4D4D4D;\n  color: #FFF;\n}\n.calendar-days--default .calendar-days__day-date--disabled {\n  background: #E2E2E2;\n}\n.calendar-days--default .calendar-days__day-lowest-indicator {\n  color: white;\n  background: #4D4D4D;\n}\n.calendar-days--default .calendar-days__day-price-wrapper {\n  color: #4D4D4D;\n}\n.calendar-days--default .calendar-days__mobile-cta {\n  background: #4D4D4D;\n}\n.calendar-days--default .calendar-days__mobile-cta svg {\n  fill: white;\n}\n.calendar-days--hh .calendar-days__day-container {\n  box-shadow: inset 1px 1px 0px 0px #006DFF, inset -1px -1px 0px 0px #006DFF;\n}\n.calendar-days--hh .calendar-days__day-container--disabled {\n  background: #F6F6F6;\n  box-shadow: none;\n}\n.calendar-days--hh .calendar-days__day-container--selected {\n  background: #006DFF;\n}\n.calendar-days--hh .calendar-days__day-container--blank {\n  background: none;\n}\n.calendar-days--hh .calendar-days__day-container:hover:not(.calendar-days__day-container--disabled):not(.calendar-days__day-container--selected) {\n  background: white;\n}\n.calendar-days--hh .calendar-days__day-date {\n  background: #006DFF;\n  color: white;\n}\n.calendar-days--hh .calendar-days__day-date--disabled {\n  color: #242424;\n  background: none;\n}\n.calendar-days--hh .calendar-days__day-date--selected {\n  background: #0057CC;\n}\n.calendar-days--hh .calendar-days__day-lowest-indicator {\n  color: white;\n  background: #DE0BA0;\n}\n.calendar-days--hh .calendar-days__day-price-wrapper {\n  color: #006DFF;\n}\n@media (max-width: 650px) {\n.calendar-days--hh .calendar-days__day-price-wrapper small {\n    margin-top: 3px;\n}\n}\n.calendar-days--hh .calendar-days__day-price-wrapper--selected {\n  color: #fff;\n}\n.calendar-days--hh .calendar-days__mobile-cta svg {\n  fill: #006DFF;\n}\n.calendar-days--hh .calendar-days__mobile-cta--selected {\n  background: #006DFF;\n}\n.calendar-days--hh .calendar-days__mobile-cta--selected svg {\n  fill: white;\n  pointer-events: none;\n}\n.calendar-days--tui .calendar-days__day-container {\n  box-shadow: inset 1px 1px 0px 0px #1a7ead, inset -1px -1px 0px 0px #1a7ead;\n}\n.calendar-days--tui .calendar-days__day-container--disabled {\n  background: #F6F6F6;\n  box-shadow: none;\n}\n.calendar-days--tui .calendar-days__day-container--selected {\n  background: #1a7ead;\n}\n.calendar-days--tui .calendar-days__day-container--blank {\n  background: none;\n}\n.calendar-days--tui .calendar-days__day-container:hover:not(.calendar-days__day-container--disabled):not(.calendar-days__day-container--selected) {\n  background: white;\n}\n.calendar-days--tui .calendar-days__day-date {\n  background: #1A7EAD;\n  color: white;\n}\n.calendar-days--tui .calendar-days__day-date--disabled {\n  color: #000;\n  background: none;\n}\n.calendar-days--tui .calendar-days__day-date--selected {\n  background: #092a5e;\n}\n.calendar-days--tui .calendar-days__day-lowest-indicator {\n  color: white;\n  background: #D40E14;\n}\n.calendar-days--tui .calendar-days__day-price-wrapper {\n  color: #1A7EAD;\n}\n@media (max-width: 650px) {\n.calendar-days--tui .calendar-days__day-price-wrapper small {\n    margin-top: 3px;\n}\n}\n.calendar-days--tui .calendar-days__day-price-wrapper--selected {\n  color: #fff;\n}\n.calendar-days--tui .calendar-days__mobile-cta svg {\n  fill: #1A7EAD;\n}\n.calendar-days--tui .calendar-days__mobile-cta--selected {\n  background: #1A7EAD;\n}\n.calendar-days--tui .calendar-days__mobile-cta--selected svg {\n  fill: white;\n  pointer-events: none;\n}\n.calendar-days--FC .calendar-days__day-container {\n  box-shadow: inset 1px 1px 0px 0px #E00085, inset -1px -1px 0px 0px #E00085;\n}\n.calendar-days--FC .calendar-days__day-container--disabled {\n  background: #F4F5F6;\n  box-shadow: none;\n}\n.calendar-days--FC .calendar-days__day-container--selected {\n  background: #E00085;\n  color: white;\n}\n.calendar-days--FC .calendar-days__day-container--blank {\n  background: none;\n}\n.calendar-days--FC .calendar-days__day-container:hover:not(.calendar-days__day-container--disabled):not(.calendar-days__day-container--selected) {\n  background: white;\n}\n.calendar-days--FC .calendar-days__day-date {\n  background: #E00085;\n  color: white;\n}\n.calendar-days--FC .calendar-days__day-date--disabled {\n  color: #000;\n  background: none;\n}\n.calendar-days--FC .calendar-days__day-date--selected {\n  background: #E00085;\n}\n.calendar-days--FC .calendar-days__day-lowest-indicator {\n  color: white;\n  background: #550F9D;\n}\n.calendar-days--FC .calendar-days__day-price-wrapper {\n  color: #003753;\n}\n.calendar-days--FC .calendar-days__day-price-wrapper--selected {\n  color: #fff;\n}\n.calendar-days--FC .calendar-days__mobile-cta svg {\n  fill: #E00085;\n}\n.calendar-days--FC .calendar-days__mobile-cta--selected {\n  background: #E00085;\n}\n.calendar-days--FC .calendar-days__mobile-cta--selected svg {\n  fill: white;\n  pointer-events: none;\n}\n.calendar-days--fcr .calendar-days__day-container {\n  border: #FF467C 1px solid;\n  border-radius: 4px;\n  height: 74px;\n}\n@media (max-width: 650px) {\n.calendar-days--fcr .calendar-days__day-container {\n    height: 60px;\n}\n}\n.calendar-days--fcr .calendar-days__day-container--disabled {\n  background: #F2EEE4;\n  border: #F2EEE4 1px solid;\n}\n.calendar-days--fcr .calendar-days__day-container--selected {\n  background: #FF467C;\n  color: white;\n}\n.calendar-days--fcr .calendar-days__day-container--blank {\n  background: none;\n  border: none;\n}\n.calendar-days--fcr .calendar-days__day-container:hover:not(.calendar-days__day-container--disabled):not(.calendar-days__day-container--selected) {\n  background: white;\n}\n.calendar-days--fcr .calendar-days__day-price-wrapper {\n  height: 58px;\n  line-height: 74px;\n}\n@media (max-width: 650px) {\n.calendar-days--fcr .calendar-days__day-price-wrapper {\n    line-height: 60px;\n}\n}\n.calendar-days--fcr .calendar-days__day-price-wrapper small {\n  line-height: 60px;\n  font-size: 15px;\n}\n.calendar-days--fcr .calendar-days__day-date {\n  font-family: RondelleBook, Inter, Arial, sans-serif;\n  background: #FF467C;\n  color: white;\n  border-radius: 0 4px 4px 4px;\n  font-weight: bold;\n  left: 0px;\n  top: 0px;\n}\n.calendar-days--fcr .calendar-days__day-date--disabled {\n  color: #002F17;\n  background: none;\n  font-weight: normal;\n}\n.calendar-days--fcr .calendar-days__day-date--selected {\n  background: #FF467C;\n  color: white;\n}\n.calendar-days--fcr .calendar-days__day-lowest-indicator {\n  color: #002F17;\n  background: #FFD4E4;\n  font-weight: bold;\n  font-family: RondelleBlack, InterBlack, "Arial Black", sans-serif;\n  border-radius: 4px 0 4px 4px;\n  top: 0;\n  right: 0;\n}\n.calendar-days--fcr .calendar-days__day-fcp-indicator {\n  background: #CEE8E0;\n  border-radius: 4px 4px 0 0;\n  color: #002F17;\n  font-family: RondelleBlack, InterBlack, "Arial Black", sans-serif;\n  text-transform: uppercase;\n  width: 100%;\n  left: 0;\n  bottom: 0;\n  font-size: 0.7rem !important;\n}\n.calendar-days--fcr .calendar-days__day-fcp-indicator--mobile {\n  font-size: 0.8rem !important;\n}\n.calendar-days--fcr .calendar-days__day-price-wrapper {\n  color: #002F17;\n  font-family: PasticheGrotesque, WorkSans, Verdana, sans-serif;\n  font-size: 17px;\n  font-style: normal;\n  font-weight: 900;\n}\n.calendar-days--fcr .calendar-days__day-price-wrapper--selected {\n  color: #fff;\n}\n.calendar-days--fcr .calendar-days__mobile-cta svg {\n  fill: #002F17;\n  width: 1rem;\n  height: 1.2rem;\n}\n.calendar-days--fcr .calendar-days__mobile-cta--selected {\n  background: #FF467C;\n}\n.calendar-days--fcr .calendar-days__mobile-cta--selected svg {\n  fill: white;\n  pointer-events: none;\n}\n@media (max-width: 650px) {\n.calendar-days--fcr .calendar-days__day-lowest-indicator, .calendar-days--fcr .calendar-days__day-fcp-indicator {\n    min-width: 6rem;\n    width: 6rem;\n    border-radius: 4px;\n}\n.calendar-days--fcr .calendar-days__day-date {\n    border-radius: 0;\n}\n}\n.calendar-days--fcr .calendar-days__day-lowest-and-fcp-indicator {\n  min-width: 6rem;\n  width: 6rem;\n}\n@media (max-width: 650px) {\n.calendar-days__day-container {\n    height: 60px;\n    flex: 0 0 100%;\n}\n.calendar-days__day-container--disabled {\n    display: none;\n}\n.calendar-days__day-date {\n    height: 60px;\n    width: 60px;\n    line-height: 20px;\n    font-size: 1rem;\n}\n.calendar-days__day-lowest-indicator {\n    display: block;\n    align-self: center;\n    margin-left: auto;\n    margin-right: 40px;\n    position: inherit;\n    min-width: 5rem;\n    width: 5rem;\n    height: 3rem;\n    line-height: 3rem;\n}\n.calendar-days__day-lowest-indicator--mobile {\n    display: block;\n}\n.calendar-days__day-lowest-indicator--desktop {\n    display: none;\n}\n.calendar-days__day-fcp-indicator {\n    background: #AAD800;\n    color: #242424;\n    display: block;\n    align-self: center;\n    margin-left: auto;\n    margin-right: 40px;\n    position: inherit;\n    min-width: 5rem;\n    width: 5rem;\n    height: 3rem;\n    line-height: 3rem;\n}\n.calendar-days__day-fcp-indicator--mobile {\n    display: block;\n}\n.calendar-days__day-fcp-indicator--desktop {\n    display: none;\n}\n.calendar-days__day-lowest-and-fcp-indicator {\n    display: flex;\n}\n.calendar-days__day-price-wrapper {\n    text-align: left;\n    padding-left: calc(60px + 1rem);\n    display: flex;\n    height: 60px;\n    line-height: 60px;\n}\n.calendar-days__weekday-text {\n    display: block;\n    margin-top: 10px;\n    text-transform: uppercase;\n    font-size: 0.9rem;\n}\n.calendar-days__date {\n    font-size: 1.5rem;\n}\n.calendar-days__mobile-cta {\n    display: block;\n    width: 30px;\n    height: 30px;\n    position: absolute;\n    right: 0;\n    top: 15px;\n    border-radius: 3px;\n}\n.calendar-days__mobile-cta svg {\n    width: 1.3rem;\n    height: 1.3rem;\n}\n}';
  const _hoisted_1$2 = { class: "calendar-days__weekday-text" };
  const _hoisted_2$2 = { class: "calendar-days__date" };
  const _hoisted_3$1 = {
    key: 1,
    class: "calendar-days__day-lowest-indicator calendar-days__day-lowest-indicator--desktop"
  };
  const _hoisted_4$1 = {
    key: 2,
    class: "calendar-days__day-fcp-indicator calendar-days__day-fcp-indicator--desktop"
  };
  const _hoisted_5$1 = /* @__PURE__ */ createBaseVNode("small", null, "pp", -1);
  const _hoisted_6$1 = {
    key: 0,
    class: "calendar-days__day-lowest-indicator calendar-days__day-lowest-indicator--mobile"
  };
  const _hoisted_7$1 = {
    key: 1,
    class: "calendar-days__day-fcp-indicator calendar-days__day-fcp-indicator--mobile"
  };
  const _hoisted_8 = {
    key: 2,
    class: "calendar-days__day-lowest-and-fcp-indicator"
  };
  const _hoisted_9 = /* @__PURE__ */ createBaseVNode("span", { class: "calendar-days__day-lowest-indicator" }, "lowest", -1);
  const _hoisted_10 = /* @__PURE__ */ createBaseVNode("span", { class: "calendar-days__day-fcp-indicator" }, "Free Child", -1);
  const _hoisted_11 = [
    _hoisted_9,
    _hoisted_10
  ];
  const _hoisted_12 = {
    key: 4,
    class: "calendar-days__mobile-cta"
  };
  const _hoisted_13 = {
    key: 5,
    class: "calendar-days__mobile-cta calendar-days__mobile-cta--selected"
  };
  const _sfc_main$2 = {
    __name: "Day.ce",
    props: {
      isCheapest: Boolean,
      isSelected: Boolean,
      price: Number,
      link: String,
      dayNumber: String,
      weekdayText: String,
      selectedMonth: String,
      hasFcp: Boolean,
      isHolidayDetails: Boolean,
      holidayObject: String,
      clientId: String,
      accountId: Number,
      availabilitySearchId: Number,
      resultsApiUrl: String,
      retailBaseUrl: String,
      theme: String
    },
    emits: ["loadAlternativeFlightByHoliday"],
    setup(__props, { emit: __emit }) {
      const emit2 = __emit;
      const props = __props;
      const calendarDayClick = (link) => {
        if (props.isHolidayDetails) {
          const url = new URL(link);
          const { searchParams } = url;
          const searchId = props.availabilitySearchId > 0 ? props.availabilitySearchId : searchParams.get("searchId");
          const holidayObject = props.holidayObject;
          emit2("loadAlternativeFlightByHoliday", { holidayObject, searchId });
        } else {
          window.location.href = link;
        }
      };
      const getIsPriceValid = computed(() => props.price && props.price !== 0);
      return (_ctx, _cache) => {
        return openBlock(), createElementBlock("div", {
          class: normalizeClass(["calendar-days__day-container", {
            "calendar-days__day-container--disabled": !__props.link || !getIsPriceValid.value,
            "calendar-days__day-container--selected": __props.isSelected,
            "calendar-days__day-container--blank": !__props.dayNumber
          }]),
          onClick: _cache[0] || (_cache[0] = ($event) => !__props.link || !getIsPriceValid.value ? null : calendarDayClick(__props.link)),
          onMouseup: _cache[1] || (_cache[1] = withModifiers(($event) => !__props.link || !getIsPriceValid.value ? null : calendarDayClick(__props.link), ["middle"])),
          "data-tm-id": "calendar-day"
        }, [
          __props.dayNumber ? (openBlock(), createElementBlock("div", {
            key: 0,
            class: normalizeClass(["calendar-days__day-date", {
              "calendar-days__day-date--disabled": !__props.link || !getIsPriceValid.value,
              "calendar-days__day-date--selected": __props.isSelected
            }])
          }, [
            createBaseVNode("span", _hoisted_1$2, toDisplayString(__props.weekdayText), 1),
            createBaseVNode("span", _hoisted_2$2, toDisplayString(__props.dayNumber), 1)
          ], 2)) : createCommentVNode("", true),
          __props.isCheapest ? (openBlock(), createElementBlock("div", _hoisted_3$1, " lowest ")) : createCommentVNode("", true),
          __props.hasFcp ? (openBlock(), createElementBlock("div", _hoisted_4$1, " Free Child Place ")) : createCommentVNode("", true),
          getIsPriceValid.value ? (openBlock(), createElementBlock("div", {
            key: 3,
            class: normalizeClass(["calendar-days__day-price-wrapper", { "calendar-days__day-price-wrapper--selected": __props.isSelected }])
          }, [
            createBaseVNode("strong", null, "£" + toDisplayString(__props.price), 1),
            _hoisted_5$1,
            __props.isCheapest && !__props.hasFcp ? (openBlock(), createElementBlock("div", _hoisted_6$1, " lowest ")) : createCommentVNode("", true),
            __props.hasFcp && !__props.isCheapest ? (openBlock(), createElementBlock("div", _hoisted_7$1, " Free Child ")) : createCommentVNode("", true),
            __props.isCheapest && __props.hasFcp ? (openBlock(), createElementBlock("div", _hoisted_8, _hoisted_11)) : createCommentVNode("", true)
          ], 2)) : createCommentVNode("", true),
          !__props.isSelected ? (openBlock(), createElementBlock("button", _hoisted_12, [
            createVNode(SVGWrapper, {
              "icon-name": `${__props.theme === "fcr" ? "chevron-fc" : "chevron"}`,
              "retail-base-url": __props.retailBaseUrl
            }, null, 8, ["icon-name", "retail-base-url"])
          ])) : (openBlock(), createElementBlock("button", _hoisted_13, [
            createVNode(SVGWrapper, {
              "icon-name": `${__props.theme === "fcr" ? "tick-alt-fc" : "tick"}`,
              "retail-base-url": __props.retailBaseUrl
            }, null, 8, ["icon-name", "retail-base-url"])
          ]))
        ], 34);
      };
    }
  };
  const Day = /* @__PURE__ */ _export_sfc(_sfc_main$2, [["styles", [_style_0$2]]]);
  var commonjsGlobal = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
  function getDefaultExportFromCjs(x) {
    return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, "default") ? x["default"] : x;
  }
  var dayjs_min = { exports: {} };
  (function(module, exports) {
    !function(t, e) {
      module.exports = e();
    }(commonjsGlobal, function() {
      var t = 1e3, e = 6e4, n = 36e5, r = "millisecond", i = "second", s = "minute", u = "hour", a = "day", o = "week", c = "month", f = "quarter", h = "year", d = "date", l = "Invalid Date", $ = /^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/, y = /\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g, M = { name: "en", weekdays: "Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"), months: "January_February_March_April_May_June_July_August_September_October_November_December".split("_"), ordinal: function(t2) {
        var e2 = ["th", "st", "nd", "rd"], n2 = t2 % 100;
        return "[" + t2 + (e2[(n2 - 20) % 10] || e2[n2] || e2[0]) + "]";
      } }, m = function(t2, e2, n2) {
        var r2 = String(t2);
        return !r2 || r2.length >= e2 ? t2 : "" + Array(e2 + 1 - r2.length).join(n2) + t2;
      }, v = { s: m, z: function(t2) {
        var e2 = -t2.utcOffset(), n2 = Math.abs(e2), r2 = Math.floor(n2 / 60), i2 = n2 % 60;
        return (e2 <= 0 ? "+" : "-") + m(r2, 2, "0") + ":" + m(i2, 2, "0");
      }, m: function t2(e2, n2) {
        if (e2.date() < n2.date())
          return -t2(n2, e2);
        var r2 = 12 * (n2.year() - e2.year()) + (n2.month() - e2.month()), i2 = e2.clone().add(r2, c), s2 = n2 - i2 < 0, u2 = e2.clone().add(r2 + (s2 ? -1 : 1), c);
        return +(-(r2 + (n2 - i2) / (s2 ? i2 - u2 : u2 - i2)) || 0);
      }, a: function(t2) {
        return t2 < 0 ? Math.ceil(t2) || 0 : Math.floor(t2);
      }, p: function(t2) {
        return { M: c, y: h, w: o, d: a, D: d, h: u, m: s, s: i, ms: r, Q: f }[t2] || String(t2 || "").toLowerCase().replace(/s$/, "");
      }, u: function(t2) {
        return void 0 === t2;
      } }, g = "en", D = {};
      D[g] = M;
      var p2 = "$isDayjsObject", S = function(t2) {
        return t2 instanceof _ || !(!t2 || !t2[p2]);
      }, w = function t2(e2, n2, r2) {
        var i2;
        if (!e2)
          return g;
        if ("string" == typeof e2) {
          var s2 = e2.toLowerCase();
          D[s2] && (i2 = s2), n2 && (D[s2] = n2, i2 = s2);
          var u2 = e2.split("-");
          if (!i2 && u2.length > 1)
            return t2(u2[0]);
        } else {
          var a2 = e2.name;
          D[a2] = e2, i2 = a2;
        }
        return !r2 && i2 && (g = i2), i2 || !r2 && g;
      }, O = function(t2, e2) {
        if (S(t2))
          return t2.clone();
        var n2 = "object" == typeof e2 ? e2 : {};
        return n2.date = t2, n2.args = arguments, new _(n2);
      }, b = v;
      b.l = w, b.i = S, b.w = function(t2, e2) {
        return O(t2, { locale: e2.$L, utc: e2.$u, x: e2.$x, $offset: e2.$offset });
      };
      var _ = function() {
        function M2(t2) {
          this.$L = w(t2.locale, null, true), this.parse(t2), this.$x = this.$x || t2.x || {}, this[p2] = true;
        }
        var m2 = M2.prototype;
        return m2.parse = function(t2) {
          this.$d = function(t3) {
            var e2 = t3.date, n2 = t3.utc;
            if (null === e2)
              return /* @__PURE__ */ new Date(NaN);
            if (b.u(e2))
              return /* @__PURE__ */ new Date();
            if (e2 instanceof Date)
              return new Date(e2);
            if ("string" == typeof e2 && !/Z$/i.test(e2)) {
              var r2 = e2.match($);
              if (r2) {
                var i2 = r2[2] - 1 || 0, s2 = (r2[7] || "0").substring(0, 3);
                return n2 ? new Date(Date.UTC(r2[1], i2, r2[3] || 1, r2[4] || 0, r2[5] || 0, r2[6] || 0, s2)) : new Date(r2[1], i2, r2[3] || 1, r2[4] || 0, r2[5] || 0, r2[6] || 0, s2);
              }
            }
            return new Date(e2);
          }(t2), this.init();
        }, m2.init = function() {
          var t2 = this.$d;
          this.$y = t2.getFullYear(), this.$M = t2.getMonth(), this.$D = t2.getDate(), this.$W = t2.getDay(), this.$H = t2.getHours(), this.$m = t2.getMinutes(), this.$s = t2.getSeconds(), this.$ms = t2.getMilliseconds();
        }, m2.$utils = function() {
          return b;
        }, m2.isValid = function() {
          return !(this.$d.toString() === l);
        }, m2.isSame = function(t2, e2) {
          var n2 = O(t2);
          return this.startOf(e2) <= n2 && n2 <= this.endOf(e2);
        }, m2.isAfter = function(t2, e2) {
          return O(t2) < this.startOf(e2);
        }, m2.isBefore = function(t2, e2) {
          return this.endOf(e2) < O(t2);
        }, m2.$g = function(t2, e2, n2) {
          return b.u(t2) ? this[e2] : this.set(n2, t2);
        }, m2.unix = function() {
          return Math.floor(this.valueOf() / 1e3);
        }, m2.valueOf = function() {
          return this.$d.getTime();
        }, m2.startOf = function(t2, e2) {
          var n2 = this, r2 = !!b.u(e2) || e2, f2 = b.p(t2), l2 = function(t3, e3) {
            var i2 = b.w(n2.$u ? Date.UTC(n2.$y, e3, t3) : new Date(n2.$y, e3, t3), n2);
            return r2 ? i2 : i2.endOf(a);
          }, $2 = function(t3, e3) {
            return b.w(n2.toDate()[t3].apply(n2.toDate("s"), (r2 ? [0, 0, 0, 0] : [23, 59, 59, 999]).slice(e3)), n2);
          }, y2 = this.$W, M3 = this.$M, m3 = this.$D, v2 = "set" + (this.$u ? "UTC" : "");
          switch (f2) {
            case h:
              return r2 ? l2(1, 0) : l2(31, 11);
            case c:
              return r2 ? l2(1, M3) : l2(0, M3 + 1);
            case o:
              var g2 = this.$locale().weekStart || 0, D2 = (y2 < g2 ? y2 + 7 : y2) - g2;
              return l2(r2 ? m3 - D2 : m3 + (6 - D2), M3);
            case a:
            case d:
              return $2(v2 + "Hours", 0);
            case u:
              return $2(v2 + "Minutes", 1);
            case s:
              return $2(v2 + "Seconds", 2);
            case i:
              return $2(v2 + "Milliseconds", 3);
            default:
              return this.clone();
          }
        }, m2.endOf = function(t2) {
          return this.startOf(t2, false);
        }, m2.$set = function(t2, e2) {
          var n2, o2 = b.p(t2), f2 = "set" + (this.$u ? "UTC" : ""), l2 = (n2 = {}, n2[a] = f2 + "Date", n2[d] = f2 + "Date", n2[c] = f2 + "Month", n2[h] = f2 + "FullYear", n2[u] = f2 + "Hours", n2[s] = f2 + "Minutes", n2[i] = f2 + "Seconds", n2[r] = f2 + "Milliseconds", n2)[o2], $2 = o2 === a ? this.$D + (e2 - this.$W) : e2;
          if (o2 === c || o2 === h) {
            var y2 = this.clone().set(d, 1);
            y2.$d[l2]($2), y2.init(), this.$d = y2.set(d, Math.min(this.$D, y2.daysInMonth())).$d;
          } else
            l2 && this.$d[l2]($2);
          return this.init(), this;
        }, m2.set = function(t2, e2) {
          return this.clone().$set(t2, e2);
        }, m2.get = function(t2) {
          return this[b.p(t2)]();
        }, m2.add = function(r2, f2) {
          var d2, l2 = this;
          r2 = Number(r2);
          var $2 = b.p(f2), y2 = function(t2) {
            var e2 = O(l2);
            return b.w(e2.date(e2.date() + Math.round(t2 * r2)), l2);
          };
          if ($2 === c)
            return this.set(c, this.$M + r2);
          if ($2 === h)
            return this.set(h, this.$y + r2);
          if ($2 === a)
            return y2(1);
          if ($2 === o)
            return y2(7);
          var M3 = (d2 = {}, d2[s] = e, d2[u] = n, d2[i] = t, d2)[$2] || 1, m3 = this.$d.getTime() + r2 * M3;
          return b.w(m3, this);
        }, m2.subtract = function(t2, e2) {
          return this.add(-1 * t2, e2);
        }, m2.format = function(t2) {
          var e2 = this, n2 = this.$locale();
          if (!this.isValid())
            return n2.invalidDate || l;
          var r2 = t2 || "YYYY-MM-DDTHH:mm:ssZ", i2 = b.z(this), s2 = this.$H, u2 = this.$m, a2 = this.$M, o2 = n2.weekdays, c2 = n2.months, f2 = n2.meridiem, h2 = function(t3, n3, i3, s3) {
            return t3 && (t3[n3] || t3(e2, r2)) || i3[n3].slice(0, s3);
          }, d2 = function(t3) {
            return b.s(s2 % 12 || 12, t3, "0");
          }, $2 = f2 || function(t3, e3, n3) {
            var r3 = t3 < 12 ? "AM" : "PM";
            return n3 ? r3.toLowerCase() : r3;
          };
          return r2.replace(y, function(t3, r3) {
            return r3 || function(t4) {
              switch (t4) {
                case "YY":
                  return String(e2.$y).slice(-2);
                case "YYYY":
                  return b.s(e2.$y, 4, "0");
                case "M":
                  return a2 + 1;
                case "MM":
                  return b.s(a2 + 1, 2, "0");
                case "MMM":
                  return h2(n2.monthsShort, a2, c2, 3);
                case "MMMM":
                  return h2(c2, a2);
                case "D":
                  return e2.$D;
                case "DD":
                  return b.s(e2.$D, 2, "0");
                case "d":
                  return String(e2.$W);
                case "dd":
                  return h2(n2.weekdaysMin, e2.$W, o2, 2);
                case "ddd":
                  return h2(n2.weekdaysShort, e2.$W, o2, 3);
                case "dddd":
                  return o2[e2.$W];
                case "H":
                  return String(s2);
                case "HH":
                  return b.s(s2, 2, "0");
                case "h":
                  return d2(1);
                case "hh":
                  return d2(2);
                case "a":
                  return $2(s2, u2, true);
                case "A":
                  return $2(s2, u2, false);
                case "m":
                  return String(u2);
                case "mm":
                  return b.s(u2, 2, "0");
                case "s":
                  return String(e2.$s);
                case "ss":
                  return b.s(e2.$s, 2, "0");
                case "SSS":
                  return b.s(e2.$ms, 3, "0");
                case "Z":
                  return i2;
              }
              return null;
            }(t3) || i2.replace(":", "");
          });
        }, m2.utcOffset = function() {
          return 15 * -Math.round(this.$d.getTimezoneOffset() / 15);
        }, m2.diff = function(r2, d2, l2) {
          var $2, y2 = this, M3 = b.p(d2), m3 = O(r2), v2 = (m3.utcOffset() - this.utcOffset()) * e, g2 = this - m3, D2 = function() {
            return b.m(y2, m3);
          };
          switch (M3) {
            case h:
              $2 = D2() / 12;
              break;
            case c:
              $2 = D2();
              break;
            case f:
              $2 = D2() / 3;
              break;
            case o:
              $2 = (g2 - v2) / 6048e5;
              break;
            case a:
              $2 = (g2 - v2) / 864e5;
              break;
            case u:
              $2 = g2 / n;
              break;
            case s:
              $2 = g2 / e;
              break;
            case i:
              $2 = g2 / t;
              break;
            default:
              $2 = g2;
          }
          return l2 ? $2 : b.a($2);
        }, m2.daysInMonth = function() {
          return this.endOf(c).$D;
        }, m2.$locale = function() {
          return D[this.$L];
        }, m2.locale = function(t2, e2) {
          if (!t2)
            return this.$L;
          var n2 = this.clone(), r2 = w(t2, e2, true);
          return r2 && (n2.$L = r2), n2;
        }, m2.clone = function() {
          return b.w(this.$d, this);
        }, m2.toDate = function() {
          return new Date(this.valueOf());
        }, m2.toJSON = function() {
          return this.isValid() ? this.toISOString() : null;
        }, m2.toISOString = function() {
          return this.$d.toISOString();
        }, m2.toString = function() {
          return this.$d.toUTCString();
        }, M2;
      }(), k = _.prototype;
      return O.prototype = k, [["$ms", r], ["$s", i], ["$m", s], ["$H", u], ["$W", a], ["$M", c], ["$y", h], ["$D", d]].forEach(function(t2) {
        k[t2[1]] = function(e2) {
          return this.$g(e2, t2[0], t2[1]);
        };
      }), O.extend = function(t2, e2) {
        return t2.$i || (t2(e2, _, O), t2.$i = true), O;
      }, O.locale = w, O.isDayjs = S, O.unix = function(t2) {
        return O(1e3 * t2);
      }, O.en = D[g], O.Ls = D, O.p = {}, O;
    });
  })(dayjs_min);
  var dayjs_minExports = dayjs_min.exports;
  const dayjs = /* @__PURE__ */ getDefaultExportFromCjs(dayjs_minExports);
  var customParseFormat$1 = { exports: {} };
  (function(module, exports) {
    !function(e, t) {
      module.exports = t();
    }(commonjsGlobal, function() {
      var e = { LTS: "h:mm:ss A", LT: "h:mm A", L: "MM/DD/YYYY", LL: "MMMM D, YYYY", LLL: "MMMM D, YYYY h:mm A", LLLL: "dddd, MMMM D, YYYY h:mm A" }, t = /(\[[^[]*\])|([-_:/.,()\s]+)|(A|a|YYYY|YY?|MM?M?M?|Do|DD?|hh?|HH?|mm?|ss?|S{1,3}|z|ZZ?)/g, n = /\d\d/, r = /\d\d?/, i = /\d*[^-_:/,()\s\d]+/, o = {}, s = function(e2) {
        return (e2 = +e2) + (e2 > 68 ? 1900 : 2e3);
      };
      var a = function(e2) {
        return function(t2) {
          this[e2] = +t2;
        };
      }, f = [/[+-]\d\d:?(\d\d)?|Z/, function(e2) {
        (this.zone || (this.zone = {})).offset = function(e3) {
          if (!e3)
            return 0;
          if ("Z" === e3)
            return 0;
          var t2 = e3.match(/([+-]|\d\d)/g), n2 = 60 * t2[1] + (+t2[2] || 0);
          return 0 === n2 ? 0 : "+" === t2[0] ? -n2 : n2;
        }(e2);
      }], h = function(e2) {
        var t2 = o[e2];
        return t2 && (t2.indexOf ? t2 : t2.s.concat(t2.f));
      }, u = function(e2, t2) {
        var n2, r2 = o.meridiem;
        if (r2) {
          for (var i2 = 1; i2 <= 24; i2 += 1)
            if (e2.indexOf(r2(i2, 0, t2)) > -1) {
              n2 = i2 > 12;
              break;
            }
        } else
          n2 = e2 === (t2 ? "pm" : "PM");
        return n2;
      }, d = { A: [i, function(e2) {
        this.afternoon = u(e2, false);
      }], a: [i, function(e2) {
        this.afternoon = u(e2, true);
      }], S: [/\d/, function(e2) {
        this.milliseconds = 100 * +e2;
      }], SS: [n, function(e2) {
        this.milliseconds = 10 * +e2;
      }], SSS: [/\d{3}/, function(e2) {
        this.milliseconds = +e2;
      }], s: [r, a("seconds")], ss: [r, a("seconds")], m: [r, a("minutes")], mm: [r, a("minutes")], H: [r, a("hours")], h: [r, a("hours")], HH: [r, a("hours")], hh: [r, a("hours")], D: [r, a("day")], DD: [n, a("day")], Do: [i, function(e2) {
        var t2 = o.ordinal, n2 = e2.match(/\d+/);
        if (this.day = n2[0], t2)
          for (var r2 = 1; r2 <= 31; r2 += 1)
            t2(r2).replace(/\[|\]/g, "") === e2 && (this.day = r2);
      }], M: [r, a("month")], MM: [n, a("month")], MMM: [i, function(e2) {
        var t2 = h("months"), n2 = (h("monthsShort") || t2.map(function(e3) {
          return e3.slice(0, 3);
        })).indexOf(e2) + 1;
        if (n2 < 1)
          throw new Error();
        this.month = n2 % 12 || n2;
      }], MMMM: [i, function(e2) {
        var t2 = h("months").indexOf(e2) + 1;
        if (t2 < 1)
          throw new Error();
        this.month = t2 % 12 || t2;
      }], Y: [/[+-]?\d+/, a("year")], YY: [n, function(e2) {
        this.year = s(e2);
      }], YYYY: [/\d{4}/, a("year")], Z: f, ZZ: f };
      function c(n2) {
        var r2, i2;
        r2 = n2, i2 = o && o.formats;
        for (var s2 = (n2 = r2.replace(/(\[[^\]]+])|(LTS?|l{1,4}|L{1,4})/g, function(t2, n3, r3) {
          var o2 = r3 && r3.toUpperCase();
          return n3 || i2[r3] || e[r3] || i2[o2].replace(/(\[[^\]]+])|(MMMM|MM|DD|dddd)/g, function(e2, t3, n4) {
            return t3 || n4.slice(1);
          });
        })).match(t), a2 = s2.length, f2 = 0; f2 < a2; f2 += 1) {
          var h2 = s2[f2], u2 = d[h2], c2 = u2 && u2[0], l = u2 && u2[1];
          s2[f2] = l ? { regex: c2, parser: l } : h2.replace(/^\[|\]$/g, "");
        }
        return function(e2) {
          for (var t2 = {}, n3 = 0, r3 = 0; n3 < a2; n3 += 1) {
            var i3 = s2[n3];
            if ("string" == typeof i3)
              r3 += i3.length;
            else {
              var o2 = i3.regex, f3 = i3.parser, h3 = e2.slice(r3), u3 = o2.exec(h3)[0];
              f3.call(t2, u3), e2 = e2.replace(u3, "");
            }
          }
          return function(e3) {
            var t3 = e3.afternoon;
            if (void 0 !== t3) {
              var n4 = e3.hours;
              t3 ? n4 < 12 && (e3.hours += 12) : 12 === n4 && (e3.hours = 0), delete e3.afternoon;
            }
          }(t2), t2;
        };
      }
      return function(e2, t2, n2) {
        n2.p.customParseFormat = true, e2 && e2.parseTwoDigitYear && (s = e2.parseTwoDigitYear);
        var r2 = t2.prototype, i2 = r2.parse;
        r2.parse = function(e3) {
          var t3 = e3.date, r3 = e3.utc, s2 = e3.args;
          this.$u = r3;
          var a2 = s2[1];
          if ("string" == typeof a2) {
            var f2 = true === s2[2], h2 = true === s2[3], u2 = f2 || h2, d2 = s2[2];
            h2 && (d2 = s2[2]), o = this.$locale(), !f2 && d2 && (o = n2.Ls[d2]), this.$d = function(e4, t4, n3) {
              try {
                if (["x", "X"].indexOf(t4) > -1)
                  return new Date(("X" === t4 ? 1e3 : 1) * e4);
                var r4 = c(t4)(e4), i3 = r4.year, o2 = r4.month, s3 = r4.day, a3 = r4.hours, f3 = r4.minutes, h3 = r4.seconds, u3 = r4.milliseconds, d3 = r4.zone, l2 = /* @__PURE__ */ new Date(), m2 = s3 || (i3 || o2 ? 1 : l2.getDate()), M2 = i3 || l2.getFullYear(), Y = 0;
                i3 && !o2 || (Y = o2 > 0 ? o2 - 1 : l2.getMonth());
                var p2 = a3 || 0, v = f3 || 0, D = h3 || 0, g = u3 || 0;
                return d3 ? new Date(Date.UTC(M2, Y, m2, p2, v, D, g + 60 * d3.offset * 1e3)) : n3 ? new Date(Date.UTC(M2, Y, m2, p2, v, D, g)) : new Date(M2, Y, m2, p2, v, D, g);
              } catch (e5) {
                return /* @__PURE__ */ new Date("");
              }
            }(t3, a2, r3), this.init(), d2 && true !== d2 && (this.$L = this.locale(d2).$L), u2 && t3 != this.format(a2) && (this.$d = /* @__PURE__ */ new Date("")), o = {};
          } else if (a2 instanceof Array)
            for (var l = a2.length, m = 1; m <= l; m += 1) {
              s2[1] = a2[m - 1];
              var M = n2.apply(this, s2);
              if (M.isValid()) {
                this.$d = M.$d, this.$L = M.$L, this.init();
                break;
              }
              m === l && (this.$d = /* @__PURE__ */ new Date(""));
            }
          else
            i2.call(this, e3);
        };
      };
    });
  })(customParseFormat$1);
  var customParseFormatExports = customParseFormat$1.exports;
  const customParseFormat = /* @__PURE__ */ getDefaultExportFromCjs(customParseFormatExports);
  var isoWeek$1 = { exports: {} };
  (function(module, exports) {
    !function(e, t) {
      module.exports = t();
    }(commonjsGlobal, function() {
      var e = "day";
      return function(t, i, s) {
        var a = function(t2) {
          return t2.add(4 - t2.isoWeekday(), e);
        }, d = i.prototype;
        d.isoWeekYear = function() {
          return a(this).year();
        }, d.isoWeek = function(t2) {
          if (!this.$utils().u(t2))
            return this.add(7 * (t2 - this.isoWeek()), e);
          var i2, d2, n2, o, r = a(this), u = (i2 = this.isoWeekYear(), d2 = this.$u, n2 = (d2 ? s.utc : s)().year(i2).startOf("year"), o = 4 - n2.isoWeekday(), n2.isoWeekday() > 4 && (o += 7), n2.add(o, e));
          return r.diff(u, "week") + 1;
        }, d.isoWeekday = function(e2) {
          return this.$utils().u(e2) ? this.day() || 7 : this.day(this.day() % 7 ? e2 : e2 - 7);
        };
        var n = d.startOf;
        d.startOf = function(e2, t2) {
          var i2 = this.$utils(), s2 = !!i2.u(t2) || t2;
          return "isoweek" === i2.p(e2) ? s2 ? this.date(this.date() - (this.isoWeekday() - 1)).startOf("day") : this.date(this.date() - 1 - (this.isoWeekday() - 1) + 7).endOf("day") : n.bind(this)(e2, t2);
        };
      };
    });
  })(isoWeek$1);
  var isoWeekExports = isoWeek$1.exports;
  const isoWeek = /* @__PURE__ */ getDefaultExportFromCjs(isoWeekExports);
  dayjs.extend(customParseFormat);
  dayjs.extend(isoWeek);
  function getPrevDate(dates, selectedDate) {
    if (!dates || !selectedDate)
      return null;
    const availableDates = getAvailableDates(dates);
    const index = getIndexValue(availableDates, selectedDate);
    return index >= 1 ? availableDates[index - 1] : null;
  }
  function getNextDate(dates, selectedDate) {
    if (!dates || !selectedDate)
      return null;
    const availableDates = getAvailableDates(dates);
    const index = getIndexValue(availableDates, selectedDate);
    const numberOfDates = availableDates.length;
    return index >= 0 && index <= numberOfDates - 1 ? availableDates[index + 1] : null;
  }
  function createOption(optionName, optionValue, available = true) {
    return { name: optionName, value: optionValue, available };
  }
  function getCalendarDays(holidays, selectedMonth) {
    const days = [];
    const dateFormat = "DD/MM/YYYY";
    const endDate = dayjs(selectedMonth.value, dateFormat).endOf("month");
    const firstDayOfMonth = endDate.startOf("month");
    const placeholders = firstDayOfMonth.isoWeekday() - 1;
    const holidayMap = createHolidayMap(holidays);
    fillPlaceholders(placeholders, days);
    let currentDate = null;
    while (!currentDate || currentDate.isBefore(endDate)) {
      if (!currentDate) {
        currentDate = firstDayOfMonth;
      } else {
        currentDate = currentDate.add(1, "day");
      }
      if (currentDate.isBefore(endDate)) {
        const day = createDayObject(currentDate, holidayMap);
        if (day) {
          days.push(day);
        }
      }
    }
    fillRemainingDays(days);
    return days;
  }
  function fillPlaceholders(placeholders, days) {
    for (let i = 0; i < placeholders; i++) {
      days.push({});
    }
  }
  function createHolidayMap(holidays) {
    const dateFormat = "DD/MM/YYYY";
    const holidayMap = holidays && holidays.length > 0 ? holidays.reduce((map, holiday) => {
      const dateKey = dayjs(holiday.date, dateFormat).format(dateFormat);
      map[dateKey] = holiday;
      return map;
    }, {}) : null;
    return holidayMap;
  }
  function createDayObject(currentDate, holidayMap) {
    const dateFormat = "DD/MM/YYYY";
    const day = {
      dayNumber: currentDate.format("DD"),
      dayString: currentDate.format("ddd"),
      date: currentDate.format(dateFormat)
    };
    const holidayKey = currentDate.format(dateFormat);
    const selectedHoliday = holidayMap[holidayKey];
    if (selectedHoliday) {
      const { price, link, isSelected, isCheapest, hasFcp, holidayLink, holidayPackageType, holidayObject } = selectedHoliday;
      day.price = price;
      day.link = link;
      day.selected = isSelected;
      day.cheapest = isCheapest;
      day.hasFcp = hasFcp != null ? hasFcp : false;
      day.holidayLink = holidayLink && holidayPackageType ? `${holidayLink}&${holidayPackageType}` : "";
      day.holidayObject = holidayObject;
    }
    return day;
  }
  function fillRemainingDays(days) {
    while (days.length % 7 !== 0) {
      days.push({ placeholder: "end" });
    }
  }
  function getIndexValue(list, selectedObj) {
    return list.findIndex((listItem) => listItem.value === selectedObj.value);
  }
  function getAvailableDates(dates) {
    return dates.filter((date) => date.available);
  }
  const _style_0$1 = ".inline-select {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n}\n.select-label--inline {\n  white-space: nowrap;\n}\n.select-label--bold {\n  font-weight: bold;\n}\n.disabled-option {\n  color: #e2e2e2;\n}\n.select-container--inline {\n  flex: 0 0 60%;\n}\n.select-container svg {\n  position: absolute;\n  right: 5px;\n  top: 10px;\n  transform: rotate(90deg);\n}\n.select-container svg.hh {\n  fill: #242424;\n}\n.select-container svg.tui {\n  fill: #000000;\n}\n.select-container svg.fcr {\n  width: 12px;\n  right: 8px;\n  top: calc(50% - 9px);\n}\n@media (min-width: 640px) {\n.select-container--inline {\n    flex: 0 0 80%;\n}\n}\n@media (min-width: 930px) {\n.select-container--inline {\n    flex: 0 0 68%;\n}\n}";
  const _hoisted_1$1 = ["id"];
  const _hoisted_2$1 = ["value", "disabled"];
  const _sfc_main$1 = {
    __name: "Dropdown.ce",
    props: {
      lbl_bold: Boolean,
      lbl_text: String,
      options: Array,
      selected: Object,
      store_property: String,
      lbl_inline_mobile: Boolean,
      dd_id: String,
      theme: String,
      retailBaseUrl: String
    },
    emits: ["option-changed"],
    setup(__props, { emit: __emit }) {
      const emit2 = __emit;
      const props = __props;
      const selectedOption = ref(props.selected);
      const onOptionChange = (event) => {
        const selectedElement = event.target.options[event.target.options.selectedIndex];
        const option = createOption(selectedElement.text, selectedElement.value);
        selectedOption.value = option;
        if (props.store_property) {
          store.commit("UPDATE", {
            [props.store_property]: option
          });
        }
        emit2("option-changed", option);
      };
      return (_ctx, _cache) => {
        return openBlock(), createElementBlock("div", {
          class: normalizeClass({ "inline-select": __props.lbl_inline_mobile })
        }, [
          __props.lbl_text ? (openBlock(), createElementBlock("label", {
            key: 0,
            class: normalizeClass(["select-label", {
              "select-label--bold": __props.lbl_bold,
              "select-label--inline": __props.lbl_inline_mobile
            }]),
            for: "select_options"
          }, toDisplayString(__props.lbl_text), 3)) : createCommentVNode("", true),
          createBaseVNode("div", {
            ref: "option",
            class: normalizeClass(["select-container", { "select-container--inline": __props.lbl_inline_mobile }])
          }, [
            withDirectives(createBaseVNode("select", {
              class: "select-container__input",
              onChange: _cache[0] || (_cache[0] = ($event) => onOptionChange($event)),
              id: __props.dd_id,
              "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => __props.selected.value = $event)
            }, [
              (openBlock(true), createElementBlock(Fragment, null, renderList(__props.options, (option) => {
                return openBlock(), createElementBlock("option", {
                  key: option.value,
                  value: option.value,
                  disabled: !option.available,
                  class: normalizeClass({ "disabled-option": !option.available })
                }, toDisplayString(option.name), 11, _hoisted_2$1);
              }), 128))
            ], 40, _hoisted_1$1), [
              [vModelSelect, __props.selected.value]
            ]),
            createVNode(SVGWrapper, {
              "icon-name": `${__props.theme === "fcr" ? "chevron-fc" : "chevron"}`,
              "retail-base-url": __props.retailBaseUrl,
              theme: __props.theme
            }, null, 8, ["icon-name", "retail-base-url", "theme"])
          ], 2)
        ], 2);
      };
    }
  };
  const Dropdown = /* @__PURE__ */ _export_sfc(_sfc_main$1, [["styles", [_style_0$1]]]);
  const _style_0 = ".mfe-calendar {\n  opacity: 0;\n}\n.mfe-calendar--loaded {\n  animation: fadeInAnimation ease 0.5s;\n  animation-iteration-count: 1;\n  animation-fill-mode: forwards;\n}\n@keyframes fadeInAnimation {\n0% {\n    opacity: 0;\n}\n100% {\n    opacity: 1;\n}\n}\n.calendar-nav {\n  width: 100%;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  border-bottom: 1px solid #dcdcdc;\n  padding: 8px;\n  margin: 0 0 8px 0;\n}\n.calendar-nav--fcr {\n  border-bottom: 1px solid #E9E3DA;\n}\n.calendar-nav__button {\n  display: flex;\n  align-items: flex-end;\n  color: white;\n  background: transparent;\n}\n.calendar-nav__button svg {\n  fill: #242424;\n}\n.calendar-nav__button svg.flipped {\n  transform: rotate(180deg);\n}\n.calendar-nav__button svg.fcr {\n  max-width: 15px;\n  max-height: 15px;\n}\n.calendar-nav__button--disabled {\n  opacity: 0.3;\n  pointer-events: none;\n}\n.calendar-nav__button--disabled svg {\n  fill: #d0d0d0;\n}\n.calendar-nav__button-text {\n  display: none;\n  padding: 0;\n}\n.calendar-nav__dates {\n  min-width: 168px;\n  margin: 0 32px;\n}\n.calendar-nav__dates--disabled {\n  opacity: 0.5;\n  pointer-events: none;\n}\n.calendar-nav--tui .calendar-nav__button svg {\n  fill: #1A7EAD;\n}\n.calendar_header {\n  display: none;\n  background: none;\n  color: #4c4c4c;\n}\n.calendar_header--FC {\n  height: 45px;\n}\n.calendar_header--FC .calendar_header__day {\n  color: #333333;\n}\n.calendar-days {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  flex-wrap: wrap;\n  position: relative;\n  transition: opacity ease-in 0.2s;\n  opacity: 1;\n}\n.calendar-days--hidden {\n  opacity: 0;\n  pointer-events: none;\n  height: 0;\n}\n.cal-overlay {\n  position: absolute;\n  background-color: #fff;\n  height: 100%;\n  width: 100%;\n  z-index: 2;\n  opacity: 0.6;\n  top: 0;\n}\n.hidden-day {\n  opacity: 0;\n}\n.calendar-loading {\n  position: relative;\n  transition: opacity ease-in 0.2s;\n  opacity: 0;\n}\n.calendar-loading--active {\n  height: 320px;\n  opacity: 1;\n  pointer-events: none;\n}\n.calendar-loading__loading-spinner {\n  height: 100px;\n  width: 100px;\n  position: absolute;\n  top: calc(50% - 50px);\n  left: calc(50% - 50px);\n}\n.calendar-loading__loading-spinner .loading-spinner__ring {\n  width: 100px;\n  height: 100px;\n  border-width: 10px;\n  margin: 0;\n}\n.calendar-loading--default .loading-spinner__ring {\n  border-top-color: #4d4d4d;\n}\n.calendar-loading--hh .loading-spinner__ring {\n  border-top-color: #de0ba0;\n}\n.calendar-loading--tui .loading-spinner__ring {\n  border-top-color: #1a7ead;\n}\n.calendar-empty {\n  position: relative;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  transition: opacity ease-in 0.2s;\n  opacity: 0;\n}\n.calendar-empty--active {\n  height: 320px;\n  opacity: 1;\n}\n.calendar-empty--hd {\n  height: calc(100% - 70px);\n  position: relative;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  min-height: 250px;\n}\n.calendar-empty--alert {\n  color: #d40e14;\n  font-size: 1.2rem;\n  text-align: center;\n}\n.calendar-empty--alert-hd {\n  color: #242424;\n  font-size: 14px;\n  font-weight: 600;\n  text-align: center;\n  display: block;\n  max-width: 300px;\n  max-height: 150px;\n  margin: auto;\n}\n.calendar-empty--alert-hd span {\n  display: block;\n  margin-top: 15px;\n}\n.calendar-empty--alert-hd a {\n  text-decoration: underline;\n  cursor: pointer;\n}\n.calendar-empty--alert-hd .calendar_unavailability-icon {\n  height: 45px;\n  width: 45px;\n  margin: 0 auto;\n}\n.calendar-empty--alert-hd .calendar_unavailability-icon--hh {\n  fill: #de0ba0;\n}\n.calendar-empty--alert-hd .calendar_unavailability-icon--tui {\n  fill: #1a7ead;\n}\n.calendar-empty--alert-hd .calendar_unavailability-text a {\n  cursor: pointer;\n}\n.calendar-empty--alert-hd .calendar_unavailability-text--tui {\n  color: #4c4c4c;\n  font-size: 16px;\n}\n.calendar-empty--alert-hd .calendar_unavailability-text--tui a {\n  color: #1a7ead !important;\n}\n@media (min-width: 640px) {\n.calendar_header {\n    display: flex;\n    justify-content: space-between;\n    align-items: center;\n    position: relative;\n}\n.calendar_header__day {\n    flex: 0 0 13.8%;\n    text-align: center;\n    font-weight: bold;\n}\n.calendar-nav__icon {\n    width: 1.6rem !important;\n    height: 1.6rem !important;\n}\n}";
  const _style_1 = '.calendar_header--fcr .calendar_header__day {\n  color: #002F17;\n  font-family: RondelleBlack, InterBlack, "Arial Black", sans-serif;\n  font-size: 13px;\n  font-weight: 900;\n  text-transform: capitalize;\n}\n.calendar-nav .select-container select {\n  height: 38px;\n  line-height: 20px;\n}\n.calendar-nav--tui .select-container__input {\n  text-transform: uppercase;\n}\n.calendar-nav--FC .calendar-nav__icon {\n  fill: #E00085 !important;\n}\n.calendar-nav--fcr .select-container {\n  position: relative;\n  line-height: 18px;\n}\n.calendar-nav--fcr .select-container select {\n  color: #002F17;\n  font-family: RondelleBook, Inter, Arial, sans-serif;\n  font-size: 13px;\n  text-transform: uppercase;\n}';
  const _hoisted_1 = ["href"];
  const _hoisted_2 = ["data-value"];
  const _hoisted_3 = /* @__PURE__ */ createBaseVNode("span", { class: "calendar-nav__button-text" }, null, -1);
  const _hoisted_4 = ["data-value"];
  const _hoisted_5 = /* @__PURE__ */ createBaseVNode("span", { class: "calendar-nav__button-text" }, null, -1);
  const _hoisted_6 = {
    key: 0,
    class: "cal-overlay"
  };
  const _hoisted_7 = /* @__PURE__ */ createStaticVNode('<span class="calendar_header__day">Mon</span><span class="calendar_header__day">Tue</span><span class="calendar_header__day">Wed</span><span class="calendar_header__day">Thu</span><span class="calendar_header__day">Fri</span><span class="calendar_header__day">Sat</span><span class="calendar_header__day">Sun</span>', 7);
  const _hoisted_14 = {
    key: 0,
    class: "cal-overlay"
  };
  const _hoisted_15 = {
    key: 0,
    class: "calendar-empty--alert-hd"
  };
  const _hoisted_16 = {
    key: 1,
    class: "calendar-empty--alert"
  };
  const _hoisted_17 = /* @__PURE__ */ createStaticVNode('<div class="calendar-loading__loading-spinner loading-spinner loading-spinner"><div class="loading-spinner__ring"></div><div class="loading-spinner__ring"></div><div class="loading-spinner__ring"></div><div class="loading-spinner__ring"></div></div>', 1);
  const _hoisted_18 = [
    _hoisted_17
  ];
  const _sfc_main = {
    __name: "Calendar.ce",
    props: {
      noResults: Boolean,
      holidays: String,
      dateSelected: String,
      dates: String,
      loading: Boolean,
      baseUrl: String,
      theme: String,
      isHolidayDetails: Boolean,
      cosmeticallySelectedDate: String,
      clientId: String,
      accountId: Number,
      availabilitySearchId: Number,
      resultsApiUrl: String,
      retailBaseUrl: String,
      whiteLabelCode: {
        type: String,
        required: true
      },
      retailBaseUrl: {
        type: String,
        required: true
      }
    },
    emits: ["onPrevClick", "onNextClick", "onDateChange", "loadAlternativeFlightByHoliday", "resetHolidayDetailsSelections"],
    setup(__props, { emit: __emit }) {
      const emit2 = __emit;
      const props = __props;
      const retailBaseLoaded = ref(false);
      const dateSelected = computed(() => JSON.parse(props.dateSelected));
      const dates = computed(() => JSON.parse(props.dates));
      const holidays = computed(() => JSON.parse(props.holidays));
      const prevDate = computed(() => getPrevDate(dates.value, dateSelected.value));
      const nextDate = computed(() => getNextDate(dates.value, dateSelected.value));
      const calendarDays = computed(() => getCalendarDays(holidays.value, dateSelected.value));
      const selectedTheme = computed(() => props.theme.toLowerCase() ? props.theme.toLowerCase() : "hh");
      const allDatesAreEmpty = computed(() => holidays.value != null && holidays.value.length > 0 ? holidays.value.filter((holiday) => holiday.price > 0).length <= 0 : false);
      const nextClick = () => emit2("onNextClick", { cosmeticallySelectedDate: props.cosmeticallySelectedDate, selectedDate: dateSelected.value });
      const prevClick = () => emit2("onPrevClick", { selectedDate: dateSelected.value, cosmeticallySelectedDate: props.cosmeticallySelectedDate });
      const onDateChange = (dropdownOption = null) => {
        emit2("onDateChange", { dropdownOption });
      };
      const loadAlternativeFlightByHoliday = (params) => emit2("loadAlternativeFlightByHoliday", params);
      const resetHolidayDetailsSelections = () => emit2("resetHolidayDetailsSelections");
      const getRelevantDayLink = (day) => props.isHolidayDetails ? props.baseUrl + day.holidayLink : props.baseUrl + day.link;
      const checkIsDaySelected = (day) => day.link ? props.cosmeticallySelectedDate ? props.cosmeticallySelectedDate === day.date : day.selected : false;
      const verifyRetailBaseLoaded = () => {
        retailBaseLoaded.value = true;
      };
      onMounted(() => {
        var _a, _b, _c;
        if (!((_a = dateSelected.value) == null ? void 0 : _a.name) && !((_b = dateSelected.value) == null ? void 0 : _b.value) && !((_c = dateSelected.value) == null ? void 0 : _c.available)) {
          onDateChange();
        }
      });
      return (_ctx, _cache) => {
        return openBlock(), createElementBlock(Fragment, null, [
          createBaseVNode("link", {
            rel: "stylesheet",
            href: `${__props.retailBaseUrl}/${__props.whiteLabelCode}/${__props.whiteLabelCode}.bundle.css`,
            type: "text/css",
            media: "all",
            onLoad: _cache[0] || (_cache[0] = ($event) => verifyRetailBaseLoaded())
          }, null, 40, _hoisted_1),
          createBaseVNode("div", {
            class: normalizeClass(["mfe-calendar", { "mfe-calendar--loaded": retailBaseLoaded.value }])
          }, [
            createBaseVNode("div", {
              class: normalizeClass(["calendar-nav", `calendar-nav--${selectedTheme.value}`])
            }, [
              createBaseVNode("button", {
                class: normalizeClass([{ "calendar-nav__button--disabled": !prevDate.value || __props.loading }, "calendar-nav__button flipped"]),
                "data-value": prevDate.value ? prevDate.value.value : null,
                onClick: prevClick,
                "data-tm-id": "calendar-prev"
              }, [
                createVNode(SVGWrapper, {
                  "icon-class": "calendar-nav__icon flipped",
                  "icon-name": `${__props.theme === "fcr" ? "chevron-fc" : "chevron"}`,
                  "retail-base-url": __props.retailBaseUrl,
                  theme: __props.theme
                }, null, 8, ["icon-name", "retail-base-url", "theme"]),
                _hoisted_3
              ], 10, _hoisted_2),
              dates.value ? (openBlock(), createBlock(Dropdown, {
                key: 0,
                dd_id: "dates",
                class: normalizeClass(["calendar-nav__dates", { "calendar-nav__dates--disabled": __props.loading }]),
                options: dates.value,
                selected: dateSelected.value,
                disabled: __props.loading,
                theme: selectedTheme.value,
                onOptionChanged: onDateChange,
                "data-tm-id": "calendar-month",
                "retail-base-url": __props.retailBaseUrl
              }, null, 8, ["class", "options", "selected", "disabled", "theme", "retail-base-url"])) : createCommentVNode("", true),
              createBaseVNode("button", {
                class: normalizeClass([{ "calendar-nav__button--disabled": !nextDate.value || __props.loading }, "calendar-nav__button"]),
                onClick: nextClick,
                "data-value": nextDate.value ? nextDate.value.value : null,
                "data-tm-id": "calendar-next"
              }, [
                _hoisted_5,
                createVNode(SVGWrapper, {
                  "icon-class": "calendar-nav__icon",
                  "icon-name": `${__props.theme === "fcr" ? "chevron-fc" : "chevron"}`,
                  "retail-base-url": __props.retailBaseUrl,
                  theme: __props.theme
                }, null, 8, ["icon-name", "retail-base-url", "theme"])
              ], 10, _hoisted_4)
            ], 2),
            createBaseVNode("div", {
              class: normalizeClass(["calendar_header", `calendar_header--${selectedTheme.value}`])
            }, [
              __props.noResults ? (openBlock(), createElementBlock("div", _hoisted_6)) : createCommentVNode("", true),
              _hoisted_7
            ], 2),
            withDirectives(createBaseVNode("div", {
              class: normalizeClass(["calendar-days", `calendar-days--${selectedTheme.value} ${__props.loading ? "calendar-days--hidden" : ""}`])
            }, [
              __props.noResults ? (openBlock(), createElementBlock("div", _hoisted_14)) : createCommentVNode("", true),
              (openBlock(true), createElementBlock(Fragment, null, renderList(calendarDays.value, (calendarDay, index) => {
                return openBlock(), createBlock(Day, {
                  key: `${index}_${calendarDay.date}`,
                  "is-selected": checkIsDaySelected(calendarDay),
                  "is-cheapest": calendarDay.cheapest,
                  price: calendarDay.price,
                  link: getRelevantDayLink(calendarDay),
                  "day-number": calendarDay.dayNumber,
                  "weekday-text": calendarDay.dayString,
                  "has-fcp": calendarDay.hasFcp,
                  "is-holiday-details": __props.isHolidayDetails,
                  "holiday-object": calendarDay.holidayObject,
                  "client-id": __props.clientId,
                  "account-id": __props.accountId,
                  "availability-search-id": __props.availabilitySearchId,
                  "results-api-url": __props.resultsApiUrl,
                  "retail-base-url": __props.retailBaseUrl,
                  theme: __props.theme,
                  onLoadAlternativeFlightByHoliday: loadAlternativeFlightByHoliday
                }, null, 8, ["is-selected", "is-cheapest", "price", "link", "day-number", "weekday-text", "has-fcp", "is-holiday-details", "holiday-object", "client-id", "account-id", "availability-search-id", "results-api-url", "retail-base-url", "theme"]);
              }), 128))
            ], 2), [
              [vShow, !allDatesAreEmpty.value]
            ]),
            withDirectives(createBaseVNode("div", {
              class: normalizeClass(["calendar-empty", { "calendar-empty--hd": __props.isHolidayDetails, "calendar-empty--active": !__props.loading }])
            }, [
              __props.isHolidayDetails ? (openBlock(), createElementBlock("div", _hoisted_15, [
                createVNode(SVGWrapper, {
                  "icon-class": "calendar_unavailability-icon",
                  "icon-name": "alert",
                  "retail-base-url": __props.retailBaseUrl,
                  theme: __props.theme
                }, null, 8, ["retail-base-url", "theme"]),
                createBaseVNode("span", {
                  class: normalizeClass(["calendar_unavailability-text", `calendar_unavailability-text--${selectedTheme.value}`])
                }, " Unfortunately, there's no availability based on your current holiday details selections. ", 2),
                createBaseVNode("span", {
                  class: normalizeClass(["calendar_unavailability-text", `calendar_unavailability-text--${selectedTheme.value}`])
                }, [
                  createBaseVNode("a", {
                    onClick: _cache[1] || (_cache[1] = ($event) => resetHolidayDetailsSelections()),
                    "data-tm-id": "calendar-reset-calendar"
                  }, "Click Here"),
                  createTextVNode(" to reset your selections ")
                ], 2)
              ])) : (openBlock(), createElementBlock("div", _hoisted_16, " Unfortunately, there's no availability for " + toDisplayString(dateSelected.value.name) + ". ", 1))
            ], 2), [
              [vShow, !__props.loading && allDatesAreEmpty.value]
            ]),
            __props.loading ? (openBlock(), createElementBlock("div", {
              key: 0,
              class: normalizeClass(["calendar-loading", `calendar-loading--${selectedTheme.value} ${__props.loading ? "calendar-loading--active" : ""}`])
            }, _hoisted_18, 2)) : createCommentVNode("", true)
          ], 2)
        ], 64);
      };
    }
  };
  const Calendar = /* @__PURE__ */ _export_sfc(_sfc_main, [["styles", [_style_0, _style_1]]]);
  const CalendarElement = /* @__PURE__ */ defineCustomElement(Calendar);
  customElements.define("mfe-calendar", CalendarElement);
});
